import typing

import android.app
import android.content
import android.database
import android.graphics
import android.net
import android.os
import android.telecom
import android.telephony.data
import android.telephony.emergency
import android.telephony.ims
import android.telephony.mbms
import android.text
import android.text.style
import android.util
import java
import java.chaquopy
import java.io
import java.lang
import java.nio.file
import java.time
import java.util
import java.util.concurrent
import java.util.function

class AccessNetworkConstants(java.lang.Object):
    TRANSPORT_TYPE_WLAN: typing.ClassVar[int] = ...
    TRANSPORT_TYPE_WWAN: typing.ClassVar[int] = ...

    class UtranBand(java.lang.Object):
        BAND_10: typing.ClassVar[int] = ...
        BAND_11: typing.ClassVar[int] = ...
        BAND_12: typing.ClassVar[int] = ...
        BAND_13: typing.ClassVar[int] = ...
        BAND_14: typing.ClassVar[int] = ...
        BAND_19: typing.ClassVar[int] = ...
        BAND_1: typing.ClassVar[int] = ...
        BAND_20: typing.ClassVar[int] = ...
        BAND_21: typing.ClassVar[int] = ...
        BAND_22: typing.ClassVar[int] = ...
        BAND_25: typing.ClassVar[int] = ...
        BAND_26: typing.ClassVar[int] = ...
        BAND_2: typing.ClassVar[int] = ...
        BAND_3: typing.ClassVar[int] = ...
        BAND_4: typing.ClassVar[int] = ...
        BAND_5: typing.ClassVar[int] = ...
        BAND_6: typing.ClassVar[int] = ...
        BAND_7: typing.ClassVar[int] = ...
        BAND_8: typing.ClassVar[int] = ...
        BAND_9: typing.ClassVar[int] = ...
        BAND_A: typing.ClassVar[int] = ...
        BAND_B: typing.ClassVar[int] = ...
        BAND_C: typing.ClassVar[int] = ...
        BAND_D: typing.ClassVar[int] = ...
        BAND_E: typing.ClassVar[int] = ...
        BAND_F: typing.ClassVar[int] = ...

    class NgranBands(java.lang.Object):
        BAND_12: typing.ClassVar[int] = ...
        BAND_14: typing.ClassVar[int] = ...
        BAND_18: typing.ClassVar[int] = ...
        BAND_1: typing.ClassVar[int] = ...
        BAND_20: typing.ClassVar[int] = ...
        BAND_257: typing.ClassVar[int] = ...
        BAND_258: typing.ClassVar[int] = ...
        BAND_25: typing.ClassVar[int] = ...
        BAND_260: typing.ClassVar[int] = ...
        BAND_261: typing.ClassVar[int] = ...
        BAND_26: typing.ClassVar[int] = ...
        BAND_28: typing.ClassVar[int] = ...
        BAND_29: typing.ClassVar[int] = ...
        BAND_2: typing.ClassVar[int] = ...
        BAND_30: typing.ClassVar[int] = ...
        BAND_34: typing.ClassVar[int] = ...
        BAND_38: typing.ClassVar[int] = ...
        BAND_39: typing.ClassVar[int] = ...
        BAND_3: typing.ClassVar[int] = ...
        BAND_40: typing.ClassVar[int] = ...
        BAND_41: typing.ClassVar[int] = ...
        BAND_46: typing.ClassVar[int] = ...
        BAND_48: typing.ClassVar[int] = ...
        BAND_50: typing.ClassVar[int] = ...
        BAND_51: typing.ClassVar[int] = ...
        BAND_53: typing.ClassVar[int] = ...
        BAND_5: typing.ClassVar[int] = ...
        BAND_65: typing.ClassVar[int] = ...
        BAND_66: typing.ClassVar[int] = ...
        BAND_70: typing.ClassVar[int] = ...
        BAND_71: typing.ClassVar[int] = ...
        BAND_74: typing.ClassVar[int] = ...
        BAND_75: typing.ClassVar[int] = ...
        BAND_76: typing.ClassVar[int] = ...
        BAND_77: typing.ClassVar[int] = ...
        BAND_78: typing.ClassVar[int] = ...
        BAND_79: typing.ClassVar[int] = ...
        BAND_7: typing.ClassVar[int] = ...
        BAND_80: typing.ClassVar[int] = ...
        BAND_81: typing.ClassVar[int] = ...
        BAND_82: typing.ClassVar[int] = ...
        BAND_83: typing.ClassVar[int] = ...
        BAND_84: typing.ClassVar[int] = ...
        BAND_86: typing.ClassVar[int] = ...
        BAND_89: typing.ClassVar[int] = ...
        BAND_8: typing.ClassVar[int] = ...
        BAND_90: typing.ClassVar[int] = ...
        BAND_91: typing.ClassVar[int] = ...
        BAND_92: typing.ClassVar[int] = ...
        BAND_93: typing.ClassVar[int] = ...
        BAND_94: typing.ClassVar[int] = ...
        BAND_95: typing.ClassVar[int] = ...
        BAND_96: typing.ClassVar[int] = ...

    class GeranBand(java.lang.Object):
        BAND_450: typing.ClassVar[int] = ...
        BAND_480: typing.ClassVar[int] = ...
        BAND_710: typing.ClassVar[int] = ...
        BAND_750: typing.ClassVar[int] = ...
        BAND_850: typing.ClassVar[int] = ...
        BAND_DCS1800: typing.ClassVar[int] = ...
        BAND_E900: typing.ClassVar[int] = ...
        BAND_ER900: typing.ClassVar[int] = ...
        BAND_P900: typing.ClassVar[int] = ...
        BAND_PCS1900: typing.ClassVar[int] = ...
        BAND_R900: typing.ClassVar[int] = ...
        BAND_T380: typing.ClassVar[int] = ...
        BAND_T410: typing.ClassVar[int] = ...
        BAND_T810: typing.ClassVar[int] = ...

    class EutranBand(java.lang.Object):
        BAND_10: typing.ClassVar[int] = ...
        BAND_11: typing.ClassVar[int] = ...
        BAND_12: typing.ClassVar[int] = ...
        BAND_13: typing.ClassVar[int] = ...
        BAND_14: typing.ClassVar[int] = ...
        BAND_17: typing.ClassVar[int] = ...
        BAND_18: typing.ClassVar[int] = ...
        BAND_19: typing.ClassVar[int] = ...
        BAND_1: typing.ClassVar[int] = ...
        BAND_20: typing.ClassVar[int] = ...
        BAND_21: typing.ClassVar[int] = ...
        BAND_22: typing.ClassVar[int] = ...
        BAND_23: typing.ClassVar[int] = ...
        BAND_24: typing.ClassVar[int] = ...
        BAND_25: typing.ClassVar[int] = ...
        BAND_26: typing.ClassVar[int] = ...
        BAND_27: typing.ClassVar[int] = ...
        BAND_28: typing.ClassVar[int] = ...
        BAND_2: typing.ClassVar[int] = ...
        BAND_30: typing.ClassVar[int] = ...
        BAND_31: typing.ClassVar[int] = ...
        BAND_33: typing.ClassVar[int] = ...
        BAND_34: typing.ClassVar[int] = ...
        BAND_35: typing.ClassVar[int] = ...
        BAND_36: typing.ClassVar[int] = ...
        BAND_37: typing.ClassVar[int] = ...
        BAND_38: typing.ClassVar[int] = ...
        BAND_39: typing.ClassVar[int] = ...
        BAND_3: typing.ClassVar[int] = ...
        BAND_40: typing.ClassVar[int] = ...
        BAND_41: typing.ClassVar[int] = ...
        BAND_42: typing.ClassVar[int] = ...
        BAND_43: typing.ClassVar[int] = ...
        BAND_44: typing.ClassVar[int] = ...
        BAND_45: typing.ClassVar[int] = ...
        BAND_46: typing.ClassVar[int] = ...
        BAND_47: typing.ClassVar[int] = ...
        BAND_48: typing.ClassVar[int] = ...
        BAND_49: typing.ClassVar[int] = ...
        BAND_4: typing.ClassVar[int] = ...
        BAND_50: typing.ClassVar[int] = ...
        BAND_51: typing.ClassVar[int] = ...
        BAND_52: typing.ClassVar[int] = ...
        BAND_53: typing.ClassVar[int] = ...
        BAND_5: typing.ClassVar[int] = ...
        BAND_65: typing.ClassVar[int] = ...
        BAND_66: typing.ClassVar[int] = ...
        BAND_68: typing.ClassVar[int] = ...
        BAND_6: typing.ClassVar[int] = ...
        BAND_70: typing.ClassVar[int] = ...
        BAND_71: typing.ClassVar[int] = ...
        BAND_72: typing.ClassVar[int] = ...
        BAND_73: typing.ClassVar[int] = ...
        BAND_74: typing.ClassVar[int] = ...
        BAND_7: typing.ClassVar[int] = ...
        BAND_85: typing.ClassVar[int] = ...
        BAND_87: typing.ClassVar[int] = ...
        BAND_88: typing.ClassVar[int] = ...
        BAND_8: typing.ClassVar[int] = ...
        BAND_9: typing.ClassVar[int] = ...

    class AccessNetworkType(java.lang.Object):
        CDMA2000: typing.ClassVar[int] = ...
        EUTRAN: typing.ClassVar[int] = ...
        GERAN: typing.ClassVar[int] = ...
        IWLAN: typing.ClassVar[int] = ...
        NGRAN: typing.ClassVar[int] = ...
        UNKNOWN: typing.ClassVar[int] = ...
        UTRAN: typing.ClassVar[int] = ...

class AvailableNetworkInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AvailableNetworkInfo]] = ...
    PRIORITY_HIGH: typing.ClassVar[int] = ...
    PRIORITY_LOW: typing.ClassVar[int] = ...
    PRIORITY_MED: typing.ClassVar[int] = ...
    def __init__(self, subId: int | java.jint | java.lang.Integer, priority: int | java.jint | java.lang.Integer, mccMncs: java.util.List[java.lang.String], bands: java.util.List[java.lang.Integer], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBands(self) -> java.util.List[java.lang.Integer]: ...
    def getMccMncs(self) -> java.util.List[java.lang.String]: ...
    def getPriority(self) -> int: ...
    def getRadioAccessSpecifiers(self) -> java.util.List[RadioAccessSpecifier]: ...
    def getSubId(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, subId: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> AvailableNetworkInfo: ...
        def setMccMncs(self, mccMncs: java.util.List[java.lang.String], /) -> AvailableNetworkInfo.Builder: ...
        def setPriority(self, priority: int | java.jint | java.lang.Integer, /) -> AvailableNetworkInfo.Builder: ...
        def setRadioAccessSpecifiers(self, radioAccessSpecifiers: java.util.List[RadioAccessSpecifier], /) -> AvailableNetworkInfo.Builder: ...

class BarringInfo(android.os.Parcelable):
    BARRING_SERVICE_TYPE_CS_FALLBACK: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_CS_SERVICE: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_CS_VOICE: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_EMERGENCY: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_MMTEL_VIDEO: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_MMTEL_VOICE: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_MO_DATA: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_MO_SIGNALLING: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_PS_SERVICE: typing.ClassVar[int] = ...
    BARRING_SERVICE_TYPE_SMS: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BarringInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, rhs: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBarringServiceInfo(self, service: int | java.jint | java.lang.Integer, /) -> BarringInfo.BarringServiceInfo: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class BarringServiceInfo(android.os.Parcelable):
        BARRING_TYPE_CONDITIONAL: typing.ClassVar[int] = ...
        BARRING_TYPE_NONE: typing.ClassVar[int] = ...
        BARRING_TYPE_UNCONDITIONAL: typing.ClassVar[int] = ...
        BARRING_TYPE_UNKNOWN: typing.ClassVar[int] = ...
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BarringInfo.BarringServiceInfo]] = ...
        def describeContents(self) -> int: ...
        def equals(self, rhs: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getBarringType(self) -> int: ...
        def getConditionalBarringFactor(self) -> int: ...
        def getConditionalBarringTimeSeconds(self) -> int: ...
        def hashCode(self) -> int: ...
        def isBarred(self) -> bool: ...
        def isConditionallyBarred(self) -> bool: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CarrierConfigManager(java.lang.Object):
    ACTION_CARRIER_CONFIG_CHANGED: typing.ClassVar[str] = ...
    CARRIER_NR_AVAILABILITY_NSA: typing.ClassVar[int] = ...
    CARRIER_NR_AVAILABILITY_SA: typing.ClassVar[int] = ...
    CROSS_SIM_SPN_FORMAT_CARRIER_NAME_ONLY: typing.ClassVar[int] = ...
    CROSS_SIM_SPN_FORMAT_CARRIER_NAME_WITH_BRANDING: typing.ClassVar[int] = ...
    DATA_CYCLE_THRESHOLD_DISABLED: typing.ClassVar[int] = ...
    DATA_CYCLE_USE_PLATFORM_DEFAULT: typing.ClassVar[int] = ...
    ENABLE_EAP_METHOD_PREFIX_BOOL: typing.ClassVar[str] = ...
    EXTRA_REBROADCAST_ON_UNLOCK: typing.ClassVar[str] = ...
    EXTRA_SLOT_INDEX: typing.ClassVar[str] = ...
    EXTRA_SUBSCRIPTION_INDEX: typing.ClassVar[str] = ...
    IMSI_KEY_AVAILABILITY_INT: typing.ClassVar[str] = ...
    KEY_5G_NR_SSRSRP_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_5G_NR_SSRSRQ_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_5G_NR_SSSINR_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_ADDITIONAL_CALL_SETTING_BOOL: typing.ClassVar[str] = ...
    KEY_ADDITIONAL_SETTINGS_CALLER_ID_VISIBILITY_BOOL: typing.ClassVar[str] = ...
    KEY_ADDITIONAL_SETTINGS_CALL_WAITING_VISIBILITY_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_ADDING_APNS_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_ADD_CALL_DURING_VIDEO_CALL_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_EMERGENCY_NUMBERS_IN_CALL_LOG_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_EMERGENCY_VIDEO_CALLS_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_HOLD_CALL_DURING_EMERGENCY_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_HOLD_VIDEO_CALL_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_LOCAL_DTMF_TONES_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_MERGE_WIFI_CALLS_WHEN_VOWIFI_OFF_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_NON_EMERGENCY_CALLS_IN_ECM_BOOL: typing.ClassVar[str] = ...
    KEY_ALLOW_VIDEO_CALLING_FALLBACK_BOOL: typing.ClassVar[str] = ...
    KEY_ALWAYS_SHOW_DATA_RAT_ICON_BOOL: typing.ClassVar[str] = ...
    KEY_ALWAYS_SHOW_EMERGENCY_ALERT_ONOFF_BOOL: typing.ClassVar[str] = ...
    KEY_ALWAYS_SHOW_PRIMARY_SIGNAL_BAR_IN_OPPORTUNISTIC_NETWORK_BOOLEAN: typing.ClassVar[str] = ...
    KEY_APN_EXPAND_BOOL: typing.ClassVar[str] = ...
    KEY_APN_SETTINGS_DEFAULT_APN_TYPES_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_AUTO_RETRY_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_CALL_BARRING_DEFAULT_SERVICE_CLASS_INT: typing.ClassVar[str] = ...
    KEY_CALL_BARRING_SUPPORTS_DEACTIVATE_ALL_BOOL: typing.ClassVar[str] = ...
    KEY_CALL_BARRING_SUPPORTS_PASSWORD_CHANGE_BOOL: typing.ClassVar[str] = ...
    KEY_CALL_BARRING_VISIBILITY_BOOL: typing.ClassVar[str] = ...
    KEY_CALL_COMPOSER_PICTURE_SERVER_URL_STRING: typing.ClassVar[str] = ...
    KEY_CALL_FORWARDING_BLOCKS_WHILE_ROAMING_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CALL_REDIRECTION_SERVICE_COMPONENT_NAME_STRING: typing.ClassVar[str] = ...
    KEY_CAPABILITIES_EXEMPT_FROM_SINGLE_DC_CHECK_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_ALLOW_DEFLECT_IMS_CALL_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_ALLOW_TURNOFF_IMS_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_APP_REQUIRED_DURING_SIM_SETUP_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_CALL_SCREENING_APP_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_CERTIFICATE_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_CONFIG_APPLIED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_CONFIG_VERSION_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_CROSS_SIM_IMS_AVAILABLE_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_DATA_CALL_PERMANENT_FAILURE_STRINGS: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_ACTIONS_ON_DCFAILURE_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_ACTIONS_ON_DEFAULT_NETWORK_AVAILABLE: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_ACTIONS_ON_REDIRECTION_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_ACTIONS_ON_RESET: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_REDIRECTION_URL_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_WFC_IMS_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_WFC_IMS_MODE_INT: typing.ClassVar[str] = ...
    KEY_CARRIER_DEFAULT_WFC_IMS_ROAMING_MODE_INT: typing.ClassVar[str] = ...
    KEY_CARRIER_FORCE_DISABLE_ETWS_CMAS_TEST_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_IMS_GBA_REQUIRED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_INSTANT_LETTERING_AVAILABLE_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_INSTANT_LETTERING_ENCODING_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_INSTANT_LETTERING_ESCAPED_CHARS_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_INSTANT_LETTERING_INVALID_CHARS_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_INSTANT_LETTERING_LENGTH_LIMIT_INT: typing.ClassVar[str] = ...
    KEY_CARRIER_METERED_APN_TYPES_STRINGS: typing.ClassVar[str] = ...
    KEY_CARRIER_METERED_ROAMING_APN_TYPES_STRINGS: typing.ClassVar[str] = ...
    KEY_CARRIER_NAME_OVERRIDE_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_NAME_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_NR_AVAILABILITIES_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_PROVISIONS_WIFI_MERGED_NETWORKS_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_RCS_PROVISIONING_REQUIRED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_ROAMING_NTN_EMERGENCY_CALL_TO_SATELLITE_HANDOVER_TYPE_INT: typing.ClassVar[str] = ...
    KEY_CARRIER_SERVICE_NAME_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_SERVICE_NUMBER_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_SETTINGS_ACTIVITY_COMPONENT_NAME_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_SETTINGS_ENABLE_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_SUPPORTED_SATELLITE_SERVICES_PER_PROVIDER_BUNDLE: typing.ClassVar[str] = ...
    KEY_CARRIER_SUPPORTS_OPP_DATA_AUTO_PROVISIONING_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_SUPPORTS_SS_OVER_UT_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_SUPPORTS_TETHERING_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_USE_IMS_FIRST_FOR_EMERGENCY_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_USSD_METHOD_INT: typing.ClassVar[str] = ...
    KEY_CARRIER_UT_PROVISIONING_REQUIRED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_VOLTE_AVAILABLE_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_VOLTE_OVERRIDE_WFC_PROVISIONING_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_VOLTE_PROVISIONED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_VOLTE_PROVISIONING_REQUIRED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_VOLTE_TTY_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_VT_AVAILABLE_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_VVM_PACKAGE_NAME_STRING: typing.ClassVar[str] = ...
    KEY_CARRIER_VVM_PACKAGE_NAME_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CARRIER_WFC_IMS_AVAILABLE_BOOL: typing.ClassVar[str] = ...
    KEY_CARRIER_WFC_SUPPORTS_WIFI_ONLY_BOOL: typing.ClassVar[str] = ...
    KEY_CDMA_3WAYCALL_FLASH_DELAY_INT: typing.ClassVar[str] = ...
    KEY_CDMA_DTMF_TONE_DELAY_INT: typing.ClassVar[str] = ...
    KEY_CDMA_NONROAMING_NETWORKS_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CDMA_ROAMING_MODE_INT: typing.ClassVar[str] = ...
    KEY_CDMA_ROAMING_NETWORKS_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_CELLULAR_SERVICE_CAPABILITIES_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_CELLULAR_USAGE_SETTING_INT: typing.ClassVar[str] = ...
    KEY_CHECK_PRICING_WITH_CARRIER_FOR_DATA_ROAMING_BOOL: typing.ClassVar[str] = ...
    KEY_CI_ACTION_ON_SYS_UPDATE_BOOL: typing.ClassVar[str] = ...
    KEY_CI_ACTION_ON_SYS_UPDATE_EXTRA_STRING: typing.ClassVar[str] = ...
    KEY_CI_ACTION_ON_SYS_UPDATE_EXTRA_VAL_STRING: typing.ClassVar[str] = ...
    KEY_CI_ACTION_ON_SYS_UPDATE_INTENT_STRING: typing.ClassVar[str] = ...
    KEY_CONFIG_IMS_MMTEL_PACKAGE_OVERRIDE_STRING: typing.ClassVar[str] = ...
    KEY_CONFIG_IMS_PACKAGE_OVERRIDE_STRING: typing.ClassVar[str] = ...
    KEY_CONFIG_IMS_RCS_PACKAGE_OVERRIDE_STRING: typing.ClassVar[str] = ...
    KEY_CONFIG_PLANS_PACKAGE_OVERRIDE_STRING: typing.ClassVar[str] = ...
    KEY_CONFIG_TELEPHONY_USE_OWN_NUMBER_FOR_VOICEMAIL_BOOL: typing.ClassVar[str] = ...
    KEY_CONFIG_WIFI_DISABLE_IN_ECBM: typing.ClassVar[str] = ...
    KEY_CROSS_SIM_SPN_FORMAT_INT: typing.ClassVar[str] = ...
    KEY_CSP_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_DATA_LIMIT_NOTIFICATION_BOOL: typing.ClassVar[str] = ...
    KEY_DATA_LIMIT_THRESHOLD_BYTES_LONG: typing.ClassVar[str] = ...
    KEY_DATA_RAPID_NOTIFICATION_BOOL: typing.ClassVar[str] = ...
    KEY_DATA_SWITCH_VALIDATION_MIN_INTERVAL_MILLIS_LONG: typing.ClassVar[str] = ...
    KEY_DATA_SWITCH_VALIDATION_TIMEOUT_LONG: typing.ClassVar[str] = ...
    KEY_DATA_WARNING_NOTIFICATION_BOOL: typing.ClassVar[str] = ...
    KEY_DATA_WARNING_THRESHOLD_BYTES_LONG: typing.ClassVar[str] = ...
    KEY_DEFAULT_SIM_CALL_MANAGER_STRING: typing.ClassVar[str] = ...
    KEY_DEFAULT_VM_NUMBER_ROAMING_AND_IMS_UNREGISTERED_STRING: typing.ClassVar[str] = ...
    KEY_DEFAULT_VM_NUMBER_STRING: typing.ClassVar[str] = ...
    KEY_DIAL_STRING_REPLACE_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_DISABLE_CDMA_ACTIVATION_CODE_BOOL: typing.ClassVar[str] = ...
    KEY_DISABLE_CHARGE_INDICATION_BOOL: typing.ClassVar[str] = ...
    KEY_DISABLE_SUPPLEMENTARY_SERVICES_IN_AIRPLANE_MODE_BOOL: typing.ClassVar[str] = ...
    KEY_DISCONNECT_CAUSE_PLAY_BUSYTONE_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_DISPLAY_CALL_STRENGTH_INDICATOR_BOOL: typing.ClassVar[str] = ...
    KEY_DISPLAY_HD_AUDIO_PROPERTY_BOOL: typing.ClassVar[str] = ...
    KEY_DROP_VIDEO_CALL_WHEN_ANSWERING_AUDIO_CALL_BOOL: typing.ClassVar[str] = ...
    KEY_DTMF_TYPE_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_DURATION_BLOCKING_DISABLED_AFTER_EMERGENCY_INT: typing.ClassVar[str] = ...
    KEY_EDITABLE_ENHANCED_4G_LTE_BOOL: typing.ClassVar[str] = ...
    KEY_EDITABLE_VOICEMAIL_NUMBER_BOOL: typing.ClassVar[str] = ...
    KEY_EDITABLE_VOICEMAIL_NUMBER_SETTING_BOOL: typing.ClassVar[str] = ...
    KEY_EDITABLE_WFC_MODE_BOOL: typing.ClassVar[str] = ...
    KEY_EDITABLE_WFC_ROAMING_MODE_BOOL: typing.ClassVar[str] = ...
    KEY_EMERGENCY_NOTIFICATION_DELAY_INT: typing.ClassVar[str] = ...
    KEY_EMERGENCY_NUMBER_PREFIX_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_ENABLE_CROSS_SIM_CALLING_ON_OPPORTUNISTIC_DATA_BOOL: typing.ClassVar[str] = ...
    KEY_ENABLE_DIALER_KEY_VIBRATION_BOOL: typing.ClassVar[str] = ...
    KEY_ENHANCED_4G_LTE_ON_BY_DEFAULT_BOOL: typing.ClassVar[str] = ...
    KEY_ENHANCED_4G_LTE_TITLE_VARIANT_INT: typing.ClassVar[str] = ...
    KEY_ESIM_DOWNLOAD_RETRY_BACKOFF_TIMER_SEC_INT: typing.ClassVar[str] = ...
    KEY_ESIM_MAX_DOWNLOAD_RETRY_ATTEMPTS_INT: typing.ClassVar[str] = ...
    KEY_FORCE_HOME_NETWORK_BOOL: typing.ClassVar[str] = ...
    KEY_GSM_DTMF_TONE_DELAY_INT: typing.ClassVar[str] = ...
    KEY_GSM_NONROAMING_NETWORKS_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_GSM_ROAMING_NETWORKS_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_HAS_IN_CALL_NOISE_SUPPRESSION_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_CARRIER_NETWORK_SETTINGS_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_ENHANCED_4G_LTE_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_IMS_APN_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_LTE_PLUS_DATA_ICON_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_PREFERRED_NETWORK_TYPE_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_PRESET_APN_DETAILS_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_SIM_LOCK_SETTINGS_BOOL: typing.ClassVar[str] = ...
    KEY_HIDE_TTY_HCO_VCO_WITH_RTT_BOOL: typing.ClassVar[str] = ...
    KEY_IGNORE_DATA_ENABLED_CHANGED_FOR_VIDEO_CALLS: typing.ClassVar[str] = ...
    KEY_IGNORE_RTT_MODE_SETTING_BOOL: typing.ClassVar[str] = ...
    KEY_IGNORE_SIM_NETWORK_LOCKED_EVENTS_BOOL: typing.ClassVar[str] = ...
    KEY_IMS_CONFERENCE_SIZE_LIMIT_INT: typing.ClassVar[str] = ...
    KEY_IMS_DTMF_TONE_DELAY_INT: typing.ClassVar[str] = ...
    KEY_INCLUDE_LTE_FOR_NR_ADVANCED_THRESHOLD_BANDWIDTH_BOOL: typing.ClassVar[str] = ...
    KEY_IS_IMS_CONFERENCE_SIZE_ENFORCED_BOOL: typing.ClassVar[str] = ...
    KEY_IS_OPPORTUNISTIC_SUBSCRIPTION_BOOL: typing.ClassVar[str] = ...
    KEY_LTE_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_LTE_RSRQ_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_LTE_RSSNR_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_MDN_IS_ADDITIONAL_VOICEMAIL_NUMBER_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_ALIAS_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_ALIAS_MAX_CHARS_INT: typing.ClassVar[str] = ...
    KEY_MMS_ALIAS_MIN_CHARS_INT: typing.ClassVar[str] = ...
    KEY_MMS_ALLOW_ATTACH_AUDIO_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_APPEND_TRANSACTION_ID_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_CLOSE_CONNECTION_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_EMAIL_GATEWAY_NUMBER_STRING: typing.ClassVar[str] = ...
    KEY_MMS_GROUP_MMS_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_HTTP_PARAMS_STRING: typing.ClassVar[str] = ...
    KEY_MMS_HTTP_SOCKET_TIMEOUT_INT: typing.ClassVar[str] = ...
    KEY_MMS_MAX_IMAGE_HEIGHT_INT: typing.ClassVar[str] = ...
    KEY_MMS_MAX_IMAGE_WIDTH_INT: typing.ClassVar[str] = ...
    KEY_MMS_MAX_MESSAGE_SIZE_INT: typing.ClassVar[str] = ...
    KEY_MMS_MESSAGE_TEXT_MAX_SIZE_INT: typing.ClassVar[str] = ...
    KEY_MMS_MMS_DELIVERY_REPORT_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_MMS_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_MMS_READ_REPORT_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_MULTIPART_SMS_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_NAI_SUFFIX_STRING: typing.ClassVar[str] = ...
    KEY_MMS_NETWORK_RELEASE_TIMEOUT_MILLIS_INT: typing.ClassVar[str] = ...
    KEY_MMS_NOTIFY_WAP_MMSC_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_RECIPIENT_LIMIT_INT: typing.ClassVar[str] = ...
    KEY_MMS_SEND_MULTIPART_SMS_AS_SEPARATE_MESSAGES_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_SHOW_CELL_BROADCAST_APP_LINKS_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_SMS_DELIVERY_REPORT_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_SMS_TO_MMS_TEXT_LENGTH_THRESHOLD_INT: typing.ClassVar[str] = ...
    KEY_MMS_SMS_TO_MMS_TEXT_THRESHOLD_INT: typing.ClassVar[str] = ...
    KEY_MMS_SUBJECT_MAX_LENGTH_INT: typing.ClassVar[str] = ...
    KEY_MMS_SUPPORT_HTTP_CHARSET_HEADER_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_SUPPORT_MMS_CONTENT_DISPOSITION_BOOL: typing.ClassVar[str] = ...
    KEY_MMS_UA_PROF_TAG_NAME_STRING: typing.ClassVar[str] = ...
    KEY_MMS_UA_PROF_URL_STRING: typing.ClassVar[str] = ...
    KEY_MMS_USER_AGENT_STRING: typing.ClassVar[str] = ...
    KEY_MONTHLY_DATA_CYCLE_DAY_INT: typing.ClassVar[str] = ...
    KEY_NTN_LTE_RSRP_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_NTN_LTE_RSRQ_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_NTN_LTE_RSSNR_THRESHOLDS_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_ONLY_AUTO_SELECT_IN_HOME_NETWORK_BOOL: typing.ClassVar[str] = ...
    KEY_ONLY_SINGLE_DC_ALLOWED_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_OPERATOR_SELECTION_EXPAND_BOOL: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_BACKOFF_TIME_LONG: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_DATA_SWITCH_EXIT_HYSTERESIS_TIME_LONG: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_DATA_SWITCH_HYSTERESIS_TIME_LONG: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_ENTRY_OR_EXIT_HYSTERESIS_TIME_LONG: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_ENTRY_THRESHOLD_BANDWIDTH_INT: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_ENTRY_THRESHOLD_RSRP_INT: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_ENTRY_THRESHOLD_RSSNR_INT: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_EXIT_THRESHOLD_RSRP_INT: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_EXIT_THRESHOLD_RSSNR_INT: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_MAX_BACKOFF_TIME_LONG: typing.ClassVar[str] = ...
    KEY_OPPORTUNISTIC_NETWORK_PING_PONG_TIME_LONG: typing.ClassVar[str] = ...
    KEY_PARAMETERS_USED_FOR_NTN_LTE_SIGNAL_BAR_INT: typing.ClassVar[str] = ...
    KEY_PING_TEST_BEFORE_DATA_SWITCH_BOOL: typing.ClassVar[str] = ...
    KEY_PREFER_2G_BOOL: typing.ClassVar[str] = ...
    KEY_PREFER_3G_VISIBILITY_BOOL: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_MAXIMUM_DAILY_NOTIFICATION_COUNT_INT: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_MAXIMUM_MONTHLY_NOTIFICATION_COUNT_INT: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_NETWORK_SETUP_TIME_MILLIS_LONG: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_NOTIFICATION_BACKOFF_HYSTERESIS_TIME_MILLIS_LONG: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_NOTIFICATION_DISPLAY_TIMEOUT_MILLIS_LONG: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_PURCHASE_CONDITION_BACKOFF_HYSTERESIS_TIME_MILLIS_LONG: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_PURCHASE_URL_STRING: typing.ClassVar[str] = ...
    KEY_PREMIUM_CAPABILITY_SUPPORTED_ON_LTE_BOOL: typing.ClassVar[str] = ...
    KEY_PREVENT_CLIR_ACTIVATION_AND_DEACTIVATION_CODE_BOOL: typing.ClassVar[str] = ...
    KEY_RADIO_RESTART_FAILURE_CAUSES_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_RATCHET_NR_ADVANCED_BANDWIDTH_IF_RRC_IDLE_BOOL: typing.ClassVar[str] = ...
    KEY_RCS_CONFIG_SERVER_URL_STRING: typing.ClassVar[str] = ...
    KEY_READ_ONLY_APN_FIELDS_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_READ_ONLY_APN_TYPES_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_REQUIRE_ENTITLEMENT_CHECKS_BOOL: typing.ClassVar[str] = ...
    KEY_RESTART_RADIO_ON_PDP_FAIL_REGULAR_DEACTIVATION_BOOL: typing.ClassVar[str] = ...
    KEY_RTT_AUTO_UPGRADE_BOOL: typing.ClassVar[str] = ...
    KEY_RTT_DOWNGRADE_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_RTT_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_RTT_SUPPORTED_FOR_VT_BOOL: typing.ClassVar[str] = ...
    KEY_RTT_SUPPORTED_WHILE_ROAMING_BOOL: typing.ClassVar[str] = ...
    KEY_RTT_UPGRADE_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_RTT_UPGRADE_SUPPORTED_FOR_DOWNGRADED_VT_CALL_BOOL: typing.ClassVar[str] = ...
    KEY_SATELLITE_ATTACH_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_SATELLITE_CONNECTION_HYSTERESIS_SEC_INT: typing.ClassVar[str] = ...
    KEY_SATELLITE_ENTITLEMENT_STATUS_REFRESH_DAYS_INT: typing.ClassVar[str] = ...
    KEY_SATELLITE_ENTITLEMENT_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_SATELLITE_ESOS_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_SATELLITE_ROAMING_ESOS_INACTIVITY_TIMEOUT_SEC_INT: typing.ClassVar[str] = ...
    KEY_SATELLITE_ROAMING_P2P_SMS_INACTIVITY_TIMEOUT_SEC_INT: typing.ClassVar[str] = ...
    KEY_SATELLITE_ROAMING_P2P_SMS_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_SATELLITE_ROAMING_SCREEN_OFF_INACTIVITY_TIMEOUT_SEC_INT: typing.ClassVar[str] = ...
    KEY_SHOW_4G_FOR_3G_DATA_ICON_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_4G_FOR_LTE_DATA_ICON_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_APN_SETTING_CDMA_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_BLOCKING_PAY_PHONE_OPTION_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_CALL_BLOCKING_DISABLED_NOTIFICATION_ALWAYS_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_CDMA_CHOICES_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_FORWARDED_NUMBER_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_ICCID_IN_SIM_STATUS_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_IMS_REGISTRATION_STATUS_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_ONSCREEN_DIAL_BUTTON_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_ROAMING_INDICATOR_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_SIGNAL_STRENGTH_IN_SIM_STATUS_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_VIDEO_CALL_CHARGES_ALERT_DIALOG_BOOL: typing.ClassVar[str] = ...
    KEY_SHOW_WFC_LOCATION_PRIVACY_POLICY_BOOL: typing.ClassVar[str] = ...
    KEY_SIMPLIFIED_NETWORK_SETTINGS_BOOL: typing.ClassVar[str] = ...
    KEY_SIM_COUNTRY_ISO_OVERRIDE_STRING: typing.ClassVar[str] = ...
    KEY_SIM_NETWORK_UNLOCK_ALLOW_DISMISS_BOOL: typing.ClassVar[str] = ...
    KEY_SMDP_SERVER_ADDRESS_STRING: typing.ClassVar[str] = ...
    KEY_SMS_REQUIRES_DESTINATION_NUMBER_CONVERSION_BOOL: typing.ClassVar[str] = ...
    KEY_SUBSCRIPTION_GROUP_UUID_STRING: typing.ClassVar[str] = ...
    KEY_SUPPORTED_PREMIUM_CAPABILITIES_INT_ARRAY: typing.ClassVar[str] = ...
    KEY_SUPPORTS_BUSINESS_CALL_COMPOSER_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORTS_CALL_COMPOSER_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORTS_DEVICE_TO_DEVICE_COMMUNICATION_USING_DTMF_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORTS_DEVICE_TO_DEVICE_COMMUNICATION_USING_RTP_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORTS_SDP_NEGOTIATION_OF_D2D_RTP_HEADER_EXTENSIONS_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_3GPP_CALL_FORWARDING_WHILE_ROAMING_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_ADD_CONFERENCE_PARTICIPANTS_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_ADHOC_CONFERENCE_CALLS_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_CLIR_NETWORK_DEFAULT_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_CONFERENCE_CALL_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_EMERGENCY_SMS_OVER_IMS_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_ENHANCED_CALL_BLOCKING_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_IMS_CONFERENCE_EVENT_PACKAGE_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_PAUSE_IMS_VIDEO_CALLS_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_SWAP_AFTER_MERGE_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_TDSCDMA_BOOL: typing.ClassVar[str] = ...
    KEY_SUPPORT_TDSCDMA_ROAMING_NETWORKS_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_SWITCH_DATA_TO_PRIMARY_IF_PRIMARY_IS_OOS_BOOL: typing.ClassVar[str] = ...
    KEY_TREAT_DOWNGRADED_VIDEO_CALLS_AS_VIDEO_CALLS_BOOL: typing.ClassVar[str] = ...
    KEY_TTY_SUPPORTED_BOOL: typing.ClassVar[str] = ...
    KEY_UNLOGGABLE_NUMBERS_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_USE_ACS_FOR_RCS_BOOL: typing.ClassVar[str] = ...
    KEY_USE_HFA_FOR_PROVISIONING_BOOL: typing.ClassVar[str] = ...
    KEY_USE_IP_FOR_CALLING_INDICATOR_BOOL: typing.ClassVar[str] = ...
    KEY_USE_OTASP_FOR_PROVISIONING_BOOL: typing.ClassVar[str] = ...
    KEY_USE_RCS_PRESENCE_BOOL: typing.ClassVar[str] = ...
    KEY_USE_RCS_SIP_OPTIONS_BOOL: typing.ClassVar[str] = ...
    KEY_USE_WFC_HOME_NETWORK_MODE_IN_ROAMING_NETWORK_BOOL: typing.ClassVar[str] = ...
    KEY_VOICEMAIL_NOTIFICATION_PERSISTENT_BOOL: typing.ClassVar[str] = ...
    KEY_VOICE_PRIVACY_DISABLE_UI_BOOL: typing.ClassVar[str] = ...
    KEY_VOLTE_REPLACEMENT_RAT_INT: typing.ClassVar[str] = ...
    KEY_VONR_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_VONR_ON_BY_DEFAULT_BOOL: typing.ClassVar[str] = ...
    KEY_VONR_SETTING_VISIBILITY_BOOL: typing.ClassVar[str] = ...
    KEY_VT_UPGRADE_SUPPORTED_FOR_DOWNGRADED_RTT_CALL_BOOL: typing.ClassVar[str] = ...
    KEY_VVM_CELLULAR_DATA_REQUIRED_BOOL: typing.ClassVar[str] = ...
    KEY_VVM_CLIENT_PREFIX_STRING: typing.ClassVar[str] = ...
    KEY_VVM_DESTINATION_NUMBER_STRING: typing.ClassVar[str] = ...
    KEY_VVM_DISABLED_CAPABILITIES_STRING_ARRAY: typing.ClassVar[str] = ...
    KEY_VVM_LEGACY_MODE_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_VVM_PORT_NUMBER_INT: typing.ClassVar[str] = ...
    KEY_VVM_PREFETCH_BOOL: typing.ClassVar[str] = ...
    KEY_VVM_SSL_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_VVM_TYPE_STRING: typing.ClassVar[str] = ...
    KEY_WFC_EMERGENCY_ADDRESS_CARRIER_APP_STRING: typing.ClassVar[str] = ...
    KEY_WORLD_MODE_ENABLED_BOOL: typing.ClassVar[str] = ...
    KEY_WORLD_PHONE_BOOL: typing.ClassVar[str] = ...
    REMOVE_GROUP_UUID_STRING: typing.ClassVar[str] = ...
    SERVICE_CLASS_NONE: typing.ClassVar[int] = ...
    SERVICE_CLASS_VOICE: typing.ClassVar[int] = ...
    USSD_OVER_CS_ONLY: typing.ClassVar[int] = ...
    USSD_OVER_CS_PREFERRED: typing.ClassVar[int] = ...
    USSD_OVER_IMS_ONLY: typing.ClassVar[int] = ...
    USSD_OVER_IMS_PREFERRED: typing.ClassVar[int] = ...
    @typing.overload
    def getConfig(self) -> android.os.PersistableBundle | None: ...
    @typing.overload
    def getConfig(self, *keys: java.lang.String) -> android.os.PersistableBundle | None: ...
    def getConfigByComponentForSubId(self, prefix: str | java.lang.String, subId: int | java.jint | java.lang.Integer, /) -> android.os.PersistableBundle | None: ...
    @typing.overload
    def getConfigForSubId(self, subId: int | java.jint | java.lang.Integer, /) -> android.os.PersistableBundle | None: ...
    @typing.overload
    def getConfigForSubId(self, subId: int | java.jint | java.lang.Integer, /, *keys: java.lang.String) -> android.os.PersistableBundle | None: ...
    @staticmethod
    def isConfigForIdentifiedCarrier(bundle: android.os.PersistableBundle, /) -> bool: ...
    def notifyConfigChangedForSubId(self, subId: int | java.jint | java.lang.Integer, /) -> None: ...
    def registerCarrierConfigChangeListener(self, executor: java.util.concurrent.Executor, listener: CarrierConfigManager.CarrierConfigChangeListener, /) -> None: ...
    def unregisterCarrierConfigChangeListener(self, listener: CarrierConfigManager.CarrierConfigChangeListener, /) -> None: ...

    class Iwlan(java.lang.Object):
        AUTHENTICATION_METHOD_CERT: typing.ClassVar[int] = ...
        AUTHENTICATION_METHOD_EAP_ONLY: typing.ClassVar[int] = ...
        EPDG_ADDRESS_CELLULAR_LOC: typing.ClassVar[int] = ...
        EPDG_ADDRESS_IPV4_ONLY: typing.ClassVar[int] = ...
        EPDG_ADDRESS_IPV4_PREFERRED: typing.ClassVar[int] = ...
        EPDG_ADDRESS_IPV6_PREFERRED: typing.ClassVar[int] = ...
        EPDG_ADDRESS_PCO: typing.ClassVar[int] = ...
        EPDG_ADDRESS_PLMN: typing.ClassVar[int] = ...
        EPDG_ADDRESS_STATIC: typing.ClassVar[int] = ...
        EPDG_ADDRESS_VISITED_COUNTRY: typing.ClassVar[int] = ...
        ID_TYPE_FQDN: typing.ClassVar[int] = ...
        ID_TYPE_KEY_ID: typing.ClassVar[int] = ...
        ID_TYPE_RFC822_ADDR: typing.ClassVar[int] = ...
        KEY_ADD_KE_TO_CHILD_SESSION_REKEY_BOOL: typing.ClassVar[str] = ...
        KEY_CHILD_SA_REKEY_HARD_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_CHILD_SA_REKEY_SOFT_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_CHILD_SESSION_AES_CBC_KEY_SIZE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CHILD_SESSION_AES_CTR_KEY_SIZE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CHILD_SESSION_AES_GCM_KEY_SIZE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_DIFFIE_HELLMAN_GROUPS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_DPD_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_EPDG_ADDRESS_IP_TYPE_PREFERENCE_INT: typing.ClassVar[str] = ...
        KEY_EPDG_ADDRESS_PRIORITY_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EPDG_AUTHENTICATION_METHOD_INT: typing.ClassVar[str] = ...
        KEY_EPDG_PCO_ID_IPV4_INT: typing.ClassVar[str] = ...
        KEY_EPDG_PCO_ID_IPV6_INT: typing.ClassVar[str] = ...
        KEY_EPDG_STATIC_ADDRESS_ROAMING_STRING: typing.ClassVar[str] = ...
        KEY_EPDG_STATIC_ADDRESS_STRING: typing.ClassVar[str] = ...
        KEY_IKE_LOCAL_ID_TYPE_INT: typing.ClassVar[str] = ...
        KEY_IKE_REKEY_HARD_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_IKE_REKEY_SOFT_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_IKE_REMOTE_ID_TYPE_INT: typing.ClassVar[str] = ...
        KEY_IKE_SESSION_AES_CBC_KEY_SIZE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_IKE_SESSION_AES_CTR_KEY_SIZE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_IKE_SESSION_AES_GCM_KEY_SIZE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_MAX_RETRIES_INT: typing.ClassVar[str] = ...
        KEY_MCC_MNCS_STRING_ARRAY: typing.ClassVar[str] = ...
        KEY_NATT_KEEP_ALIVE_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_RETRANSMIT_TIMER_MSEC_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SUPPORTED_CHILD_SESSION_AEAD_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SUPPORTED_CHILD_SESSION_ENCRYPTION_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SUPPORTED_IKE_SESSION_AEAD_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SUPPORTED_IKE_SESSION_ENCRYPTION_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SUPPORTED_INTEGRITY_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SUPPORTED_PRF_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SUPPORTS_CHILD_SESSION_MULTIPLE_SA_PROPOSALS_BOOL: typing.ClassVar[str] = ...
        KEY_SUPPORTS_EAP_AKA_FAST_REAUTH_BOOL: typing.ClassVar[str] = ...
        KEY_SUPPORTS_IKE_SESSION_MULTIPLE_SA_PROPOSALS_BOOL: typing.ClassVar[str] = ...

    class ImsWfc(java.lang.Object):
        KEY_EMERGENCY_CALL_OVER_EMERGENCY_PDN_BOOL: typing.ClassVar[str] = ...
        KEY_PIDF_SHORT_CODE_STRING_ARRAY: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...

    class ImsVt(java.lang.Object):
        KEY_H264_PAYLOAD_DESCRIPTION_BUNDLE: typing.ClassVar[str] = ...
        KEY_H264_PAYLOAD_TYPE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_H264_VIDEO_CODEC_ATTRIBUTE_PROFILE_LEVEL_ID_STRING: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_VIDEO_AS_BANDWIDTH_KBPS_INT: typing.ClassVar[str] = ...
        KEY_VIDEO_CODEC_ATTRIBUTE_FRAME_RATE_INT: typing.ClassVar[str] = ...
        KEY_VIDEO_CODEC_ATTRIBUTE_PACKETIZATION_MODE_INT: typing.ClassVar[str] = ...
        KEY_VIDEO_CODEC_ATTRIBUTE_RESOLUTION_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_VIDEO_CODEC_CAPABILITY_PAYLOAD_TYPES_BUNDLE: typing.ClassVar[str] = ...
        KEY_VIDEO_ON_DEFAULT_BEARER_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_VIDEO_QOS_PRECONDITION_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_VIDEO_RR_BANDWIDTH_BPS_INT: typing.ClassVar[str] = ...
        KEY_VIDEO_RS_BANDWIDTH_BPS_INT: typing.ClassVar[str] = ...
        KEY_VIDEO_RTCP_INACTIVITY_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_VIDEO_RTP_DSCP_INT: typing.ClassVar[str] = ...
        KEY_VIDEO_RTP_INACTIVITY_TIMER_MILLIS_INT: typing.ClassVar[str] = ...

    class ImsVoice(java.lang.Object):
        ALERTING_SRVCC_SUPPORT: typing.ClassVar[int] = ...
        BANDWIDTH_EFFICIENT: typing.ClassVar[int] = ...
        BASIC_SRVCC_SUPPORT: typing.ClassVar[int] = ...
        CONFERENCE_SUBSCRIBE_TYPE_IN_DIALOG: typing.ClassVar[int] = ...
        CONFERENCE_SUBSCRIBE_TYPE_OUT_OF_DIALOG: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_FB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_NB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_NB_WB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_NB_WB_SWB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_NB_WB_SWB_FB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_SWB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_WB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_WB_SWB: typing.ClassVar[int] = ...
        EVS_ENCODED_BW_TYPE_WB_SWB_FB: typing.ClassVar[int] = ...
        EVS_OPERATIONAL_MODE_AMRWB_IO: typing.ClassVar[int] = ...
        EVS_OPERATIONAL_MODE_PRIMARY: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_128_0_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_13_2_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_16_4_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_24_4_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_32_0_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_48_0_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_5_9_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_64_0_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_7_2_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_8_0_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_96_0_KBPS: typing.ClassVar[int] = ...
        EVS_PRIMARY_MODE_BITRATE_9_6_KBPS: typing.ClassVar[int] = ...
        KEY_AMRNB_PAYLOAD_DESCRIPTION_BUNDLE: typing.ClassVar[str] = ...
        KEY_AMRNB_PAYLOAD_TYPE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_AMRWB_PAYLOAD_DESCRIPTION_BUNDLE: typing.ClassVar[str] = ...
        KEY_AMRWB_PAYLOAD_TYPE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_AMR_CODEC_ATTRIBUTE_MODESET_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_AMR_CODEC_ATTRIBUTE_PAYLOAD_FORMAT_INT: typing.ClassVar[str] = ...
        KEY_AUDIO_AS_BANDWIDTH_KBPS_INT: typing.ClassVar[str] = ...
        KEY_AUDIO_CODEC_CAPABILITY_PAYLOAD_TYPES_BUNDLE: typing.ClassVar[str] = ...
        KEY_AUDIO_INACTIVITY_CALL_END_REASONS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_AUDIO_RR_BANDWIDTH_BPS_INT: typing.ClassVar[str] = ...
        KEY_AUDIO_RS_BANDWIDTH_BPS_INT: typing.ClassVar[str] = ...
        KEY_AUDIO_RTCP_INACTIVITY_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_AUDIO_RTP_INACTIVITY_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_CARRIER_VOLTE_ROAMING_AVAILABLE_BOOL: typing.ClassVar[str] = ...
        KEY_CODEC_ATTRIBUTE_MODE_CHANGE_CAPABILITY_INT: typing.ClassVar[str] = ...
        KEY_CODEC_ATTRIBUTE_MODE_CHANGE_NEIGHBOR_INT: typing.ClassVar[str] = ...
        KEY_CODEC_ATTRIBUTE_MODE_CHANGE_PERIOD_INT: typing.ClassVar[str] = ...
        KEY_CONFERENCE_FACTORY_URI_STRING: typing.ClassVar[str] = ...
        KEY_CONFERENCE_SUBSCRIBE_TYPE_INT: typing.ClassVar[str] = ...
        KEY_DEDICATED_BEARER_WAIT_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_DTMFNB_PAYLOAD_TYPE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_DTMFWB_PAYLOAD_TYPE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_BANDWIDTH_INT: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_BITRATE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_CHANNELS_INT: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_CH_AW_RECV_INT: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_CMR_INT: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_DTX_BOOL: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_DTX_RECV_BOOL: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_HF_ONLY_INT: typing.ClassVar[str] = ...
        KEY_EVS_CODEC_ATTRIBUTE_MODE_SWITCH_INT: typing.ClassVar[str] = ...
        KEY_EVS_PAYLOAD_DESCRIPTION_BUNDLE: typing.ClassVar[str] = ...
        KEY_EVS_PAYLOAD_TYPE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_INCLUDE_CALLER_ID_SERVICE_CODES_IN_SIP_INVITE_BOOL: typing.ClassVar[str] = ...
        KEY_MINIMUM_SESSION_EXPIRES_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_MO_CALL_REQUEST_TIMEOUT_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_MULTIENDPOINT_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_OIP_SOURCE_FROM_HEADER_BOOL: typing.ClassVar[str] = ...
        KEY_PRACK_SUPPORTED_FOR_18X_BOOL: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_RINGBACK_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_RINGING_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SESSION_EXPIRES_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_SESSION_PRIVACY_TYPE_INT: typing.ClassVar[str] = ...
        KEY_SESSION_REFRESHER_TYPE_INT: typing.ClassVar[str] = ...
        KEY_SESSION_REFRESH_METHOD_INT: typing.ClassVar[str] = ...
        KEY_SESSION_TIMER_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_SRVCC_TYPE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_VOICE_ON_DEFAULT_BEARER_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_VOICE_QOS_PRECONDITION_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        MIDCALL_SRVCC_SUPPORT: typing.ClassVar[int] = ...
        OCTET_ALIGNED: typing.ClassVar[int] = ...
        PREALERTING_SRVCC_SUPPORT: typing.ClassVar[int] = ...
        SESSION_PRIVACY_TYPE_HEADER: typing.ClassVar[int] = ...
        SESSION_PRIVACY_TYPE_ID: typing.ClassVar[int] = ...
        SESSION_PRIVACY_TYPE_NONE: typing.ClassVar[int] = ...
        SESSION_REFRESHER_TYPE_UAC: typing.ClassVar[int] = ...
        SESSION_REFRESHER_TYPE_UAS: typing.ClassVar[int] = ...
        SESSION_REFRESHER_TYPE_UNKNOWN: typing.ClassVar[int] = ...
        SESSION_REFRESH_METHOD_INVITE: typing.ClassVar[int] = ...
        SESSION_REFRESH_METHOD_UPDATE_PREFERRED: typing.ClassVar[int] = ...

    class ImsSs(java.lang.Object):
        CALL_WAITING_SYNC_FIRST_CHANGE: typing.ClassVar[int] = ...
        CALL_WAITING_SYNC_FIRST_POWER_UP: typing.ClassVar[int] = ...
        CALL_WAITING_SYNC_IMS_ONLY: typing.ClassVar[int] = ...
        CALL_WAITING_SYNC_NONE: typing.ClassVar[int] = ...
        CALL_WAITING_SYNC_USER_CHANGE: typing.ClassVar[int] = ...
        KEY_NETWORK_INITIATED_USSD_OVER_IMS_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_TERMINAL_BASED_CALL_WAITING_DEFAULT_ENABLED_BOOL: typing.ClassVar[str] = ...
        KEY_TERMINAL_BASED_CALL_WAITING_SYNC_TYPE_INT: typing.ClassVar[str] = ...
        KEY_USE_CSFB_ON_XCAP_OVER_UT_FAILURE_BOOL: typing.ClassVar[str] = ...
        KEY_UT_AS_SERVER_FQDN_STRING: typing.ClassVar[str] = ...
        KEY_UT_AS_SERVER_PORT_INT: typing.ClassVar[str] = ...
        KEY_UT_IPTYPE_HOME_INT: typing.ClassVar[str] = ...
        KEY_UT_IPTYPE_ROAMING_INT: typing.ClassVar[str] = ...
        KEY_UT_REQUIRES_IMS_REGISTRATION_BOOL: typing.ClassVar[str] = ...
        KEY_UT_SERVER_BASED_SERVICES_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_UT_SUPPORTED_WHEN_PS_DATA_OFF_BOOL: typing.ClassVar[str] = ...
        KEY_UT_SUPPORTED_WHEN_ROAMING_BOOL: typing.ClassVar[str] = ...
        KEY_UT_TERMINAL_BASED_SERVICES_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_UT_TRANSPORT_TYPE_INT: typing.ClassVar[str] = ...
        KEY_XCAP_OVER_UT_SUPPORTED_RATS_INT_ARRAY: typing.ClassVar[str] = ...
        SUPPLEMENTARY_SERVICE_CB_ACR: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_ALL: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_BAIC: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_BAOC: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_BIC_ROAM: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_BIL: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_BOIC: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_BOIC_EXHC: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_IBS: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CB_OBS: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CF_ALL: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CF_ALL_CONDITONAL_FORWARDING: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CF_CFB: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CF_CFNL: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CF_CFNRC: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CF_CFNRY: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CF_CFU: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_CW: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_IDENTIFICATION_OIP: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_IDENTIFICATION_OIR: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_IDENTIFICATION_TIP: typing.ClassVar[int] = ...
        SUPPLEMENTARY_SERVICE_IDENTIFICATION_TIR: typing.ClassVar[int] = ...

    class ImsSms(java.lang.Object):
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_SMS_CSFB_RETRY_ON_FAILURE_BOOL: typing.ClassVar[str] = ...
        KEY_SMS_MAX_RETRY_COUNT_INT: typing.ClassVar[str] = ...
        KEY_SMS_MAX_RETRY_OVER_IMS_COUNT_INT: typing.ClassVar[str] = ...
        KEY_SMS_OVER_IMS_FORMAT_INT: typing.ClassVar[str] = ...
        KEY_SMS_OVER_IMS_SEND_RETRY_DELAY_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SMS_OVER_IMS_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_SMS_OVER_IMS_SUPPORTED_RATS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SMS_RP_CAUSE_VALUES_TO_FALLBACK_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SMS_RP_CAUSE_VALUES_TO_RETRY_OVER_IMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_SMS_TR1_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SMS_TR2_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        SMS_FORMAT_3GPP2: typing.ClassVar[int] = ...
        SMS_FORMAT_3GPP: typing.ClassVar[int] = ...

    class ImsServiceEntitlement(java.lang.Object):
        KEY_ENTITLEMENT_SERVER_URL_STRING: typing.ClassVar[str] = ...
        KEY_FCM_SENDER_ID_STRING: typing.ClassVar[str] = ...
        KEY_IMS_PROVISIONING_BOOL: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_SHOW_VOWIFI_WEBVIEW_BOOL: typing.ClassVar[str] = ...

    class ImsRtt(java.lang.Object):
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_RED_PAYLOAD_TYPE_INT: typing.ClassVar[str] = ...
        KEY_T140_PAYLOAD_TYPE_INT: typing.ClassVar[str] = ...
        KEY_TEXT_AS_BANDWIDTH_KBPS_INT: typing.ClassVar[str] = ...
        KEY_TEXT_CODEC_CAPABILITY_PAYLOAD_TYPES_BUNDLE: typing.ClassVar[str] = ...
        KEY_TEXT_ON_DEFAULT_BEARER_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_TEXT_QOS_PRECONDITION_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_TEXT_RR_BANDWIDTH_BPS_INT: typing.ClassVar[str] = ...
        KEY_TEXT_RS_BANDWIDTH_BPS_INT: typing.ClassVar[str] = ...

    class ImsEmergency(java.lang.Object):
        DOMAIN_CS: typing.ClassVar[int] = ...
        DOMAIN_PS_3GPP: typing.ClassVar[int] = ...
        DOMAIN_PS_NON_3GPP: typing.ClassVar[int] = ...
        KEY_CROSS_STACK_REDIAL_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_EMERGENCY_CALLBACK_MODE_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_EMERGENCY_CALL_SETUP_TIMER_ON_CURRENT_NETWORK_SEC_INT: typing.ClassVar[str] = ...
        KEY_EMERGENCY_CDMA_PREFERRED_NUMBERS_STRING_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_DOMAIN_PREFERENCE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_DOMAIN_PREFERENCE_ROAMING_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_LTE_PREFERRED_AFTER_NR_FAILED_BOOL: typing.ClassVar[str] = ...
        KEY_EMERGENCY_NETWORK_SCAN_TYPE_INT: typing.ClassVar[str] = ...
        KEY_EMERGENCY_OVER_CS_ROAMING_SUPPORTED_ACCESS_NETWORK_TYPES_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_OVER_CS_SUPPORTED_ACCESS_NETWORK_TYPES_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_OVER_IMS_ROAMING_SUPPORTED_3GPP_NETWORK_TYPES_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_OVER_IMS_SUPPORTED_3GPP_NETWORK_TYPES_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_OVER_IMS_SUPPORTED_RATS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_EMERGENCY_QOS_PRECONDITION_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_EMERGENCY_REGISTRATION_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_EMERGENCY_REQUIRES_IMS_REGISTRATION_BOOL: typing.ClassVar[str] = ...
        KEY_EMERGENCY_REQUIRES_VOLTE_ENABLED_BOOL: typing.ClassVar[str] = ...
        KEY_EMERGENCY_SCAN_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_EMERGENCY_VOWIFI_REQUIRES_CONDITION_INT: typing.ClassVar[str] = ...
        KEY_MAXIMUM_CELLULAR_SEARCH_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_MAXIMUM_NUMBER_OF_EMERGENCY_TRIES_OVER_VOWIFI_INT: typing.ClassVar[str] = ...
        KEY_PREFER_IMS_EMERGENCY_WHEN_VOICE_CALLS_ON_CS_BOOL: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_QUICK_CROSS_STACK_REDIAL_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_REFRESH_GEOLOCATION_TIMEOUT_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_RETRY_EMERGENCY_ON_IMS_PDN_BOOL: typing.ClassVar[str] = ...
        KEY_SCAN_LIMITED_SERVICE_AFTER_VOLTE_FAILURE_BOOL: typing.ClassVar[str] = ...
        KEY_START_QUICK_CROSS_STACK_REDIAL_TIMER_WHEN_REGISTERED_BOOL: typing.ClassVar[str] = ...
        REDIAL_TIMER_DISABLED: typing.ClassVar[int] = ...
        SCAN_TYPE_FULL_SERVICE: typing.ClassVar[int] = ...
        SCAN_TYPE_FULL_SERVICE_FOLLOWED_BY_LIMITED_SERVICE: typing.ClassVar[int] = ...
        SCAN_TYPE_NO_PREFERENCE: typing.ClassVar[int] = ...
        VOWIFI_REQUIRES_NONE: typing.ClassVar[int] = ...
        VOWIFI_REQUIRES_SETTING_ENABLED: typing.ClassVar[int] = ...
        VOWIFI_REQUIRES_VALID_EID: typing.ClassVar[int] = ...

    class Ims(java.lang.Object):
        E911_RTCP_INACTIVITY_ON_CONNECTED: typing.ClassVar[int] = ...
        E911_RTP_INACTIVITY_ON_CONNECTED: typing.ClassVar[int] = ...
        GEOLOCATION_PIDF_FOR_EMERGENCY_ON_CELLULAR: typing.ClassVar[int] = ...
        GEOLOCATION_PIDF_FOR_EMERGENCY_ON_WIFI: typing.ClassVar[int] = ...
        GEOLOCATION_PIDF_FOR_NON_EMERGENCY_ON_CELLULAR: typing.ClassVar[int] = ...
        GEOLOCATION_PIDF_FOR_NON_EMERGENCY_ON_WIFI: typing.ClassVar[int] = ...
        IPSEC_AUTHENTICATION_ALGORITHM_HMAC_MD5: typing.ClassVar[int] = ...
        IPSEC_AUTHENTICATION_ALGORITHM_HMAC_SHA1: typing.ClassVar[int] = ...
        IPSEC_ENCRYPTION_ALGORITHM_AES_CBC: typing.ClassVar[int] = ...
        IPSEC_ENCRYPTION_ALGORITHM_DES_EDE3_CBC: typing.ClassVar[int] = ...
        IPSEC_ENCRYPTION_ALGORITHM_NULL: typing.ClassVar[int] = ...
        KEY_CAPABILITY_TYPE_CALL_COMPOSER_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CAPABILITY_TYPE_OPTIONS_UCE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CAPABILITY_TYPE_PRESENCE_UCE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CAPABILITY_TYPE_SMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CAPABILITY_TYPE_UT_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CAPABILITY_TYPE_VIDEO_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_CAPABILITY_TYPE_VOICE_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_ENABLE_PRESENCE_CAPABILITY_EXCHANGE_BOOL: typing.ClassVar[str] = ...
        KEY_ENABLE_PRESENCE_GROUP_SUBSCRIBE_BOOL: typing.ClassVar[str] = ...
        KEY_ENABLE_PRESENCE_PUBLISH_BOOL: typing.ClassVar[str] = ...
        KEY_GEOLOCATION_PIDF_IN_SIP_INVITE_SUPPORT_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_GEOLOCATION_PIDF_IN_SIP_REGISTER_SUPPORT_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_GRUU_ENABLED_BOOL: typing.ClassVar[str] = ...
        KEY_IMS_PDN_ENABLED_IN_NO_VOPS_SUPPORT_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_IMS_SINGLE_REGISTRATION_REQUIRED_BOOL: typing.ClassVar[str] = ...
        KEY_IMS_USER_AGENT_STRING: typing.ClassVar[str] = ...
        KEY_IPSEC_AUTHENTICATION_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_IPSEC_ENCRYPTION_ALGORITHMS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_IPV4_SIP_MTU_SIZE_CELLULAR_INT: typing.ClassVar[str] = ...
        KEY_IPV6_SIP_MTU_SIZE_CELLULAR_INT: typing.ClassVar[str] = ...
        KEY_KEEP_PDN_UP_IN_NO_VOPS_BOOL: typing.ClassVar[str] = ...
        KEY_MMTEL_REQUIRES_PROVISIONING_BUNDLE: typing.ClassVar[str] = ...
        KEY_NON_RCS_CAPABILITIES_CACHE_EXPIRATION_SEC_INT: typing.ClassVar[str] = ...
        KEY_PHONE_CONTEXT_DOMAIN_NAME_STRING: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_RCS_BULK_CAPABILITY_EXCHANGE_BOOL: typing.ClassVar[str] = ...
        KEY_RCS_FEATURE_TAG_ALLOWED_STRING_ARRAY: typing.ClassVar[str] = ...
        KEY_RCS_REQUIRES_PROVISIONING_BUNDLE: typing.ClassVar[str] = ...
        KEY_REGISTRATION_EVENT_PACKAGE_SUPPORTED_BOOL: typing.ClassVar[str] = ...
        KEY_REGISTRATION_EXPIRY_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_REGISTRATION_RETRY_BASE_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_REGISTRATION_RETRY_MAX_TIMER_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_REGISTRATION_SUBSCRIBE_EXPIRY_TIMER_SEC_INT: typing.ClassVar[str] = ...
        KEY_REQUEST_URI_TYPE_INT: typing.ClassVar[str] = ...
        KEY_SIP_OVER_IPSEC_ENABLED_BOOL: typing.ClassVar[str] = ...
        KEY_SIP_PREFERRED_TRANSPORT_INT: typing.ClassVar[str] = ...
        KEY_SIP_SERVER_PORT_NUMBER_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_B_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_C_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_D_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_F_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_H_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_J_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_T1_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_T2_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SIP_TIMER_T4_MILLIS_INT: typing.ClassVar[str] = ...
        KEY_SUPPORTED_RATS_INT_ARRAY: typing.ClassVar[str] = ...
        KEY_USE_SIP_URI_FOR_PRESENCE_SUBSCRIBE_BOOL: typing.ClassVar[str] = ...
        KEY_WIFI_OFF_DEFERRING_TIME_MILLIS_INT: typing.ClassVar[str] = ...
        NETWORK_TYPE_HOME: typing.ClassVar[int] = ...
        NETWORK_TYPE_ROAMING: typing.ClassVar[int] = ...
        PREFERRED_TRANSPORT_DYNAMIC_UDP_TCP: typing.ClassVar[int] = ...
        PREFERRED_TRANSPORT_TCP: typing.ClassVar[int] = ...
        PREFERRED_TRANSPORT_TLS: typing.ClassVar[int] = ...
        PREFERRED_TRANSPORT_UDP: typing.ClassVar[int] = ...
        REQUEST_URI_FORMAT_SIP: typing.ClassVar[int] = ...
        REQUEST_URI_FORMAT_TEL: typing.ClassVar[int] = ...
        RTCP_INACTIVITY_ON_CONNECTED: typing.ClassVar[int] = ...
        RTCP_INACTIVITY_ON_HOLD: typing.ClassVar[int] = ...
        RTP_INACTIVITY_ON_CONNECTED: typing.ClassVar[int] = ...

    class Gps(java.lang.Object):
        KEY_ENABLE_NI_SUPL_MESSAGE_INJECTION_BOOL: typing.ClassVar[str] = ...
        KEY_PERSIST_LPP_MODE_BOOL: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...

    class CarrierConfigChangeListener(java.lang.Object):
        def onCarrierConfigChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

    class Bsf(java.lang.Object):
        KEY_BSF_SERVER_FQDN_STRING: typing.ClassVar[str] = ...
        KEY_BSF_SERVER_PORT_INT: typing.ClassVar[str] = ...
        KEY_BSF_TRANSPORT_TYPE_INT: typing.ClassVar[str] = ...
        KEY_PREFIX: typing.ClassVar[str] = ...

    class Apn(java.lang.Object):
        KEY_PREFIX: typing.ClassVar[str] = ...
        KEY_SETTINGS_DEFAULT_PROTOCOL_STRING: typing.ClassVar[str] = ...
        KEY_SETTINGS_DEFAULT_ROAMING_PROTOCOL_STRING: typing.ClassVar[str] = ...
        PROTOCOL_IPV4: typing.ClassVar[str] = ...
        PROTOCOL_IPV4V6: typing.ClassVar[str] = ...
        PROTOCOL_IPV6: typing.ClassVar[str] = ...

class CellIdentity(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellIdentity]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOperatorAlphaLong(self) -> java.lang.CharSequence | None: ...
    def getOperatorAlphaShort(self) -> java.lang.CharSequence | None: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, type: int | java.jint | java.lang.Integer, /) -> None: ...

class CellIdentityCdma(CellIdentity):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellIdentityCdma]] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBasestationId(self) -> int: ...
    def getLatitude(self) -> int: ...
    def getLongitude(self) -> int: ...
    def getNetworkId(self) -> int: ...
    def getSystemId(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellIdentityGsm(CellIdentity):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellIdentityGsm]] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdditionalPlmns(self) -> java.util.Set[java.lang.String]: ...
    def getArfcn(self) -> int: ...
    def getBsic(self) -> int: ...
    def getCid(self) -> int: ...
    def getLac(self) -> int: ...
    def getMcc(self) -> int: ...
    def getMccString(self) -> str | None: ...
    def getMnc(self) -> int: ...
    def getMncString(self) -> str | None: ...
    def getMobileNetworkOperator(self) -> str | None: ...
    def getPsc(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellIdentityLte(CellIdentity):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellIdentityLte]] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdditionalPlmns(self) -> java.util.Set[java.lang.String]: ...
    def getBands(self) -> java.chaquopy.JavaArrayJInt: ...
    def getBandwidth(self) -> int: ...
    def getCi(self) -> int: ...
    def getClosedSubscriberGroupInfo(self) -> ClosedSubscriberGroupInfo | None: ...
    def getEarfcn(self) -> int: ...
    def getMcc(self) -> int: ...
    def getMccString(self) -> str | None: ...
    def getMnc(self) -> int: ...
    def getMncString(self) -> str | None: ...
    def getMobileNetworkOperator(self) -> str | None: ...
    def getPci(self) -> int: ...
    def getTac(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellIdentityNr(CellIdentity):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellIdentityNr]] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdditionalPlmns(self) -> java.util.Set[java.lang.String]: ...
    def getBands(self) -> java.chaquopy.JavaArrayJInt: ...
    def getMccString(self) -> str | None: ...
    def getMncString(self) -> str | None: ...
    def getNci(self) -> int: ...
    def getNrarfcn(self) -> int: ...
    def getPci(self) -> int: ...
    def getTac(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, type: int | java.jint | java.lang.Integer, /) -> None: ...

class CellIdentityTdscdma(CellIdentity):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellIdentityTdscdma]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdditionalPlmns(self) -> java.util.Set[java.lang.String]: ...
    def getCid(self) -> int: ...
    def getClosedSubscriberGroupInfo(self) -> ClosedSubscriberGroupInfo | None: ...
    def getCpid(self) -> int: ...
    def getLac(self) -> int: ...
    def getMccString(self) -> str | None: ...
    def getMncString(self) -> str | None: ...
    def getMobileNetworkOperator(self) -> str | None: ...
    def getUarfcn(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellIdentityWcdma(CellIdentity):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellIdentityWcdma]] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdditionalPlmns(self) -> java.util.Set[java.lang.String]: ...
    def getCid(self) -> int: ...
    def getClosedSubscriberGroupInfo(self) -> ClosedSubscriberGroupInfo | None: ...
    def getLac(self) -> int: ...
    def getMcc(self) -> int: ...
    def getMccString(self) -> str | None: ...
    def getMnc(self) -> int: ...
    def getMncString(self) -> str | None: ...
    def getMobileNetworkOperator(self) -> str | None: ...
    def getPsc(self) -> int: ...
    def getUarfcn(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellInfo(android.os.Parcelable):
    CONNECTION_NONE: typing.ClassVar[int] = ...
    CONNECTION_PRIMARY_SERVING: typing.ClassVar[int] = ...
    CONNECTION_SECONDARY_SERVING: typing.ClassVar[int] = ...
    CONNECTION_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellInfo]] = ...
    UNAVAILABLE: typing.ClassVar[int] = ...
    UNAVAILABLE_LONG: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCellConnectionStatus(self) -> int: ...
    def getCellIdentity(self) -> CellIdentity: ...
    def getCellSignalStrength(self) -> CellSignalStrength: ...
    def getTimeStamp(self) -> int: ...
    def getTimestampMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def isRegistered(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, arg1: android.os.Parcel, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class CellInfoCdma(CellInfo, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellInfoCdma]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCellIdentity(self) -> CellIdentityCdma: ...
    def getCellSignalStrength(self) -> CellSignalStrengthCdma: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellInfoGsm(CellInfo, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellInfoGsm]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCellIdentity(self) -> CellIdentityGsm: ...
    def getCellSignalStrength(self) -> CellSignalStrengthGsm: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellInfoLte(CellInfo, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellInfoLte]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCellIdentity(self) -> CellIdentityLte: ...
    def getCellSignalStrength(self) -> CellSignalStrengthLte: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellInfoNr(CellInfo):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellInfoNr]] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCellIdentity(self) -> CellIdentity: ...
    def getCellSignalStrength(self) -> CellSignalStrength: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellInfoTdscdma(CellInfo, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellInfoTdscdma]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCellIdentity(self) -> CellIdentityTdscdma: ...
    def getCellSignalStrength(self) -> CellSignalStrengthTdscdma: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellInfoWcdma(CellInfo, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellInfoWcdma]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCellIdentity(self) -> CellIdentityWcdma: ...
    def getCellSignalStrength(self) -> CellSignalStrengthWcdma: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellLocation(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def getEmpty() -> CellLocation: ...
    @staticmethod
    def requestLocationUpdate() -> None: ...

class CellSignalStrength(java.lang.Object):
    SIGNAL_STRENGTH_GOOD: typing.ClassVar[int] = ...
    SIGNAL_STRENGTH_GREAT: typing.ClassVar[int] = ...
    SIGNAL_STRENGTH_MODERATE: typing.ClassVar[int] = ...
    SIGNAL_STRENGTH_NONE_OR_UNKNOWN: typing.ClassVar[int] = ...
    SIGNAL_STRENGTH_POOR: typing.ClassVar[int] = ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsuLevel(self) -> int: ...
    def getDbm(self) -> int: ...
    def getLevel(self) -> int: ...
    def hashCode(self) -> int: ...

class CellSignalStrengthCdma(android.os.Parcelable, CellSignalStrength):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellSignalStrengthCdma]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsuLevel(self) -> int: ...
    def getCdmaDbm(self) -> int: ...
    def getCdmaEcio(self) -> int: ...
    def getCdmaLevel(self) -> int: ...
    def getDbm(self) -> int: ...
    def getEvdoDbm(self) -> int: ...
    def getEvdoEcio(self) -> int: ...
    def getEvdoLevel(self) -> int: ...
    def getEvdoSnr(self) -> int: ...
    def getLevel(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellSignalStrengthGsm(android.os.Parcelable, CellSignalStrength):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellSignalStrengthGsm]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsuLevel(self) -> int: ...
    def getBitErrorRate(self) -> int: ...
    def getDbm(self) -> int: ...
    def getLevel(self) -> int: ...
    def getRssi(self) -> int: ...
    def getTimingAdvance(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellSignalStrengthLte(android.os.Parcelable, CellSignalStrength):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellSignalStrengthLte]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsuLevel(self) -> int: ...
    def getCqi(self) -> int: ...
    def getCqiTableIndex(self) -> int: ...
    def getDbm(self) -> int: ...
    def getLevel(self) -> int: ...
    def getRsrp(self) -> int: ...
    def getRsrq(self) -> int: ...
    def getRssi(self) -> int: ...
    def getRssnr(self) -> int: ...
    def getTimingAdvance(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellSignalStrengthNr(android.os.Parcelable, CellSignalStrength):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellSignalStrengthNr]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsuLevel(self) -> int: ...
    def getCsiCqiReport(self) -> java.util.List[java.lang.Integer]: ...
    def getCsiCqiTableIndex(self) -> int: ...
    def getCsiRsrp(self) -> int: ...
    def getCsiRsrq(self) -> int: ...
    def getCsiSinr(self) -> int: ...
    def getDbm(self) -> int: ...
    def getLevel(self) -> int: ...
    def getSsRsrp(self) -> int: ...
    def getSsRsrq(self) -> int: ...
    def getSsSinr(self) -> int: ...
    def getTimingAdvanceMicros(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellSignalStrengthTdscdma(android.os.Parcelable, CellSignalStrength):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellSignalStrengthTdscdma]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsuLevel(self) -> int: ...
    def getDbm(self) -> int: ...
    def getLevel(self) -> int: ...
    def getRscp(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CellSignalStrengthWcdma(android.os.Parcelable, CellSignalStrength):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CellSignalStrengthWcdma]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsuLevel(self) -> int: ...
    def getDbm(self) -> int: ...
    def getEcNo(self) -> int: ...
    def getLevel(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ClosedSubscriberGroupInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ClosedSubscriberGroupInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCsgIdentity(self) -> int: ...
    def getCsgIndicator(self) -> bool: ...
    def getHomeNodebName(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, type: int | java.jint | java.lang.Integer, /) -> None: ...

class DataFailCause(java.lang.Object):
    ACCESS_ATTEMPT_ALREADY_IN_PROGRESS: typing.ClassVar[int] = ...
    ACCESS_BLOCK: typing.ClassVar[int] = ...
    ACCESS_BLOCK_ALL: typing.ClassVar[int] = ...
    ACCESS_CLASS_DSAC_REJECTION: typing.ClassVar[int] = ...
    ACCESS_CONTROL_LIST_CHECK_FAILURE: typing.ClassVar[int] = ...
    ACTIVATION_REJECTED_BCM_VIOLATION: typing.ClassVar[int] = ...
    ACTIVATION_REJECT_GGSN: typing.ClassVar[int] = ...
    ACTIVATION_REJECT_UNSPECIFIED: typing.ClassVar[int] = ...
    ACTIVE_PDP_CONTEXT_MAX_NUMBER_REACHED: typing.ClassVar[int] = ...
    ALL_MATCHING_RULES_FAILED: typing.ClassVar[int] = ...
    APN_DISABLED: typing.ClassVar[int] = ...
    APN_DISALLOWED_ON_ROAMING: typing.ClassVar[int] = ...
    APN_MISMATCH: typing.ClassVar[int] = ...
    APN_PARAMETERS_CHANGED: typing.ClassVar[int] = ...
    APN_PENDING_HANDOVER: typing.ClassVar[int] = ...
    APN_TYPE_CONFLICT: typing.ClassVar[int] = ...
    AUTH_FAILURE_ON_EMERGENCY_CALL: typing.ClassVar[int] = ...
    BEARER_HANDLING_NOT_SUPPORTED: typing.ClassVar[int] = ...
    CALL_DISALLOWED_IN_ROAMING: typing.ClassVar[int] = ...
    CALL_PREEMPT_BY_EMERGENCY_APN: typing.ClassVar[int] = ...
    CANNOT_ENCODE_OTA_MESSAGE: typing.ClassVar[int] = ...
    CDMA_ALERT_STOP: typing.ClassVar[int] = ...
    CDMA_INCOMING_CALL: typing.ClassVar[int] = ...
    CDMA_INTERCEPT: typing.ClassVar[int] = ...
    CDMA_LOCK: typing.ClassVar[int] = ...
    CDMA_RELEASE_DUE_TO_SO_REJECTION: typing.ClassVar[int] = ...
    CDMA_REORDER: typing.ClassVar[int] = ...
    CDMA_RETRY_ORDER: typing.ClassVar[int] = ...
    CHANNEL_ACQUISITION_FAILURE: typing.ClassVar[int] = ...
    CLOSE_IN_PROGRESS: typing.ClassVar[int] = ...
    COLLISION_WITH_NETWORK_INITIATED_REQUEST: typing.ClassVar[int] = ...
    COMPANION_IFACE_IN_USE: typing.ClassVar[int] = ...
    CONCURRENT_SERVICES_INCOMPATIBLE: typing.ClassVar[int] = ...
    CONCURRENT_SERVICES_NOT_ALLOWED: typing.ClassVar[int] = ...
    CONCURRENT_SERVICE_NOT_SUPPORTED_BY_BASE_STATION: typing.ClassVar[int] = ...
    CONDITIONAL_IE_ERROR: typing.ClassVar[int] = ...
    CONGESTION: typing.ClassVar[int] = ...
    CONNECTION_RELEASED: typing.ClassVar[int] = ...
    CS_DOMAIN_NOT_AVAILABLE: typing.ClassVar[int] = ...
    CS_FALLBACK_CALL_ESTABLISHMENT_NOT_ALLOWED: typing.ClassVar[int] = ...
    DATA_PLAN_EXPIRED: typing.ClassVar[int] = ...
    DATA_ROAMING_SETTINGS_DISABLED: typing.ClassVar[int] = ...
    DATA_SETTINGS_DISABLED: typing.ClassVar[int] = ...
    DBM_OR_SMS_IN_PROGRESS: typing.ClassVar[int] = ...
    DDS_SWITCHED: typing.ClassVar[int] = ...
    DDS_SWITCH_IN_PROGRESS: typing.ClassVar[int] = ...
    DRB_RELEASED_BY_RRC: typing.ClassVar[int] = ...
    DS_EXPLICIT_DEACTIVATION: typing.ClassVar[int] = ...
    DUAL_SWITCH: typing.ClassVar[int] = ...
    DUN_CALL_DISALLOWED: typing.ClassVar[int] = ...
    DUPLICATE_BEARER_ID: typing.ClassVar[int] = ...
    EHRPD_TO_HRPD_FALLBACK: typing.ClassVar[int] = ...
    EMBMS_NOT_ENABLED: typing.ClassVar[int] = ...
    EMBMS_REGULAR_DEACTIVATION: typing.ClassVar[int] = ...
    EMERGENCY_IFACE_ONLY: typing.ClassVar[int] = ...
    EMERGENCY_MODE: typing.ClassVar[int] = ...
    EMM_ACCESS_BARRED: typing.ClassVar[int] = ...
    EMM_ACCESS_BARRED_INFINITE_RETRY: typing.ClassVar[int] = ...
    EMM_ATTACH_FAILED: typing.ClassVar[int] = ...
    EMM_ATTACH_STARTED: typing.ClassVar[int] = ...
    EMM_DETACHED: typing.ClassVar[int] = ...
    EMM_T3417_EXPIRED: typing.ClassVar[int] = ...
    EMM_T3417_EXT_EXPIRED: typing.ClassVar[int] = ...
    EPS_SERVICES_AND_NON_EPS_SERVICES_NOT_ALLOWED: typing.ClassVar[int] = ...
    EPS_SERVICES_NOT_ALLOWED_IN_PLMN: typing.ClassVar[int] = ...
    ERROR_UNSPECIFIED: typing.ClassVar[int] = ...
    ESM_BAD_OTA_MESSAGE: typing.ClassVar[int] = ...
    ESM_BEARER_DEACTIVATED_TO_SYNC_WITH_NETWORK: typing.ClassVar[int] = ...
    ESM_COLLISION_SCENARIOS: typing.ClassVar[int] = ...
    ESM_CONTEXT_TRANSFERRED_DUE_TO_IRAT: typing.ClassVar[int] = ...
    ESM_DOWNLOAD_SERVER_REJECTED_THE_CALL: typing.ClassVar[int] = ...
    ESM_FAILURE: typing.ClassVar[int] = ...
    ESM_INFO_NOT_RECEIVED: typing.ClassVar[int] = ...
    ESM_LOCAL_CAUSE_NONE: typing.ClassVar[int] = ...
    ESM_NW_ACTIVATED_DED_BEARER_WITH_ID_OF_DEF_BEARER: typing.ClassVar[int] = ...
    ESM_PROCEDURE_TIME_OUT: typing.ClassVar[int] = ...
    ESM_UNKNOWN_EPS_BEARER_CONTEXT: typing.ClassVar[int] = ...
    EVDO_CONNECTION_DENY_BY_BILLING_OR_AUTHENTICATION_FAILURE: typing.ClassVar[int] = ...
    EVDO_CONNECTION_DENY_BY_GENERAL_OR_NETWORK_BUSY: typing.ClassVar[int] = ...
    EVDO_HDR_CHANGED: typing.ClassVar[int] = ...
    EVDO_HDR_CONNECTION_SETUP_TIMEOUT: typing.ClassVar[int] = ...
    EVDO_HDR_EXITED: typing.ClassVar[int] = ...
    EVDO_HDR_NO_SESSION: typing.ClassVar[int] = ...
    EVDO_USING_GPS_FIX_INSTEAD_OF_HDR_CALL: typing.ClassVar[int] = ...
    FADE: typing.ClassVar[int] = ...
    FAILED_TO_ACQUIRE_COLOCATED_HDR: typing.ClassVar[int] = ...
    FEATURE_NOT_SUPP: typing.ClassVar[int] = ...
    FILTER_SEMANTIC_ERROR: typing.ClassVar[int] = ...
    FILTER_SYTAX_ERROR: typing.ClassVar[int] = ...
    FORBIDDEN_APN_NAME: typing.ClassVar[int] = ...
    GPRS_REGISTRATION_FAIL: typing.ClassVar[int] = ...
    GPRS_SERVICES_AND_NON_GPRS_SERVICES_NOT_ALLOWED: typing.ClassVar[int] = ...
    GPRS_SERVICES_NOT_ALLOWED: typing.ClassVar[int] = ...
    GPRS_SERVICES_NOT_ALLOWED_IN_THIS_PLMN: typing.ClassVar[int] = ...
    HANDOFF_PREFERENCE_CHANGED: typing.ClassVar[int] = ...
    HDR_ACCESS_FAILURE: typing.ClassVar[int] = ...
    HDR_FADE: typing.ClassVar[int] = ...
    HDR_NO_LOCK_GRANTED: typing.ClassVar[int] = ...
    IFACE_AND_POL_FAMILY_MISMATCH: typing.ClassVar[int] = ...
    IFACE_MISMATCH: typing.ClassVar[int] = ...
    ILLEGAL_ME: typing.ClassVar[int] = ...
    ILLEGAL_MS: typing.ClassVar[int] = ...
    IMEI_NOT_ACCEPTED: typing.ClassVar[int] = ...
    IMPLICITLY_DETACHED: typing.ClassVar[int] = ...
    IMSI_UNKNOWN_IN_HOME_SUBSCRIBER_SERVER: typing.ClassVar[int] = ...
    INCOMING_CALL_REJECTED: typing.ClassVar[int] = ...
    INSUFFICIENT_RESOURCES: typing.ClassVar[int] = ...
    INTERFACE_IN_USE: typing.ClassVar[int] = ...
    INTERNAL_CALL_PREEMPT_BY_HIGH_PRIO_APN: typing.ClassVar[int] = ...
    INTERNAL_EPC_NONEPC_TRANSITION: typing.ClassVar[int] = ...
    INVALID_CONNECTION_ID: typing.ClassVar[int] = ...
    INVALID_DNS_ADDR: typing.ClassVar[int] = ...
    INVALID_EMM_STATE: typing.ClassVar[int] = ...
    INVALID_MANDATORY_INFO: typing.ClassVar[int] = ...
    INVALID_MODE: typing.ClassVar[int] = ...
    INVALID_PCSCF_ADDR: typing.ClassVar[int] = ...
    INVALID_PCSCF_OR_DNS_ADDRESS: typing.ClassVar[int] = ...
    INVALID_PRIMARY_NSAPI: typing.ClassVar[int] = ...
    INVALID_SIM_STATE: typing.ClassVar[int] = ...
    INVALID_TRANSACTION_ID: typing.ClassVar[int] = ...
    IPV6_ADDRESS_TRANSFER_FAILED: typing.ClassVar[int] = ...
    IPV6_PREFIX_UNAVAILABLE: typing.ClassVar[int] = ...
    IP_ADDRESS_MISMATCH: typing.ClassVar[int] = ...
    IP_VERSION_MISMATCH: typing.ClassVar[int] = ...
    IRAT_HANDOVER_FAILED: typing.ClassVar[int] = ...
    IS707B_MAX_ACCESS_PROBES: typing.ClassVar[int] = ...
    IWLAN_AUTHORIZATION_REJECTED: typing.ClassVar[int] = ...
    IWLAN_CONGESTION: typing.ClassVar[int] = ...
    IWLAN_DNS_RESOLUTION_NAME_FAILURE: typing.ClassVar[int] = ...
    IWLAN_DNS_RESOLUTION_TIMEOUT: typing.ClassVar[int] = ...
    IWLAN_IKEV2_AUTH_FAILURE: typing.ClassVar[int] = ...
    IWLAN_IKEV2_CERT_INVALID: typing.ClassVar[int] = ...
    IWLAN_IKEV2_CONFIG_FAILURE: typing.ClassVar[int] = ...
    IWLAN_IKEV2_MSG_TIMEOUT: typing.ClassVar[int] = ...
    IWLAN_ILLEGAL_ME: typing.ClassVar[int] = ...
    IWLAN_IMEI_NOT_ACCEPTED: typing.ClassVar[int] = ...
    IWLAN_MAX_CONNECTION_REACHED: typing.ClassVar[int] = ...
    IWLAN_NETWORK_FAILURE: typing.ClassVar[int] = ...
    IWLAN_NON_3GPP_ACCESS_TO_EPC_NOT_ALLOWED: typing.ClassVar[int] = ...
    IWLAN_NO_APN_SUBSCRIPTION: typing.ClassVar[int] = ...
    IWLAN_PDN_CONNECTION_REJECTION: typing.ClassVar[int] = ...
    IWLAN_PLMN_NOT_ALLOWED: typing.ClassVar[int] = ...
    IWLAN_RAT_TYPE_NOT_ALLOWED: typing.ClassVar[int] = ...
    IWLAN_SEMANTIC_ERRORS_IN_PACKET_FILTERS: typing.ClassVar[int] = ...
    IWLAN_SEMANTIC_ERROR_IN_THE_TFT_OPERATION: typing.ClassVar[int] = ...
    IWLAN_SYNTACTICAL_ERRORS_IN_PACKET_FILTERS: typing.ClassVar[int] = ...
    IWLAN_SYNTACTICAL_ERROR_IN_THE_TFT_OPERATION: typing.ClassVar[int] = ...
    IWLAN_TUNNEL_NOT_FOUND: typing.ClassVar[int] = ...
    IWLAN_UNAUTHENTICATED_EMERGENCY_NOT_SUPPORTED: typing.ClassVar[int] = ...
    IWLAN_USER_UNKNOWN: typing.ClassVar[int] = ...
    LIMITED_TO_IPV4: typing.ClassVar[int] = ...
    LIMITED_TO_IPV6: typing.ClassVar[int] = ...
    LLC_SNDCP: typing.ClassVar[int] = ...
    LOCAL_END: typing.ClassVar[int] = ...
    LOCATION_AREA_NOT_ALLOWED: typing.ClassVar[int] = ...
    LOST_CONNECTION: typing.ClassVar[int] = ...
    LOWER_LAYER_REGISTRATION_FAILURE: typing.ClassVar[int] = ...
    LOW_POWER_MODE_OR_POWERING_DOWN: typing.ClassVar[int] = ...
    LTE_NAS_SERVICE_REQUEST_FAILED: typing.ClassVar[int] = ...
    LTE_THROTTLING_NOT_REQUIRED: typing.ClassVar[int] = ...
    MAC_FAILURE: typing.ClassVar[int] = ...
    MATCH_ALL_RULE_NOT_ALLOWED: typing.ClassVar[int] = ...
    MAXIMIUM_NSAPIS_EXCEEDED: typing.ClassVar[int] = ...
    MAXINUM_SIZE_OF_L2_MESSAGE_EXCEEDED: typing.ClassVar[int] = ...
    MAX_ACCESS_PROBE: typing.ClassVar[int] = ...
    MAX_IPV4_CONNECTIONS: typing.ClassVar[int] = ...
    MAX_IPV6_CONNECTIONS: typing.ClassVar[int] = ...
    MAX_PPP_INACTIVITY_TIMER_EXPIRED: typing.ClassVar[int] = ...
    MESSAGE_INCORRECT_SEMANTIC: typing.ClassVar[int] = ...
    MESSAGE_TYPE_UNSUPPORTED: typing.ClassVar[int] = ...
    MIP_CONFIG_FAILURE: typing.ClassVar[int] = ...
    MIP_FA_ADMIN_PROHIBITED: typing.ClassVar[int] = ...
    MIP_FA_DELIVERY_STYLE_NOT_SUPPORTED: typing.ClassVar[int] = ...
    MIP_FA_ENCAPSULATION_UNAVAILABLE: typing.ClassVar[int] = ...
    MIP_FA_HOME_AGENT_AUTHENTICATION_FAILURE: typing.ClassVar[int] = ...
    MIP_FA_INSUFFICIENT_RESOURCES: typing.ClassVar[int] = ...
    MIP_FA_MALFORMED_REPLY: typing.ClassVar[int] = ...
    MIP_FA_MALFORMED_REQUEST: typing.ClassVar[int] = ...
    MIP_FA_MISSING_CHALLENGE: typing.ClassVar[int] = ...
    MIP_FA_MISSING_HOME_ADDRESS: typing.ClassVar[int] = ...
    MIP_FA_MISSING_HOME_AGENT: typing.ClassVar[int] = ...
    MIP_FA_MISSING_NAI: typing.ClassVar[int] = ...
    MIP_FA_MOBILE_NODE_AUTHENTICATION_FAILURE: typing.ClassVar[int] = ...
    MIP_FA_REASON_UNSPECIFIED: typing.ClassVar[int] = ...
    MIP_FA_REQUESTED_LIFETIME_TOO_LONG: typing.ClassVar[int] = ...
    MIP_FA_REVERSE_TUNNEL_IS_MANDATORY: typing.ClassVar[int] = ...
    MIP_FA_REVERSE_TUNNEL_UNAVAILABLE: typing.ClassVar[int] = ...
    MIP_FA_STALE_CHALLENGE: typing.ClassVar[int] = ...
    MIP_FA_UNKNOWN_CHALLENGE: typing.ClassVar[int] = ...
    MIP_FA_VJ_HEADER_COMPRESSION_UNAVAILABLE: typing.ClassVar[int] = ...
    MIP_HA_ADMIN_PROHIBITED: typing.ClassVar[int] = ...
    MIP_HA_ENCAPSULATION_UNAVAILABLE: typing.ClassVar[int] = ...
    MIP_HA_FOREIGN_AGENT_AUTHENTICATION_FAILURE: typing.ClassVar[int] = ...
    MIP_HA_INSUFFICIENT_RESOURCES: typing.ClassVar[int] = ...
    MIP_HA_MALFORMED_REQUEST: typing.ClassVar[int] = ...
    MIP_HA_MOBILE_NODE_AUTHENTICATION_FAILURE: typing.ClassVar[int] = ...
    MIP_HA_REASON_UNSPECIFIED: typing.ClassVar[int] = ...
    MIP_HA_REGISTRATION_ID_MISMATCH: typing.ClassVar[int] = ...
    MIP_HA_REVERSE_TUNNEL_IS_MANDATORY: typing.ClassVar[int] = ...
    MIP_HA_REVERSE_TUNNEL_UNAVAILABLE: typing.ClassVar[int] = ...
    MIP_HA_UNKNOWN_HOME_AGENT_ADDRESS: typing.ClassVar[int] = ...
    MISSING_UNKNOWN_APN: typing.ClassVar[int] = ...
    MODEM_APP_PREEMPTED: typing.ClassVar[int] = ...
    MODEM_RESTART: typing.ClassVar[int] = ...
    MSC_TEMPORARILY_NOT_REACHABLE: typing.ClassVar[int] = ...
    MSG_AND_PROTOCOL_STATE_UNCOMPATIBLE: typing.ClassVar[int] = ...
    MSG_TYPE_NONCOMPATIBLE_STATE: typing.ClassVar[int] = ...
    MS_IDENTITY_CANNOT_BE_DERIVED_BY_THE_NETWORK: typing.ClassVar[int] = ...
    MULTIPLE_PDP_CALL_NOT_ALLOWED: typing.ClassVar[int] = ...
    MULTI_CONN_TO_SAME_PDN_NOT_ALLOWED: typing.ClassVar[int] = ...
    NAS_LAYER_FAILURE: typing.ClassVar[int] = ...
    NAS_REQUEST_REJECTED_BY_NETWORK: typing.ClassVar[int] = ...
    NAS_SIGNALLING: typing.ClassVar[int] = ...
    NETWORK_FAILURE: typing.ClassVar[int] = ...
    NETWORK_INITIATED_DETACH_NO_AUTO_REATTACH: typing.ClassVar[int] = ...
    NETWORK_INITIATED_DETACH_WITH_AUTO_REATTACH: typing.ClassVar[int] = ...
    NETWORK_INITIATED_TERMINATION: typing.ClassVar[int] = ...
    NONE: typing.ClassVar[int] = ...
    NON_IP_NOT_SUPPORTED: typing.ClassVar[int] = ...
    NORMAL_RELEASE: typing.ClassVar[int] = ...
    NO_CDMA_SERVICE: typing.ClassVar[int] = ...
    NO_COLLOCATED_HDR: typing.ClassVar[int] = ...
    NO_EPS_BEARER_CONTEXT_ACTIVATED: typing.ClassVar[int] = ...
    NO_GPRS_CONTEXT: typing.ClassVar[int] = ...
    NO_HYBRID_HDR_SERVICE: typing.ClassVar[int] = ...
    NO_PDP_CONTEXT_ACTIVATED: typing.ClassVar[int] = ...
    NO_RESPONSE_FROM_BASE_STATION: typing.ClassVar[int] = ...
    NO_SERVICE: typing.ClassVar[int] = ...
    NO_SERVICE_ON_GATEWAY: typing.ClassVar[int] = ...
    NSAPI_IN_USE: typing.ClassVar[int] = ...
    NULL_APN_DISALLOWED: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_10: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_11: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_12: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_13: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_14: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_15: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_1: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_2: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_3: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_4: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_5: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_6: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_7: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_8: typing.ClassVar[int] = ...
    OEM_DCFAILCAUSE_9: typing.ClassVar[int] = ...
    ONLY_IPV4V6_ALLOWED: typing.ClassVar[int] = ...
    ONLY_IPV4_ALLOWED: typing.ClassVar[int] = ...
    ONLY_IPV6_ALLOWED: typing.ClassVar[int] = ...
    ONLY_NON_IP_ALLOWED: typing.ClassVar[int] = ...
    ONLY_SINGLE_BEARER_ALLOWED: typing.ClassVar[int] = ...
    OPERATOR_BARRED: typing.ClassVar[int] = ...
    OTASP_COMMIT_IN_PROGRESS: typing.ClassVar[int] = ...
    PDN_CONN_DOES_NOT_EXIST: typing.ClassVar[int] = ...
    PDN_INACTIVITY_TIMER_EXPIRED: typing.ClassVar[int] = ...
    PDN_IPV4_CALL_DISALLOWED: typing.ClassVar[int] = ...
    PDN_IPV4_CALL_THROTTLED: typing.ClassVar[int] = ...
    PDN_IPV6_CALL_DISALLOWED: typing.ClassVar[int] = ...
    PDN_IPV6_CALL_THROTTLED: typing.ClassVar[int] = ...
    PDN_NON_IP_CALL_DISALLOWED: typing.ClassVar[int] = ...
    PDN_NON_IP_CALL_THROTTLED: typing.ClassVar[int] = ...
    PDP_ACTIVATE_MAX_RETRY_FAILED: typing.ClassVar[int] = ...
    PDP_DUPLICATE: typing.ClassVar[int] = ...
    PDP_ESTABLISH_TIMEOUT_EXPIRED: typing.ClassVar[int] = ...
    PDP_INACTIVE_TIMEOUT_EXPIRED: typing.ClassVar[int] = ...
    PDP_LOWERLAYER_ERROR: typing.ClassVar[int] = ...
    PDP_MODIFY_COLLISION: typing.ClassVar[int] = ...
    PDP_MODIFY_TIMEOUT_EXPIRED: typing.ClassVar[int] = ...
    PDP_PPP_NOT_SUPPORTED: typing.ClassVar[int] = ...
    PDP_WITHOUT_ACTIVE_TFT: typing.ClassVar[int] = ...
    PHONE_IN_USE: typing.ClassVar[int] = ...
    PHYSICAL_LINK_CLOSE_IN_PROGRESS: typing.ClassVar[int] = ...
    PLMN_NOT_ALLOWED: typing.ClassVar[int] = ...
    PPP_AUTH_FAILURE: typing.ClassVar[int] = ...
    PPP_CHAP_FAILURE: typing.ClassVar[int] = ...
    PPP_CLOSE_IN_PROGRESS: typing.ClassVar[int] = ...
    PPP_OPTION_MISMATCH: typing.ClassVar[int] = ...
    PPP_PAP_FAILURE: typing.ClassVar[int] = ...
    PPP_TIMEOUT: typing.ClassVar[int] = ...
    PREF_RADIO_TECH_CHANGED: typing.ClassVar[int] = ...
    PROFILE_BEARER_INCOMPATIBLE: typing.ClassVar[int] = ...
    PROTOCOL_ERRORS: typing.ClassVar[int] = ...
    QOS_NOT_ACCEPTED: typing.ClassVar[int] = ...
    RADIO_ACCESS_BEARER_FAILURE: typing.ClassVar[int] = ...
    RADIO_ACCESS_BEARER_SETUP_FAILURE: typing.ClassVar[int] = ...
    RADIO_NOT_AVAILABLE: typing.ClassVar[int] = ...
    RADIO_POWER_OFF: typing.ClassVar[int] = ...
    REDIRECTION_OR_HANDOFF_IN_PROGRESS: typing.ClassVar[int] = ...
    REGISTRATION_FAIL: typing.ClassVar[int] = ...
    REGULAR_DEACTIVATION: typing.ClassVar[int] = ...
    REJECTED_BY_BASE_STATION: typing.ClassVar[int] = ...
    RRC_CONNECTION_ABORTED_AFTER_HANDOVER: typing.ClassVar[int] = ...
    RRC_CONNECTION_ABORTED_AFTER_IRAT_CELL_CHANGE: typing.ClassVar[int] = ...
    RRC_CONNECTION_ABORTED_DUE_TO_IRAT_CHANGE: typing.ClassVar[int] = ...
    RRC_CONNECTION_ABORTED_DURING_IRAT_CELL_CHANGE: typing.ClassVar[int] = ...
    RRC_CONNECTION_ABORT_REQUEST: typing.ClassVar[int] = ...
    RRC_CONNECTION_ACCESS_BARRED: typing.ClassVar[int] = ...
    RRC_CONNECTION_ACCESS_STRATUM_FAILURE: typing.ClassVar[int] = ...
    RRC_CONNECTION_ANOTHER_PROCEDURE_IN_PROGRESS: typing.ClassVar[int] = ...
    RRC_CONNECTION_CELL_NOT_CAMPED: typing.ClassVar[int] = ...
    RRC_CONNECTION_CELL_RESELECTION: typing.ClassVar[int] = ...
    RRC_CONNECTION_CONFIG_FAILURE: typing.ClassVar[int] = ...
    RRC_CONNECTION_INVALID_REQUEST: typing.ClassVar[int] = ...
    RRC_CONNECTION_LINK_FAILURE: typing.ClassVar[int] = ...
    RRC_CONNECTION_NORMAL_RELEASE: typing.ClassVar[int] = ...
    RRC_CONNECTION_OUT_OF_SERVICE_DURING_CELL_REGISTER: typing.ClassVar[int] = ...
    RRC_CONNECTION_RADIO_LINK_FAILURE: typing.ClassVar[int] = ...
    RRC_CONNECTION_REESTABLISHMENT_FAILURE: typing.ClassVar[int] = ...
    RRC_CONNECTION_REJECT_BY_NETWORK: typing.ClassVar[int] = ...
    RRC_CONNECTION_RELEASED_SECURITY_NOT_ACTIVE: typing.ClassVar[int] = ...
    RRC_CONNECTION_RF_UNAVAILABLE: typing.ClassVar[int] = ...
    RRC_CONNECTION_SYSTEM_INFORMATION_BLOCK_READ_ERROR: typing.ClassVar[int] = ...
    RRC_CONNECTION_SYSTEM_INTERVAL_FAILURE: typing.ClassVar[int] = ...
    RRC_CONNECTION_TIMER_EXPIRED: typing.ClassVar[int] = ...
    RRC_CONNECTION_TRACKING_AREA_ID_CHANGED: typing.ClassVar[int] = ...
    RRC_UPLINK_CONNECTION_RELEASE: typing.ClassVar[int] = ...
    RRC_UPLINK_DATA_TRANSMISSION_FAILURE: typing.ClassVar[int] = ...
    RRC_UPLINK_DELIVERY_FAILED_DUE_TO_HANDOVER: typing.ClassVar[int] = ...
    RRC_UPLINK_ERROR_REQUEST_FROM_NAS: typing.ClassVar[int] = ...
    RRC_UPLINK_RADIO_LINK_FAILURE: typing.ClassVar[int] = ...
    RUIM_NOT_PRESENT: typing.ClassVar[int] = ...
    SECURITY_MODE_REJECTED: typing.ClassVar[int] = ...
    SERVICE_NOT_ALLOWED_ON_PLMN: typing.ClassVar[int] = ...
    SERVICE_OPTION_NOT_SUBSCRIBED: typing.ClassVar[int] = ...
    SERVICE_OPTION_NOT_SUPPORTED: typing.ClassVar[int] = ...
    SERVICE_OPTION_OUT_OF_ORDER: typing.ClassVar[int] = ...
    SIGNAL_LOST: typing.ClassVar[int] = ...
    SIM_CARD_CHANGED: typing.ClassVar[int] = ...
    SLICE_REJECTED: typing.ClassVar[int] = ...
    SYNCHRONIZATION_FAILURE: typing.ClassVar[int] = ...
    TEST_LOOPBACK_REGULAR_DEACTIVATION: typing.ClassVar[int] = ...
    TETHERED_CALL_ACTIVE: typing.ClassVar[int] = ...
    TFT_SEMANTIC_ERROR: typing.ClassVar[int] = ...
    TFT_SYTAX_ERROR: typing.ClassVar[int] = ...
    THERMAL_EMERGENCY: typing.ClassVar[int] = ...
    THERMAL_MITIGATION: typing.ClassVar[int] = ...
    TRAT_SWAP_FAILED: typing.ClassVar[int] = ...
    UE_INITIATED_DETACH_OR_DISCONNECT: typing.ClassVar[int] = ...
    UE_IS_ENTERING_POWERSAVE_MODE: typing.ClassVar[int] = ...
    UE_RAT_CHANGE: typing.ClassVar[int] = ...
    UE_SECURITY_CAPABILITIES_MISMATCH: typing.ClassVar[int] = ...
    UMTS_HANDOVER_TO_IWLAN: typing.ClassVar[int] = ...
    UMTS_REACTIVATION_REQ: typing.ClassVar[int] = ...
    UNACCEPTABLE_NETWORK_PARAMETER: typing.ClassVar[int] = ...
    UNACCEPTABLE_NON_EPS_AUTHENTICATION: typing.ClassVar[int] = ...
    UNKNOWN: typing.ClassVar[int] = ...
    UNKNOWN_INFO_ELEMENT: typing.ClassVar[int] = ...
    UNKNOWN_PDP_ADDRESS_TYPE: typing.ClassVar[int] = ...
    UNKNOWN_PDP_CONTEXT: typing.ClassVar[int] = ...
    UNPREFERRED_RAT: typing.ClassVar[int] = ...
    UNSUPPORTED_1X_PREV: typing.ClassVar[int] = ...
    UNSUPPORTED_APN_IN_CURRENT_PLMN: typing.ClassVar[int] = ...
    UNSUPPORTED_QCI_VALUE: typing.ClassVar[int] = ...
    USER_AUTHENTICATION: typing.ClassVar[int] = ...
    VSNCP_ADMINISTRATIVELY_PROHIBITED: typing.ClassVar[int] = ...
    VSNCP_APN_UNAUTHORIZED: typing.ClassVar[int] = ...
    VSNCP_GEN_ERROR: typing.ClassVar[int] = ...
    VSNCP_INSUFFICIENT_PARAMETERS: typing.ClassVar[int] = ...
    VSNCP_NO_PDN_GATEWAY_ADDRESS: typing.ClassVar[int] = ...
    VSNCP_PDN_EXISTS_FOR_THIS_APN: typing.ClassVar[int] = ...
    VSNCP_PDN_GATEWAY_REJECT: typing.ClassVar[int] = ...
    VSNCP_PDN_GATEWAY_UNREACHABLE: typing.ClassVar[int] = ...
    VSNCP_PDN_ID_IN_USE: typing.ClassVar[int] = ...
    VSNCP_PDN_LIMIT_EXCEEDED: typing.ClassVar[int] = ...
    VSNCP_RECONNECT_NOT_ALLOWED: typing.ClassVar[int] = ...
    VSNCP_RESOURCE_UNAVAILABLE: typing.ClassVar[int] = ...
    VSNCP_SUBSCRIBER_LIMITATION: typing.ClassVar[int] = ...
    VSNCP_TIMEOUT: typing.ClassVar[int] = ...

class DisconnectCause(java.lang.Object):
    ALREADY_DIALING: typing.ClassVar[int] = ...
    ANSWERED_ELSEWHERE: typing.ClassVar[int] = ...
    BUSY: typing.ClassVar[int] = ...
    CALLING_DISABLED: typing.ClassVar[int] = ...
    CALL_BARRED: typing.ClassVar[int] = ...
    CALL_PULLED: typing.ClassVar[int] = ...
    CANT_CALL_WHILE_RINGING: typing.ClassVar[int] = ...
    CDMA_ACCESS_BLOCKED: typing.ClassVar[int] = ...
    CDMA_ACCESS_FAILURE: typing.ClassVar[int] = ...
    CDMA_ALREADY_ACTIVATED: typing.ClassVar[int] = ...
    CDMA_DROP: typing.ClassVar[int] = ...
    CDMA_INTERCEPT: typing.ClassVar[int] = ...
    CDMA_LOCKED_UNTIL_POWER_CYCLE: typing.ClassVar[int] = ...
    CDMA_NOT_EMERGENCY: typing.ClassVar[int] = ...
    CDMA_PREEMPTED: typing.ClassVar[int] = ...
    CDMA_REORDER: typing.ClassVar[int] = ...
    CDMA_RETRY_ORDER: typing.ClassVar[int] = ...
    CDMA_SO_REJECT: typing.ClassVar[int] = ...
    CONGESTION: typing.ClassVar[int] = ...
    CS_RESTRICTED: typing.ClassVar[int] = ...
    CS_RESTRICTED_EMERGENCY: typing.ClassVar[int] = ...
    CS_RESTRICTED_NORMAL: typing.ClassVar[int] = ...
    DATA_DISABLED: typing.ClassVar[int] = ...
    DATA_LIMIT_REACHED: typing.ClassVar[int] = ...
    DIALED_CALL_FORWARDING_WHILE_ROAMING: typing.ClassVar[int] = ...
    DIALED_MMI: typing.ClassVar[int] = ...
    DIAL_LOW_BATTERY: typing.ClassVar[int] = ...
    DIAL_MODIFIED_TO_DIAL: typing.ClassVar[int] = ...
    DIAL_MODIFIED_TO_DIAL_VIDEO: typing.ClassVar[int] = ...
    DIAL_MODIFIED_TO_SS: typing.ClassVar[int] = ...
    DIAL_MODIFIED_TO_USSD: typing.ClassVar[int] = ...
    DIAL_VIDEO_MODIFIED_TO_DIAL: typing.ClassVar[int] = ...
    DIAL_VIDEO_MODIFIED_TO_DIAL_VIDEO: typing.ClassVar[int] = ...
    DIAL_VIDEO_MODIFIED_TO_SS: typing.ClassVar[int] = ...
    DIAL_VIDEO_MODIFIED_TO_USSD: typing.ClassVar[int] = ...
    EMERGENCY_CALL_OVER_WFC_NOT_AVAILABLE: typing.ClassVar[int] = ...
    EMERGENCY_PERM_FAILURE: typing.ClassVar[int] = ...
    EMERGENCY_TEMP_FAILURE: typing.ClassVar[int] = ...
    ERROR_UNSPECIFIED: typing.ClassVar[int] = ...
    FDN_BLOCKED: typing.ClassVar[int] = ...
    ICC_ERROR: typing.ClassVar[int] = ...
    IMEI_NOT_ACCEPTED: typing.ClassVar[int] = ...
    IMS_ACCESS_BLOCKED: typing.ClassVar[int] = ...
    IMS_MERGED_SUCCESSFULLY: typing.ClassVar[int] = ...
    IMS_SIP_ALTERNATE_EMERGENCY_CALL: typing.ClassVar[int] = ...
    INCOMING_AUTO_REJECTED: typing.ClassVar[int] = ...
    INCOMING_MISSED: typing.ClassVar[int] = ...
    INCOMING_REJECTED: typing.ClassVar[int] = ...
    INVALID_CREDENTIALS: typing.ClassVar[int] = ...
    INVALID_NUMBER: typing.ClassVar[int] = ...
    LIMIT_EXCEEDED: typing.ClassVar[int] = ...
    LOCAL: typing.ClassVar[int] = ...
    LOST_SIGNAL: typing.ClassVar[int] = ...
    LOW_BATTERY: typing.ClassVar[int] = ...
    MAXIMUM_NUMBER_OF_CALLS_REACHED: typing.ClassVar[int] = ...
    MEDIA_TIMEOUT: typing.ClassVar[int] = ...
    MMI: typing.ClassVar[int] = ...
    NORMAL: typing.ClassVar[int] = ...
    NORMAL_UNSPECIFIED: typing.ClassVar[int] = ...
    NOT_DISCONNECTED: typing.ClassVar[int] = ...
    NOT_VALID: typing.ClassVar[int] = ...
    NO_PHONE_NUMBER_SUPPLIED: typing.ClassVar[int] = ...
    NUMBER_UNREACHABLE: typing.ClassVar[int] = ...
    OTASP_PROVISIONING_IN_PROCESS: typing.ClassVar[int] = ...
    OUTGOING_CANCELED: typing.ClassVar[int] = ...
    OUTGOING_EMERGENCY_CALL_PLACED: typing.ClassVar[int] = ...
    OUTGOING_FAILURE: typing.ClassVar[int] = ...
    OUT_OF_NETWORK: typing.ClassVar[int] = ...
    OUT_OF_SERVICE: typing.ClassVar[int] = ...
    POWER_OFF: typing.ClassVar[int] = ...
    SATELLITE_ENABLED: typing.ClassVar[int] = ...
    SERVER_ERROR: typing.ClassVar[int] = ...
    SERVER_UNREACHABLE: typing.ClassVar[int] = ...
    TIMED_OUT: typing.ClassVar[int] = ...
    TOO_MANY_ONGOING_CALLS: typing.ClassVar[int] = ...
    UNOBTAINABLE_NUMBER: typing.ClassVar[int] = ...
    VIDEO_CALL_NOT_ALLOWED_WHILE_TTY_ENABLED: typing.ClassVar[int] = ...
    VOICEMAIL_NUMBER_MISSING: typing.ClassVar[int] = ...
    WFC_SERVICE_NOT_AVAILABLE_IN_THIS_LOCATION: typing.ClassVar[int] = ...
    WIFI_LOST: typing.ClassVar[int] = ...

class IccOpenLogicalChannelResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[IccOpenLogicalChannelResponse]] = ...
    INVALID_CHANNEL: typing.ClassVar[int] = ...
    STATUS_MISSING_RESOURCE: typing.ClassVar[int] = ...
    STATUS_NO_ERROR: typing.ClassVar[int] = ...
    STATUS_NO_SUCH_ELEMENT: typing.ClassVar[int] = ...
    STATUS_UNKNOWN_ERROR: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getChannel(self) -> int: ...
    def getSelectResponse(self) -> java.chaquopy.JavaArrayJByte: ...
    def getStatus(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class MbmsDownloadSession(java.lang.AutoCloseable):
    DEFAULT_TOP_LEVEL_TEMP_DIRECTORY: typing.ClassVar[str] = ...
    EXTRA_MBMS_COMPLETED_FILE_URI: typing.ClassVar[str] = ...
    EXTRA_MBMS_DOWNLOAD_REQUEST: typing.ClassVar[str] = ...
    EXTRA_MBMS_DOWNLOAD_RESULT: typing.ClassVar[str] = ...
    EXTRA_MBMS_FILE_INFO: typing.ClassVar[str] = ...
    RESULT_CANCELLED: typing.ClassVar[int] = ...
    RESULT_DOWNLOAD_FAILURE: typing.ClassVar[int] = ...
    RESULT_EXPIRED: typing.ClassVar[int] = ...
    RESULT_FILE_ROOT_UNREACHABLE: typing.ClassVar[int] = ...
    RESULT_IO_ERROR: typing.ClassVar[int] = ...
    RESULT_OUT_OF_STORAGE: typing.ClassVar[int] = ...
    RESULT_SERVICE_ID_NOT_DEFINED: typing.ClassVar[int] = ...
    RESULT_SUCCESSFUL: typing.ClassVar[int] = ...
    STATUS_ACTIVELY_DOWNLOADING: typing.ClassVar[int] = ...
    STATUS_PENDING_DOWNLOAD: typing.ClassVar[int] = ...
    STATUS_PENDING_DOWNLOAD_WINDOW: typing.ClassVar[int] = ...
    STATUS_PENDING_REPAIR: typing.ClassVar[int] = ...
    STATUS_UNKNOWN: typing.ClassVar[int] = ...
    def addProgressListener(self, request: android.telephony.mbms.DownloadRequest, executor: java.util.concurrent.Executor, listener: android.telephony.mbms.DownloadProgressListener, /) -> None: ...
    def addServiceAnnouncement(self, contents: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def addStatusListener(self, request: android.telephony.mbms.DownloadRequest, executor: java.util.concurrent.Executor, listener: android.telephony.mbms.DownloadStatusListener, /) -> None: ...
    def cancelDownload(self, downloadRequest: android.telephony.mbms.DownloadRequest, /) -> None: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create(context: android.content.Context, executor: java.util.concurrent.Executor, callback: android.telephony.mbms.MbmsDownloadSessionCallback, /) -> MbmsDownloadSession | None: ...
    @typing.overload
    @staticmethod
    def create(context: android.content.Context, executor: java.util.concurrent.Executor, subscriptionId: int | java.jint | java.lang.Integer, callback: android.telephony.mbms.MbmsDownloadSessionCallback, /) -> MbmsDownloadSession | None: ...
    def download(self, request: android.telephony.mbms.DownloadRequest, /) -> None: ...
    @staticmethod
    def getMaximumServiceAnnouncementSize() -> int: ...
    def getTempFileRootDirectory(self) -> java.io.File | None: ...
    def listPendingDownloads(self) -> java.util.List[android.telephony.mbms.DownloadRequest]: ...
    def removeProgressListener(self, request: android.telephony.mbms.DownloadRequest, listener: android.telephony.mbms.DownloadProgressListener, /) -> None: ...
    def removeStatusListener(self, request: android.telephony.mbms.DownloadRequest, listener: android.telephony.mbms.DownloadStatusListener, /) -> None: ...
    def requestDownloadState(self, downloadRequest: android.telephony.mbms.DownloadRequest, fileInfo: android.telephony.mbms.FileInfo, /) -> None: ...
    def requestUpdateFileServices(self, classList: java.util.List[java.lang.String], /) -> None: ...
    def resetDownloadKnowledge(self, downloadRequest: android.telephony.mbms.DownloadRequest, /) -> None: ...
    def setTempFileRootDirectory(self, tempFileRootDirectory: java.io.File, /) -> None: ...

class MbmsGroupCallSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create(context: android.content.Context, executor: java.util.concurrent.Executor, callback: android.telephony.mbms.MbmsGroupCallSessionCallback, /) -> MbmsGroupCallSession | None: ...
    @typing.overload
    @staticmethod
    def create(context: android.content.Context, subscriptionId: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, callback: android.telephony.mbms.MbmsGroupCallSessionCallback, /) -> MbmsGroupCallSession | None: ...
    def startGroupCall(self, tmgi: int | java.jlong | java.lang.Long, saiList: java.util.List[java.lang.Integer], frequencyList: java.util.List[java.lang.Integer], executor: java.util.concurrent.Executor, callback: android.telephony.mbms.GroupCallCallback, /) -> android.telephony.mbms.GroupCall | None: ...

class MbmsStreamingSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create(context: android.content.Context, executor: java.util.concurrent.Executor, callback: android.telephony.mbms.MbmsStreamingSessionCallback, /) -> MbmsStreamingSession | None: ...
    @typing.overload
    @staticmethod
    def create(context: android.content.Context, executor: java.util.concurrent.Executor, subscriptionId: int | java.jint | java.lang.Integer, callback: android.telephony.mbms.MbmsStreamingSessionCallback, /) -> MbmsStreamingSession | None: ...
    def requestUpdateStreamingServices(self, serviceClassList: java.util.List[java.lang.String], /) -> None: ...
    def startStreaming(self, serviceInfo: android.telephony.mbms.StreamingServiceInfo, executor: java.util.concurrent.Executor, callback: android.telephony.mbms.StreamingServiceCallback, /) -> android.telephony.mbms.StreamingService | None: ...

class NeighboringCellInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NeighboringCellInfo]] = ...
    UNKNOWN_CID: typing.ClassVar[int] = ...
    UNKNOWN_RSSI: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, rssi: int | java.jint | java.lang.Integer, cid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, rssi: int | java.jint | java.lang.Integer, location: str | java.lang.String, radioType: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCid(self) -> int: ...
    def getLac(self) -> int: ...
    def getNetworkType(self) -> int: ...
    def getPsc(self) -> int: ...
    def getRssi(self) -> int: ...
    def setCid(self, cid: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRssi(self, rssi: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class NetworkRegistrationInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NetworkRegistrationInfo]] = ...
    DOMAIN_CS: typing.ClassVar[int] = ...
    DOMAIN_CS_PS: typing.ClassVar[int] = ...
    DOMAIN_PS: typing.ClassVar[int] = ...
    DOMAIN_UNKNOWN: typing.ClassVar[int] = ...
    NR_STATE_CONNECTED: typing.ClassVar[int] = ...
    NR_STATE_NONE: typing.ClassVar[int] = ...
    NR_STATE_NOT_RESTRICTED: typing.ClassVar[int] = ...
    NR_STATE_RESTRICTED: typing.ClassVar[int] = ...
    SERVICE_TYPE_DATA: typing.ClassVar[int] = ...
    SERVICE_TYPE_EMERGENCY: typing.ClassVar[int] = ...
    SERVICE_TYPE_MMS: typing.ClassVar[int] = ...
    SERVICE_TYPE_SMS: typing.ClassVar[int] = ...
    SERVICE_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    SERVICE_TYPE_VIDEO: typing.ClassVar[int] = ...
    SERVICE_TYPE_VOICE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAccessNetworkTechnology(self) -> int: ...
    def getAvailableServices(self) -> java.util.List[java.lang.Integer]: ...
    def getCellIdentity(self) -> CellIdentity | None: ...
    def getDomain(self) -> int: ...
    def getRegisteredPlmn(self) -> str | None: ...
    def getRejectCause(self) -> int: ...
    def getTransportType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isNetworkRegistered(self) -> bool: ...
    def isNetworkRoaming(self) -> bool: ...
    def isNetworkSearching(self) -> bool: ...
    def isNonTerrestrialNetwork(self) -> bool: ...
    def isRegistered(self) -> bool: ...
    def isRoaming(self) -> bool: ...
    def isSearching(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class NetworkScan(java.lang.Object):
    ERROR_INTERRUPTED: typing.ClassVar[int] = ...
    ERROR_INVALID_SCAN: typing.ClassVar[int] = ...
    ERROR_INVALID_SCANID: typing.ClassVar[int] = ...
    ERROR_MODEM_ERROR: typing.ClassVar[int] = ...
    ERROR_MODEM_UNAVAILABLE: typing.ClassVar[int] = ...
    ERROR_RADIO_INTERFACE_ERROR: typing.ClassVar[int] = ...
    ERROR_UNSUPPORTED: typing.ClassVar[int] = ...
    SUCCESS: typing.ClassVar[int] = ...
    def stopScan(self) -> None: ...

class NetworkScanRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NetworkScanRequest]] = ...
    SCAN_TYPE_ONE_SHOT: typing.ClassVar[int] = ...
    SCAN_TYPE_PERIODIC: typing.ClassVar[int] = ...
    def __init__(self, scanType: int | java.jint | java.lang.Integer, specifiers: java.chaquopy.JavaArray[RadioAccessSpecifier], searchPeriodicity: int | java.jint | java.lang.Integer, maxSearchTime: int | java.jint | java.lang.Integer, incrementalResults: bool | java.jboolean | java.lang.Boolean, incrementalResultsPeriodicity: int | java.jint | java.lang.Integer, mccMncs: java.util.ArrayList[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIncrementalResults(self) -> bool: ...
    def getIncrementalResultsPeriodicity(self) -> int: ...
    def getMaxSearchTime(self) -> int: ...
    def getPlmns(self) -> java.util.ArrayList[java.lang.String]: ...
    def getScanType(self) -> int: ...
    def getSearchPeriodicity(self) -> int: ...
    def getSpecifiers(self) -> java.chaquopy.JavaArray[RadioAccessSpecifier]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PhoneNumberFormattingTextWatcher(android.text.TextWatcher):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, countryCode: str | java.lang.String, /) -> None: ...
    def afterTextChanged(self, s: android.text.Editable, /) -> None: ...
    def beforeTextChanged(self, s: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, after: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTextChanged(self, s: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, before: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...

class PhoneNumberUtils(java.lang.Object):
    BCD_EXTENDED_TYPE_CALLED_PARTY: typing.ClassVar[int] = ...
    BCD_EXTENDED_TYPE_EF_ADN: typing.ClassVar[int] = ...
    FORMAT_JAPAN: typing.ClassVar[int] = ...
    FORMAT_NANP: typing.ClassVar[int] = ...
    FORMAT_UNKNOWN: typing.ClassVar[int] = ...
    PAUSE: typing.ClassVar[str] = ...
    TOA_International: typing.ClassVar[int] = ...
    TOA_Unknown: typing.ClassVar[int] = ...
    WAIT: typing.ClassVar[str] = ...
    WILD: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def addTtsSpan(s: android.text.Spannable, start: int | java.jint | java.lang.Integer, endExclusive: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def areSamePhoneNumber(number1: str | java.lang.String, number2: str | java.lang.String, defaultCountryIso: str | java.lang.String, /) -> bool: ...
    @typing.overload
    @staticmethod
    def calledPartyBCDFragmentToString(bytes: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def calledPartyBCDFragmentToString(bytes: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, bcdExtType: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def calledPartyBCDToString(bytes: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def calledPartyBCDToString(bytes: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, bcdExtType: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def compare(a: str | java.lang.String, b: str | java.lang.String, /) -> bool: ...
    @typing.overload
    @staticmethod
    def compare(context: android.content.Context, a: str | java.lang.String, b: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def convertKeypadLettersToDigits(input: str | java.lang.String, /) -> str: ...
    @staticmethod
    def createTtsSpan(phoneNumberString: str | java.lang.String, /) -> android.text.style.TtsSpan: ...
    @staticmethod
    def createTtsSpannable(phoneNumber: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
    @staticmethod
    def extractNetworkPortion(phoneNumber: str | java.lang.String, /) -> str: ...
    @staticmethod
    def extractPostDialPortion(phoneNumber: str | java.lang.String, /) -> str: ...
    @staticmethod
    def formatJapaneseNumber(text: android.text.Editable, /) -> None: ...
    @staticmethod
    def formatNanpNumber(text: android.text.Editable, /) -> None: ...
    @typing.overload
    @staticmethod
    def formatNumber(source: str | java.lang.String, /) -> str | None: ...
    @typing.overload
    @staticmethod
    def formatNumber(text: android.text.Editable, defaultFormattingType: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def formatNumber(phoneNumber: str | java.lang.String, defaultCountryIso: str | java.lang.String, /) -> str | None: ...
    @typing.overload
    @staticmethod
    def formatNumber(phoneNumber: str | java.lang.String, phoneNumberE164: str | java.lang.String, defaultCountryIso: str | java.lang.String, /) -> str | None: ...
    @staticmethod
    def formatNumberToE164(phoneNumber: str | java.lang.String, defaultCountryIso: str | java.lang.String, /) -> str | None: ...
    @staticmethod
    def formatNumberToRFC3966(phoneNumber: str | java.lang.String, defaultCountryIso: str | java.lang.String, /) -> str | None: ...
    @staticmethod
    def getFormatTypeForLocale(locale: java.util.Locale, /) -> int: ...
    @staticmethod
    def getNumberFromIntent(intent: android.content.Intent, context: android.content.Context, /) -> str: ...
    @staticmethod
    def getStrippedReversed(phoneNumber: str | java.lang.String, /) -> str: ...
    @staticmethod
    def is12Key(c: str | java.jchar | java.lang.Character, /) -> bool: ...
    @staticmethod
    def isDialable(c: str | java.jchar | java.lang.Character, /) -> bool: ...
    @staticmethod
    def isEmergencyNumber(number: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isGlobalPhoneNumber(phoneNumber: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isISODigit(c: str | java.jchar | java.lang.Character, /) -> bool: ...
    @staticmethod
    def isLocalEmergencyNumber(context: android.content.Context, number: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isNonSeparator(c: str | java.jchar | java.lang.Character, /) -> bool: ...
    @staticmethod
    def isReallyDialable(c: str | java.jchar | java.lang.Character, /) -> bool: ...
    @staticmethod
    def isStartsPostDial(c: str | java.jchar | java.lang.Character, /) -> bool: ...
    @staticmethod
    def isVoiceMailNumber(number: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isWellFormedSmsAddress(address: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isWpsCallNumber(number: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def networkPortionToCalledPartyBCD(s: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def networkPortionToCalledPartyBCDWithLength(s: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def normalizeNumber(phoneNumber: str | java.lang.String, /) -> str: ...
    @typing.overload
    @staticmethod
    def numberToCalledPartyBCD(number: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    @staticmethod
    def numberToCalledPartyBCD(number: str | java.lang.String, bcdExtType: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def replaceUnicodeDigits(number: str | java.lang.String, /) -> str: ...
    @staticmethod
    def stringFromStringAndTOA(s: str | java.lang.String, TOA: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def stripSeparators(phoneNumber: str | java.lang.String, /) -> str: ...
    @staticmethod
    def toCallerIDMinMatch(phoneNumber: str | java.lang.String, /) -> str: ...
    @staticmethod
    def toaFromString(s: str | java.lang.String, /) -> int: ...

class PhoneStateListener(java.lang.Object):
    LISTEN_ACTIVE_DATA_SUBSCRIPTION_ID_CHANGE: typing.ClassVar[int] = ...
    LISTEN_BARRING_INFO: typing.ClassVar[int] = ...
    LISTEN_CALL_DISCONNECT_CAUSES: typing.ClassVar[int] = ...
    LISTEN_CALL_FORWARDING_INDICATOR: typing.ClassVar[int] = ...
    LISTEN_CALL_STATE: typing.ClassVar[int] = ...
    LISTEN_CELL_INFO: typing.ClassVar[int] = ...
    LISTEN_CELL_LOCATION: typing.ClassVar[int] = ...
    LISTEN_DATA_ACTIVITY: typing.ClassVar[int] = ...
    LISTEN_DATA_CONNECTION_STATE: typing.ClassVar[int] = ...
    LISTEN_DISPLAY_INFO_CHANGED: typing.ClassVar[int] = ...
    LISTEN_EMERGENCY_NUMBER_LIST: typing.ClassVar[int] = ...
    LISTEN_IMS_CALL_DISCONNECT_CAUSES: typing.ClassVar[int] = ...
    LISTEN_MESSAGE_WAITING_INDICATOR: typing.ClassVar[int] = ...
    LISTEN_NONE: typing.ClassVar[int] = ...
    LISTEN_PRECISE_DATA_CONNECTION_STATE: typing.ClassVar[int] = ...
    LISTEN_REGISTRATION_FAILURE: typing.ClassVar[int] = ...
    LISTEN_SERVICE_STATE: typing.ClassVar[int] = ...
    LISTEN_SIGNAL_STRENGTH: typing.ClassVar[int] = ...
    LISTEN_SIGNAL_STRENGTHS: typing.ClassVar[int] = ...
    LISTEN_USER_MOBILE_DATA_STATE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, executor: java.util.concurrent.Executor, /) -> None: ...
    def onActiveDataSubscriptionIdChanged(self, subId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onBarringInfoChanged(self, barringInfo: BarringInfo, /) -> None: ...
    def onCallDisconnectCauseChanged(self, disconnectCause: int | java.jint | java.lang.Integer, preciseDisconnectCause: int | java.jint | java.lang.Integer, /) -> None: ...
    def onCallForwardingIndicatorChanged(self, cfi: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onCallStateChanged(self, state: int | java.jint | java.lang.Integer, phoneNumber: str | java.lang.String, /) -> None: ...
    def onCellInfoChanged(self, cellInfo: java.util.List[CellInfo], /) -> None: ...
    def onCellLocationChanged(self, location: CellLocation, /) -> None: ...
    def onDataActivity(self, direction: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onDataConnectionStateChanged(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onDataConnectionStateChanged(self, state: int | java.jint | java.lang.Integer, networkType: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDisplayInfoChanged(self, telephonyDisplayInfo: TelephonyDisplayInfo, /) -> None: ...
    def onEmergencyNumberListChanged(self, emergencyNumberList: java.util.Map[java.lang.Integer, java.util.List[android.telephony.emergency.EmergencyNumber]], /) -> None: ...
    def onImsCallDisconnectCauseChanged(self, imsReasonInfo: android.telephony.ims.ImsReasonInfo, /) -> None: ...
    def onMessageWaitingIndicatorChanged(self, mwi: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onPreciseDataConnectionStateChanged(self, dataConnectionState: PreciseDataConnectionState, /) -> None: ...
    def onRegistrationFailed(self, cellIdentity: CellIdentity, chosenPlmn: str | java.lang.String, domain: int | java.jint | java.lang.Integer, causeCode: int | java.jint | java.lang.Integer, additionalCauseCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onServiceStateChanged(self, serviceState: ServiceState, /) -> None: ...
    def onSignalStrengthChanged(self, asu: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSignalStrengthsChanged(self, signalStrength: SignalStrength, /) -> None: ...
    def onUserMobileDataStateChanged(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class PhysicalChannelConfig(android.os.Parcelable):
    BAND_UNKNOWN: typing.ClassVar[int] = ...
    CELL_BANDWIDTH_UNKNOWN: typing.ClassVar[int] = ...
    CHANNEL_NUMBER_UNKNOWN: typing.ClassVar[int] = ...
    CONNECTION_PRIMARY_SERVING: typing.ClassVar[int] = ...
    CONNECTION_SECONDARY_SERVING: typing.ClassVar[int] = ...
    CONNECTION_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PhysicalChannelConfig]] = ...
    FREQUENCY_UNKNOWN: typing.ClassVar[int] = ...
    PHYSICAL_CELL_ID_MAXIMUM_VALUE: typing.ClassVar[int] = ...
    PHYSICAL_CELL_ID_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBand(self) -> int: ...
    def getCellBandwidthDownlinkKhz(self) -> int: ...
    def getCellBandwidthUplinkKhz(self) -> int: ...
    def getConnectionStatus(self) -> int: ...
    def getDownlinkChannelNumber(self) -> int: ...
    def getDownlinkFrequencyKhz(self) -> int: ...
    def getNetworkType(self) -> int: ...
    def getPhysicalCellId(self) -> int: ...
    def getUplinkChannelNumber(self) -> int: ...
    def getUplinkFrequencyKhz(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PreciseDataConnectionState(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PreciseDataConnectionState]] = ...
    NETWORK_VALIDATION_FAILURE: typing.ClassVar[int] = ...
    NETWORK_VALIDATION_IN_PROGRESS: typing.ClassVar[int] = ...
    NETWORK_VALIDATION_NOT_REQUESTED: typing.ClassVar[int] = ...
    NETWORK_VALIDATION_SUCCESS: typing.ClassVar[int] = ...
    NETWORK_VALIDATION_UNSUPPORTED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getApnSetting(self) -> android.telephony.data.ApnSetting | None: ...
    def getId(self) -> int: ...
    def getLastCauseCode(self) -> int: ...
    def getLinkProperties(self) -> android.net.LinkProperties | None: ...
    def getNetworkType(self) -> int: ...
    def getNetworkValidationStatus(self) -> int: ...
    def getState(self) -> int: ...
    def getTransportType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RadioAccessSpecifier(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RadioAccessSpecifier]] = ...
    def __init__(self, ran: int | java.jint | java.lang.Integer, bands: java.chaquopy.JavaArrayJInt, channels: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBands(self) -> java.chaquopy.JavaArrayJInt: ...
    def getChannels(self) -> java.chaquopy.JavaArrayJInt: ...
    def getRadioAccessNetwork(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ServiceState(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ServiceState]] = ...
    DUPLEX_MODE_FDD: typing.ClassVar[int] = ...
    DUPLEX_MODE_TDD: typing.ClassVar[int] = ...
    DUPLEX_MODE_UNKNOWN: typing.ClassVar[int] = ...
    STATE_EMERGENCY_ONLY: typing.ClassVar[int] = ...
    STATE_IN_SERVICE: typing.ClassVar[int] = ...
    STATE_OUT_OF_SERVICE: typing.ClassVar[int] = ...
    STATE_POWER_OFF: typing.ClassVar[int] = ...
    UNKNOWN_ID: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, s: ServiceState, /) -> None: ...
    def copyFrom(self, s: ServiceState, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCdmaNetworkId(self) -> int: ...
    def getCdmaSystemId(self) -> int: ...
    def getCellBandwidths(self) -> java.chaquopy.JavaArrayJInt: ...
    def getChannelNumber(self) -> int: ...
    def getDuplexMode(self) -> int: ...
    def getIsManualSelection(self) -> bool: ...
    def getNetworkRegistrationInfoList(self) -> java.util.List[NetworkRegistrationInfo]: ...
    def getOperatorAlphaLong(self) -> str: ...
    def getOperatorAlphaShort(self) -> str: ...
    def getOperatorNumeric(self) -> str: ...
    def getRoaming(self) -> bool: ...
    def getState(self) -> int: ...
    def hashCode(self) -> int: ...
    def isSearching(self) -> bool: ...
    def isUsingNonTerrestrialNetwork(self) -> bool: ...
    def setIsManualSelection(self, isManual: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOperatorName(self, longName: str | java.lang.String, shortName: str | java.lang.String, numeric: str | java.lang.String, /) -> None: ...
    def setRoaming(self, roaming: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setState(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStateOff(self) -> None: ...
    def setStateOutOfService(self) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SignalStrength(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SignalStrength]] = ...
    INVALID: typing.ClassVar[int] = ...
    def __init__(self, s: SignalStrength, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCdmaDbm(self) -> int: ...
    def getCdmaEcio(self) -> int: ...
    _getCellSignalStrengths_1__T = typing.TypeVar('_getCellSignalStrengths_1__T', bound=CellSignalStrength)  # <T>
    @typing.overload
    def getCellSignalStrengths(self) -> java.util.List[CellSignalStrength]: ...
    @typing.overload
    def getCellSignalStrengths(self, clazz: typing.Type[_getCellSignalStrengths_1__T], /) -> java.util.List[_getCellSignalStrengths_1__T]: ...
    def getEvdoDbm(self) -> int: ...
    def getEvdoEcio(self) -> int: ...
    def getEvdoSnr(self) -> int: ...
    def getGsmBitErrorRate(self) -> int: ...
    def getGsmSignalStrength(self) -> int: ...
    def getLevel(self) -> int: ...
    def getTimestampMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def isGsm(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SignalStrengthUpdateRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SignalStrengthUpdateRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSignalThresholdInfos(self) -> java.util.Collection[SignalThresholdInfo]: ...
    def hashCode(self) -> int: ...
    def isReportingRequestedWhileIdle(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> SignalStrengthUpdateRequest: ...
        def setReportingRequestedWhileIdle(self, isReportingRequestedWhileIdle: bool | java.jboolean | java.lang.Boolean, /) -> SignalStrengthUpdateRequest.Builder: ...
        def setSignalThresholdInfos(self, signalThresholdInfos: java.util.Collection[SignalThresholdInfo], /) -> SignalStrengthUpdateRequest.Builder: ...

class SignalThresholdInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SignalThresholdInfo]] = ...
    SIGNAL_MEASUREMENT_TYPE_ECNO: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_RSCP: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_RSRP: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_RSRQ: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_RSSI: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_RSSNR: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_SSRSRP: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_SSRSRQ: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_SSSINR: typing.ClassVar[int] = ...
    SIGNAL_MEASUREMENT_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHysteresisDb(self) -> int: ...
    @staticmethod
    def getMaximumNumberOfThresholdsAllowed() -> int: ...
    @staticmethod
    def getMinimumNumberOfThresholdsAllowed() -> int: ...
    def getRadioAccessNetworkType(self) -> int: ...
    def getSignalMeasurementType(self) -> int: ...
    def getThresholds(self) -> java.chaquopy.JavaArrayJInt: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> SignalThresholdInfo: ...
        def setHysteresisDb(self, hysteresisDb: int | java.jint | java.lang.Integer, /) -> SignalThresholdInfo.Builder: ...
        def setRadioAccessNetworkType(self, ran: int | java.jint | java.lang.Integer, /) -> SignalThresholdInfo.Builder: ...
        def setSignalMeasurementType(self, signalMeasurementType: int | java.jint | java.lang.Integer, /) -> SignalThresholdInfo.Builder: ...
        def setThresholds(self, thresholds: java.chaquopy.JavaArrayJInt, /) -> SignalThresholdInfo.Builder: ...

class SmsManager(java.lang.Object):
    EXTRA_MMS_DATA: typing.ClassVar[str] = ...
    EXTRA_MMS_HTTP_STATUS: typing.ClassVar[str] = ...
    MMS_CONFIG_ALIAS_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_ALIAS_MAX_CHARS: typing.ClassVar[str] = ...
    MMS_CONFIG_ALIAS_MIN_CHARS: typing.ClassVar[str] = ...
    MMS_CONFIG_ALLOW_ATTACH_AUDIO: typing.ClassVar[str] = ...
    MMS_CONFIG_APPEND_TRANSACTION_ID: typing.ClassVar[str] = ...
    MMS_CONFIG_EMAIL_GATEWAY_NUMBER: typing.ClassVar[str] = ...
    MMS_CONFIG_GROUP_MMS_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_HTTP_PARAMS: typing.ClassVar[str] = ...
    MMS_CONFIG_HTTP_SOCKET_TIMEOUT: typing.ClassVar[str] = ...
    MMS_CONFIG_MAX_IMAGE_HEIGHT: typing.ClassVar[str] = ...
    MMS_CONFIG_MAX_IMAGE_WIDTH: typing.ClassVar[str] = ...
    MMS_CONFIG_MAX_MESSAGE_SIZE: typing.ClassVar[str] = ...
    MMS_CONFIG_MESSAGE_TEXT_MAX_SIZE: typing.ClassVar[str] = ...
    MMS_CONFIG_MMS_DELIVERY_REPORT_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_MMS_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_MMS_READ_REPORT_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_MULTIPART_SMS_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_NAI_SUFFIX: typing.ClassVar[str] = ...
    MMS_CONFIG_NOTIFY_WAP_MMSC_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_RECIPIENT_LIMIT: typing.ClassVar[str] = ...
    MMS_CONFIG_SEND_MULTIPART_SMS_AS_SEPARATE_MESSAGES: typing.ClassVar[str] = ...
    MMS_CONFIG_SHOW_CELL_BROADCAST_APP_LINKS: typing.ClassVar[str] = ...
    MMS_CONFIG_SMS_DELIVERY_REPORT_ENABLED: typing.ClassVar[str] = ...
    MMS_CONFIG_SMS_TO_MMS_TEXT_LENGTH_THRESHOLD: typing.ClassVar[str] = ...
    MMS_CONFIG_SMS_TO_MMS_TEXT_THRESHOLD: typing.ClassVar[str] = ...
    MMS_CONFIG_SUBJECT_MAX_LENGTH: typing.ClassVar[str] = ...
    MMS_CONFIG_SUPPORT_HTTP_CHARSET_HEADER: typing.ClassVar[str] = ...
    MMS_CONFIG_SUPPORT_MMS_CONTENT_DISPOSITION: typing.ClassVar[str] = ...
    MMS_CONFIG_UA_PROF_TAG_NAME: typing.ClassVar[str] = ...
    MMS_CONFIG_UA_PROF_URL: typing.ClassVar[str] = ...
    MMS_CONFIG_USER_AGENT: typing.ClassVar[str] = ...
    MMS_ERROR_CONFIGURATION_ERROR: typing.ClassVar[int] = ...
    MMS_ERROR_DATA_DISABLED: typing.ClassVar[int] = ...
    MMS_ERROR_HTTP_FAILURE: typing.ClassVar[int] = ...
    MMS_ERROR_INACTIVE_SUBSCRIPTION: typing.ClassVar[int] = ...
    MMS_ERROR_INVALID_APN: typing.ClassVar[int] = ...
    MMS_ERROR_INVALID_SUBSCRIPTION_ID: typing.ClassVar[int] = ...
    MMS_ERROR_IO_ERROR: typing.ClassVar[int] = ...
    MMS_ERROR_MMS_DISABLED_BY_CARRIER: typing.ClassVar[int] = ...
    MMS_ERROR_NO_DATA_NETWORK: typing.ClassVar[int] = ...
    MMS_ERROR_RETRY: typing.ClassVar[int] = ...
    MMS_ERROR_UNABLE_CONNECT_MMS: typing.ClassVar[int] = ...
    MMS_ERROR_UNSPECIFIED: typing.ClassVar[int] = ...
    RESULT_BLUETOOTH_DISCONNECTED: typing.ClassVar[int] = ...
    RESULT_CANCELLED: typing.ClassVar[int] = ...
    RESULT_ENCODING_ERROR: typing.ClassVar[int] = ...
    RESULT_ERROR_FDN_CHECK_FAILURE: typing.ClassVar[int] = ...
    RESULT_ERROR_GENERIC_FAILURE: typing.ClassVar[int] = ...
    RESULT_ERROR_LIMIT_EXCEEDED: typing.ClassVar[int] = ...
    RESULT_ERROR_NONE: typing.ClassVar[int] = ...
    RESULT_ERROR_NO_SERVICE: typing.ClassVar[int] = ...
    RESULT_ERROR_NULL_PDU: typing.ClassVar[int] = ...
    RESULT_ERROR_RADIO_OFF: typing.ClassVar[int] = ...
    RESULT_ERROR_SHORT_CODE_NEVER_ALLOWED: typing.ClassVar[int] = ...
    RESULT_ERROR_SHORT_CODE_NOT_ALLOWED: typing.ClassVar[int] = ...
    RESULT_INTERNAL_ERROR: typing.ClassVar[int] = ...
    RESULT_INVALID_ARGUMENTS: typing.ClassVar[int] = ...
    RESULT_INVALID_BLUETOOTH_ADDRESS: typing.ClassVar[int] = ...
    RESULT_INVALID_SMSC_ADDRESS: typing.ClassVar[int] = ...
    RESULT_INVALID_SMS_FORMAT: typing.ClassVar[int] = ...
    RESULT_INVALID_STATE: typing.ClassVar[int] = ...
    RESULT_MODEM_ERROR: typing.ClassVar[int] = ...
    RESULT_NETWORK_ERROR: typing.ClassVar[int] = ...
    RESULT_NETWORK_REJECT: typing.ClassVar[int] = ...
    RESULT_NO_BLUETOOTH_SERVICE: typing.ClassVar[int] = ...
    RESULT_NO_DEFAULT_SMS_APP: typing.ClassVar[int] = ...
    RESULT_NO_MEMORY: typing.ClassVar[int] = ...
    RESULT_NO_RESOURCES: typing.ClassVar[int] = ...
    RESULT_OPERATION_NOT_ALLOWED: typing.ClassVar[int] = ...
    RESULT_RADIO_NOT_AVAILABLE: typing.ClassVar[int] = ...
    RESULT_RECEIVE_DISPATCH_FAILURE: typing.ClassVar[int] = ...
    RESULT_RECEIVE_INJECTED_NULL_PDU: typing.ClassVar[int] = ...
    RESULT_RECEIVE_NULL_MESSAGE_FROM_RIL: typing.ClassVar[int] = ...
    RESULT_RECEIVE_RUNTIME_EXCEPTION: typing.ClassVar[int] = ...
    RESULT_RECEIVE_SQL_EXCEPTION: typing.ClassVar[int] = ...
    RESULT_RECEIVE_URI_EXCEPTION: typing.ClassVar[int] = ...
    RESULT_RECEIVE_WHILE_ENCRYPTED: typing.ClassVar[int] = ...
    RESULT_REMOTE_EXCEPTION: typing.ClassVar[int] = ...
    RESULT_REQUEST_NOT_SUPPORTED: typing.ClassVar[int] = ...
    RESULT_RIL_ABORTED: typing.ClassVar[int] = ...
    RESULT_RIL_ACCESS_BARRED: typing.ClassVar[int] = ...
    RESULT_RIL_BLOCKED_DUE_TO_CALL: typing.ClassVar[int] = ...
    RESULT_RIL_CANCELLED: typing.ClassVar[int] = ...
    RESULT_RIL_DEVICE_IN_USE: typing.ClassVar[int] = ...
    RESULT_RIL_ENCODING_ERR: typing.ClassVar[int] = ...
    RESULT_RIL_GENERIC_ERROR: typing.ClassVar[int] = ...
    RESULT_RIL_INTERNAL_ERR: typing.ClassVar[int] = ...
    RESULT_RIL_INVALID_ARGUMENTS: typing.ClassVar[int] = ...
    RESULT_RIL_INVALID_MODEM_STATE: typing.ClassVar[int] = ...
    RESULT_RIL_INVALID_RESPONSE: typing.ClassVar[int] = ...
    RESULT_RIL_INVALID_SIM_STATE: typing.ClassVar[int] = ...
    RESULT_RIL_INVALID_SMSC_ADDRESS: typing.ClassVar[int] = ...
    RESULT_RIL_INVALID_SMS_FORMAT: typing.ClassVar[int] = ...
    RESULT_RIL_INVALID_STATE: typing.ClassVar[int] = ...
    RESULT_RIL_MODEM_ERR: typing.ClassVar[int] = ...
    RESULT_RIL_NETWORK_ERR: typing.ClassVar[int] = ...
    RESULT_RIL_NETWORK_NOT_READY: typing.ClassVar[int] = ...
    RESULT_RIL_NETWORK_REJECT: typing.ClassVar[int] = ...
    RESULT_RIL_NO_MEMORY: typing.ClassVar[int] = ...
    RESULT_RIL_NO_NETWORK_FOUND: typing.ClassVar[int] = ...
    RESULT_RIL_NO_RESOURCES: typing.ClassVar[int] = ...
    RESULT_RIL_NO_SMS_TO_ACK: typing.ClassVar[int] = ...
    RESULT_RIL_NO_SUBSCRIPTION: typing.ClassVar[int] = ...
    RESULT_RIL_OPERATION_NOT_ALLOWED: typing.ClassVar[int] = ...
    RESULT_RIL_RADIO_NOT_AVAILABLE: typing.ClassVar[int] = ...
    RESULT_RIL_REQUEST_NOT_SUPPORTED: typing.ClassVar[int] = ...
    RESULT_RIL_REQUEST_RATE_LIMITED: typing.ClassVar[int] = ...
    RESULT_RIL_SIMULTANEOUS_SMS_AND_CALL_NOT_ALLOWED: typing.ClassVar[int] = ...
    RESULT_RIL_SIM_ABSENT: typing.ClassVar[int] = ...
    RESULT_RIL_SIM_BUSY: typing.ClassVar[int] = ...
    RESULT_RIL_SIM_ERROR: typing.ClassVar[int] = ...
    RESULT_RIL_SIM_FULL: typing.ClassVar[int] = ...
    RESULT_RIL_SIM_PIN2: typing.ClassVar[int] = ...
    RESULT_RIL_SIM_PUK2: typing.ClassVar[int] = ...
    RESULT_RIL_SMS_SEND_FAIL_RETRY: typing.ClassVar[int] = ...
    RESULT_RIL_SUBSCRIPTION_NOT_AVAILABLE: typing.ClassVar[int] = ...
    RESULT_RIL_SYSTEM_ERR: typing.ClassVar[int] = ...
    RESULT_SMS_BLOCKED_DURING_EMERGENCY: typing.ClassVar[int] = ...
    RESULT_SMS_SEND_RETRY_FAILED: typing.ClassVar[int] = ...
    RESULT_SYSTEM_ERROR: typing.ClassVar[int] = ...
    RESULT_UNEXPECTED_EVENT_STOP_SENDING: typing.ClassVar[int] = ...
    RESULT_USER_NOT_ALLOWED: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_CALL_BARRING: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_CONGESTION: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_DESTINATION_OUT_OF_ORDER: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_FACILITY_NOT_IMPLEMENTED: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_FACILITY_NOT_SUBSCRIBED: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_FACILITY_REJECTED: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_INFORMATION_ELEMENT_NON_EXISTENT: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_INTERWORKING_UNSPECIFIED: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_INVALID_MANDATORY_INFORMATION: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_INVALID_MESSAGE_REFERENCE_VALUE: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_MESSAGE_INCOMPATIBLE_WITH_PROTOCOL_STATE: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_MESSAGE_TYPE_NON_EXISTENT: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_NETWORK_OUT_OF_ORDER: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_OPERATOR_DETERMINED_BARRING: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_PROTOCOL_ERROR: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_RESERVED: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_RESOURCES_UNAVAILABLE: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_SEMANTICALLY_INCORRECT_MESSAGE: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_SHORT_MESSAGE_TRANSFER_REJECTED: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_TEMPORARY_FAILURE: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_UNALLOCATED_NUMBER: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_UNIDENTIFIED_SUBSCRIBER: typing.ClassVar[int] = ...
    SMS_RP_CAUSE_UNKNOWN_SUBSCRIBER: typing.ClassVar[int] = ...
    STATUS_ON_ICC_FREE: typing.ClassVar[int] = ...
    STATUS_ON_ICC_READ: typing.ClassVar[int] = ...
    STATUS_ON_ICC_SENT: typing.ClassVar[int] = ...
    STATUS_ON_ICC_UNREAD: typing.ClassVar[int] = ...
    STATUS_ON_ICC_UNSENT: typing.ClassVar[int] = ...
    def createAppSpecificSmsToken(self, intent: android.app.PendingIntent, /) -> str: ...
    def createAppSpecificSmsTokenWithPackageInfo(self, prefixes: str | java.lang.String, intent: android.app.PendingIntent, /) -> str | None: ...
    def createForSubscriptionId(self, subId: int | java.jint | java.lang.Integer, /) -> SmsManager: ...
    def divideMessage(self, text: str | java.lang.String, /) -> java.util.ArrayList[java.lang.String]: ...
    @typing.overload
    def downloadMultimediaMessage(self, context: android.content.Context, locationUrl: str | java.lang.String, contentUri: android.net.Uri, configOverrides: android.os.Bundle, downloadedIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def downloadMultimediaMessage(self, context: android.content.Context, locationUrl: str | java.lang.String, contentUri: android.net.Uri, configOverrides: android.os.Bundle, downloadedIntent: android.app.PendingIntent, messageId: int | java.jlong | java.lang.Long, /) -> None: ...
    def getCarrierConfigValues(self) -> android.os.Bundle: ...
    @staticmethod
    def getDefault() -> SmsManager: ...
    @staticmethod
    def getDefaultSmsSubscriptionId() -> int: ...
    def getSmsCapacityOnIcc(self) -> int: ...
    @staticmethod
    def getSmsManagerForSubscriptionId(subId: int | java.jint | java.lang.Integer, /) -> SmsManager: ...
    def getSmsMessagesForFinancialApp(self, params: android.os.Bundle, executor: java.util.concurrent.Executor, callback: SmsManager.FinancialSmsCallback, /) -> None: ...
    def getSmscAddress(self) -> str | None: ...
    def getSubscriptionId(self) -> int: ...
    def injectSmsPdu(self, pdu: java.chaquopy.JavaArrayJByte, format: str | java.lang.String, receivedIntent: android.app.PendingIntent, /) -> None: ...
    def sendDataMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, destinationPort: int | java.jshort | java.lang.Short, data: java.chaquopy.JavaArrayJByte, sentIntent: android.app.PendingIntent, deliveryIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def sendMultimediaMessage(self, context: android.content.Context, contentUri: android.net.Uri, locationUrl: str | java.lang.String, configOverrides: android.os.Bundle, sentIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def sendMultimediaMessage(self, context: android.content.Context, contentUri: android.net.Uri, locationUrl: str | java.lang.String, configOverrides: android.os.Bundle, sentIntent: android.app.PendingIntent, messageId: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def sendMultipartTextMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, parts: java.util.ArrayList[java.lang.String], sentIntents: java.util.ArrayList[android.app.PendingIntent], deliveryIntents: java.util.ArrayList[android.app.PendingIntent], /) -> None: ...
    @typing.overload
    def sendMultipartTextMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, parts: java.util.List[java.lang.String], sentIntents: java.util.List[android.app.PendingIntent], deliveryIntents: java.util.List[android.app.PendingIntent], messageId: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def sendMultipartTextMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, parts: java.util.List[java.lang.String], sentIntents: java.util.List[android.app.PendingIntent], deliveryIntents: java.util.List[android.app.PendingIntent], packageName: str | java.lang.String, attributionTag: str | java.lang.String, /) -> None: ...
    @typing.overload
    def sendTextMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, text: str | java.lang.String, sentIntent: android.app.PendingIntent, deliveryIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def sendTextMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, text: str | java.lang.String, sentIntent: android.app.PendingIntent, deliveryIntent: android.app.PendingIntent, messageId: int | java.jlong | java.lang.Long, /) -> None: ...
    def sendTextMessageWithoutPersisting(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, text: str | java.lang.String, sentIntent: android.app.PendingIntent, deliveryIntent: android.app.PendingIntent, /) -> None: ...
    def setSmscAddress(self, smsc: str | java.lang.String, /) -> bool: ...

    class FinancialSmsCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onFinancialSmsMessages(self, arg1: android.database.CursorWindow, /) -> None: ...

class SmsMessage(java.lang.Object):
    ENCODING_16BIT: typing.ClassVar[int] = ...
    ENCODING_7BIT: typing.ClassVar[int] = ...
    ENCODING_8BIT: typing.ClassVar[int] = ...
    ENCODING_KSC5601: typing.ClassVar[int] = ...
    ENCODING_UNKNOWN: typing.ClassVar[int] = ...
    FORMAT_3GPP2: typing.ClassVar[str] = ...
    FORMAT_3GPP: typing.ClassVar[str] = ...
    MAX_USER_DATA_BYTES: typing.ClassVar[int] = ...
    MAX_USER_DATA_BYTES_WITH_HEADER: typing.ClassVar[int] = ...
    MAX_USER_DATA_SEPTETS: typing.ClassVar[int] = ...
    MAX_USER_DATA_SEPTETS_WITH_HEADER: typing.ClassVar[int] = ...
    @typing.overload
    @staticmethod
    def calculateLength(msgBody: java.lang.CharSequence, use7bitOnly: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArrayJInt: ...
    @typing.overload
    @staticmethod
    def calculateLength(messageBody: str | java.lang.String, use7bitOnly: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArrayJInt: ...
    @typing.overload
    @staticmethod
    def createFromPdu(pdu: java.chaquopy.JavaArrayJByte, /) -> SmsMessage: ...
    @typing.overload
    @staticmethod
    def createFromPdu(pdu: java.chaquopy.JavaArrayJByte, format: str | java.lang.String, /) -> SmsMessage: ...
    def getDisplayMessageBody(self) -> str: ...
    def getDisplayOriginatingAddress(self) -> str: ...
    def getEmailBody(self) -> str: ...
    def getEmailFrom(self) -> str: ...
    def getIndexOnIcc(self) -> int: ...
    def getIndexOnSim(self) -> int: ...
    def getMessageBody(self) -> str | None: ...
    def getMessageClass(self) -> SmsMessage.MessageClass: ...
    def getOriginatingAddress(self) -> str | None: ...
    def getPdu(self) -> java.chaquopy.JavaArrayJByte: ...
    def getProtocolIdentifier(self) -> int: ...
    def getPseudoSubject(self) -> str: ...
    def getRecipientAddress(self) -> str: ...
    def getServiceCenterAddress(self) -> str: ...
    def getStatus(self) -> int: ...
    def getStatusOnIcc(self) -> int: ...
    def getStatusOnSim(self) -> int: ...
    @typing.overload
    @staticmethod
    def getSubmitPdu(scAddress: str | java.lang.String, destinationAddress: str | java.lang.String, message: str | java.lang.String, statusReportRequested: bool | java.jboolean | java.lang.Boolean, /) -> SmsMessage.SubmitPdu | None: ...
    @typing.overload
    @staticmethod
    def getSubmitPdu(scAddress: str | java.lang.String, destinationAddress: str | java.lang.String, destinationPort: int | java.jshort | java.lang.Short, data: java.chaquopy.JavaArrayJByte, statusReportRequested: bool | java.jboolean | java.lang.Boolean, /) -> SmsMessage.SubmitPdu | None: ...
    @staticmethod
    def getTPLayerLengthForPDU(pdu: str | java.lang.String, /) -> int: ...
    def getTimestampMillis(self) -> int: ...
    def getUserData(self) -> java.chaquopy.JavaArrayJByte: ...
    def isCphsMwiMessage(self) -> bool: ...
    def isEmail(self) -> bool: ...
    def isMWIClearMessage(self) -> bool: ...
    def isMWISetMessage(self) -> bool: ...
    def isMwiDontStore(self) -> bool: ...
    def isReplace(self) -> bool: ...
    def isReplyPathPresent(self) -> bool: ...
    def isStatusReportMessage(self) -> bool: ...

    class SubmitPdu(java.lang.Object):
        encodedMessage: java.chaquopy.JavaArrayJByte = ...
        encodedScAddress: java.chaquopy.JavaArrayJByte = ...
        def toString(self) -> str: ...

    class MessageClass(java.lang.Enum[SmsMessage.MessageClass]):
        CLASS_0: typing.ClassVar[SmsMessage.MessageClass] = ...
        CLASS_1: typing.ClassVar[SmsMessage.MessageClass] = ...
        CLASS_2: typing.ClassVar[SmsMessage.MessageClass] = ...
        CLASS_3: typing.ClassVar[SmsMessage.MessageClass] = ...
        UNKNOWN: typing.ClassVar[SmsMessage.MessageClass] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> SmsMessage.MessageClass: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[SmsMessage.MessageClass]: ...

class SubscriptionInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SubscriptionInfo]] = ...
    def createIconBitmap(self, context: android.content.Context, /) -> android.graphics.Bitmap: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCardId(self) -> int: ...
    def getCarrierId(self) -> int: ...
    def getCarrierName(self) -> java.lang.CharSequence: ...
    def getCountryIso(self) -> str: ...
    def getDataRoaming(self) -> int: ...
    def getDisplayName(self) -> java.lang.CharSequence: ...
    def getGroupUuid(self) -> android.os.ParcelUuid | None: ...
    def getIccId(self) -> str: ...
    def getIconTint(self) -> int: ...
    def getMcc(self) -> int: ...
    def getMccString(self) -> str | None: ...
    def getMnc(self) -> int: ...
    def getMncString(self) -> str | None: ...
    def getNumber(self) -> str: ...
    def getPortIndex(self) -> int: ...
    def getServiceCapabilities(self) -> java.util.Set[java.lang.Integer]: ...
    def getSimSlotIndex(self) -> int: ...
    def getSubscriptionId(self) -> int: ...
    def getSubscriptionType(self) -> int: ...
    def getUsageSetting(self) -> int: ...
    def hashCode(self) -> int: ...
    def isEmbedded(self) -> bool: ...
    def isOnlyNonTerrestrialNetwork(self) -> bool: ...
    def isOpportunistic(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SubscriptionManager(java.lang.Object):
    ACTION_DEFAULT_SMS_SUBSCRIPTION_CHANGED: typing.ClassVar[str] = ...
    ACTION_DEFAULT_SUBSCRIPTION_CHANGED: typing.ClassVar[str] = ...
    ACTION_MANAGE_SUBSCRIPTION_PLANS: typing.ClassVar[str] = ...
    ACTION_REFRESH_SUBSCRIPTION_PLANS: typing.ClassVar[str] = ...
    D2D_SHARING_ALL: typing.ClassVar[int] = ...
    D2D_SHARING_ALL_CONTACTS: typing.ClassVar[int] = ...
    D2D_SHARING_DISABLED: typing.ClassVar[int] = ...
    D2D_SHARING_SELECTED_CONTACTS: typing.ClassVar[int] = ...
    D2D_STATUS_SHARING: typing.ClassVar[str] = ...
    D2D_STATUS_SHARING_SELECTED_CONTACTS: typing.ClassVar[str] = ...
    DATA_ROAMING_DISABLE: typing.ClassVar[int] = ...
    DATA_ROAMING_ENABLE: typing.ClassVar[int] = ...
    DEFAULT_SUBSCRIPTION_ID: typing.ClassVar[int] = ...
    EXTRA_SLOT_INDEX: typing.ClassVar[str] = ...
    EXTRA_SUBSCRIPTION_INDEX: typing.ClassVar[str] = ...
    INVALID_SIM_SLOT_INDEX: typing.ClassVar[int] = ...
    INVALID_SUBSCRIPTION_ID: typing.ClassVar[int] = ...
    PHONE_NUMBER_SOURCE_CARRIER: typing.ClassVar[int] = ...
    PHONE_NUMBER_SOURCE_IMS: typing.ClassVar[int] = ...
    PHONE_NUMBER_SOURCE_UICC: typing.ClassVar[int] = ...
    SERVICE_CAPABILITY_DATA: typing.ClassVar[int] = ...
    SERVICE_CAPABILITY_SMS: typing.ClassVar[int] = ...
    SERVICE_CAPABILITY_VOICE: typing.ClassVar[int] = ...
    SUBSCRIPTION_TYPE_LOCAL_SIM: typing.ClassVar[int] = ...
    SUBSCRIPTION_TYPE_REMOTE_SIM: typing.ClassVar[int] = ...
    USAGE_SETTING_DATA_CENTRIC: typing.ClassVar[int] = ...
    USAGE_SETTING_DEFAULT: typing.ClassVar[int] = ...
    USAGE_SETTING_UNKNOWN: typing.ClassVar[int] = ...
    USAGE_SETTING_VOICE_CENTRIC: typing.ClassVar[int] = ...
    def addOnOpportunisticSubscriptionsChangedListener(self, executor: java.util.concurrent.Executor, listener: SubscriptionManager.OnOpportunisticSubscriptionsChangedListener, /) -> None: ...
    @typing.overload
    def addOnSubscriptionsChangedListener(self, listener: SubscriptionManager.OnSubscriptionsChangedListener, /) -> None: ...
    @typing.overload
    def addOnSubscriptionsChangedListener(self, executor: java.util.concurrent.Executor, listener: SubscriptionManager.OnSubscriptionsChangedListener, /) -> None: ...
    def addSubscriptionsIntoGroup(self, subIdList: java.util.List[java.lang.Integer], groupUuid: android.os.ParcelUuid, /) -> None: ...
    def canManageSubscription(self, info: SubscriptionInfo, /) -> bool: ...
    def createSubscriptionGroup(self, subIdList: java.util.List[java.lang.Integer], /) -> android.os.ParcelUuid: ...
    @staticmethod
    def from_(context: android.content.Context, /) -> SubscriptionManager: ...
    def getAccessibleSubscriptionInfoList(self) -> java.util.List[SubscriptionInfo] | None: ...
    @staticmethod
    def getActiveDataSubscriptionId() -> int: ...
    def getActiveSubscriptionInfo(self, subId: int | java.jint | java.lang.Integer, /) -> SubscriptionInfo | None: ...
    def getActiveSubscriptionInfoCount(self) -> int: ...
    def getActiveSubscriptionInfoCountMax(self) -> int: ...
    def getActiveSubscriptionInfoForSimSlotIndex(self, slotIndex: int | java.jint | java.lang.Integer, /) -> SubscriptionInfo | None: ...
    def getActiveSubscriptionInfoList(self) -> java.util.List[SubscriptionInfo] | None: ...
    def getAllSubscriptionInfoList(self) -> java.util.List[SubscriptionInfo]: ...
    def getCompleteActiveSubscriptionInfoList(self) -> java.util.List[SubscriptionInfo]: ...
    @staticmethod
    def getDefaultDataSubscriptionId() -> int: ...
    @staticmethod
    def getDefaultSmsSubscriptionId() -> int: ...
    @staticmethod
    def getDefaultSubscriptionId() -> int: ...
    @staticmethod
    def getDefaultVoiceSubscriptionId() -> int: ...
    def getDeviceToDeviceStatusSharingContacts(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> java.util.List[android.net.Uri]: ...
    def getDeviceToDeviceStatusSharingPreference(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> int: ...
    def getOpportunisticSubscriptions(self) -> java.util.List[SubscriptionInfo]: ...
    @typing.overload
    def getPhoneNumber(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getPhoneNumber(self, subscriptionId: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getSlotIndex(subscriptionId: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getSubscriptionId(slotIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getSubscriptionIds(self, slotIndex: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt | None: ...
    def getSubscriptionPlans(self, subId: int | java.jint | java.lang.Integer, /) -> java.util.List[SubscriptionPlan]: ...
    def getSubscriptionsInGroup(self, groupUuid: android.os.ParcelUuid, /) -> java.util.List[SubscriptionInfo]: ...
    def isActiveSubscriptionId(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isNetworkRoaming(self, subId: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isUsableSubscriptionId(subscriptionId: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isValidSubscriptionId(subscriptionId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def removeOnOpportunisticSubscriptionsChangedListener(self, listener: SubscriptionManager.OnOpportunisticSubscriptionsChangedListener, /) -> None: ...
    def removeOnSubscriptionsChangedListener(self, listener: SubscriptionManager.OnSubscriptionsChangedListener, /) -> None: ...
    def removeSubscriptionsFromGroup(self, subIdList: java.util.List[java.lang.Integer], groupUuid: android.os.ParcelUuid, /) -> None: ...
    def setCarrierPhoneNumber(self, subscriptionId: int | java.jint | java.lang.Integer, number: str | java.lang.String, /) -> None: ...
    def setDeviceToDeviceStatusSharingContacts(self, subscriptionId: int | java.jint | java.lang.Integer, contacts: java.util.List[android.net.Uri], /) -> None: ...
    def setDeviceToDeviceStatusSharingPreference(self, subscriptionId: int | java.jint | java.lang.Integer, sharing: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOpportunistic(self, opportunistic: bool | java.jboolean | java.lang.Boolean, subId: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def setSubscriptionOverrideCongested(self, subId: int | java.jint | java.lang.Integer, overrideCongested: bool | java.jboolean | java.lang.Boolean, expirationDurationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setSubscriptionOverrideCongested(self, subId: int | java.jint | java.lang.Integer, overrideCongested: bool | java.jboolean | java.lang.Boolean, networkTypes: java.chaquopy.JavaArrayJInt, expirationDurationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setSubscriptionOverrideUnmetered(self, subId: int | java.jint | java.lang.Integer, overrideUnmetered: bool | java.jboolean | java.lang.Boolean, expirationDurationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setSubscriptionOverrideUnmetered(self, subId: int | java.jint | java.lang.Integer, overrideUnmetered: bool | java.jboolean | java.lang.Boolean, networkTypes: java.chaquopy.JavaArrayJInt, expirationDurationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setSubscriptionPlans(self, subId: int | java.jint | java.lang.Integer, plans: java.util.List[SubscriptionPlan], /) -> None: ...
    @typing.overload
    def setSubscriptionPlans(self, subId: int | java.jint | java.lang.Integer, plans: java.util.List[SubscriptionPlan], expirationDurationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def switchToSubscription(self, subId: int | java.jint | java.lang.Integer, callbackIntent: android.app.PendingIntent, /) -> None: ...

    class OnSubscriptionsChangedListener(java.lang.Object):
        def __init__(self) -> None: ...
        def onSubscriptionsChanged(self) -> None: ...

    class OnOpportunisticSubscriptionsChangedListener(java.lang.Object):
        def __init__(self) -> None: ...
        def onOpportunisticSubscriptionsChanged(self) -> None: ...

class SubscriptionPlan(android.os.Parcelable):
    BYTES_UNKNOWN: typing.ClassVar[int] = ...
    BYTES_UNLIMITED: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SubscriptionPlan]] = ...
    LIMIT_BEHAVIOR_BILLED: typing.ClassVar[int] = ...
    LIMIT_BEHAVIOR_DISABLED: typing.ClassVar[int] = ...
    LIMIT_BEHAVIOR_THROTTLED: typing.ClassVar[int] = ...
    LIMIT_BEHAVIOR_UNKNOWN: typing.ClassVar[int] = ...
    SUBSCRIPTION_STATUS_ACTIVE: typing.ClassVar[int] = ...
    SUBSCRIPTION_STATUS_INACTIVE: typing.ClassVar[int] = ...
    SUBSCRIPTION_STATUS_SUSPENDED: typing.ClassVar[int] = ...
    SUBSCRIPTION_STATUS_TRIAL: typing.ClassVar[int] = ...
    SUBSCRIPTION_STATUS_UNKNOWN: typing.ClassVar[int] = ...
    TIME_UNKNOWN: typing.ClassVar[int] = ...
    def cycleIterator(self) -> java.util.Iterator[android.util.Range[java.time.ZonedDateTime]]: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDataLimitBehavior(self) -> int: ...
    def getDataLimitBytes(self) -> int: ...
    def getDataUsageBytes(self) -> int: ...
    def getDataUsageTime(self) -> int: ...
    def getNetworkTypes(self) -> java.chaquopy.JavaArrayJInt: ...
    def getPlanEndDate(self) -> java.time.ZonedDateTime: ...
    def getSubscriptionStatus(self) -> int: ...
    def getSummary(self) -> java.lang.CharSequence | None: ...
    def getTitle(self) -> java.lang.CharSequence | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def build(self) -> SubscriptionPlan: ...
        @staticmethod
        def createNonrecurring(start: java.time.ZonedDateTime, end: java.time.ZonedDateTime, /) -> SubscriptionPlan.Builder: ...
        @staticmethod
        def createRecurring(start: java.time.ZonedDateTime, period: java.time.Period, /) -> SubscriptionPlan.Builder: ...
        def resetNetworkTypes(self) -> SubscriptionPlan.Builder: ...
        def setDataLimit(self, dataLimitBytes: int | java.jlong | java.lang.Long, dataLimitBehavior: int | java.jint | java.lang.Integer, /) -> SubscriptionPlan.Builder: ...
        def setDataUsage(self, dataUsageBytes: int | java.jlong | java.lang.Long, dataUsageTime: int | java.jlong | java.lang.Long, /) -> SubscriptionPlan.Builder: ...
        def setNetworkTypes(self, networkTypes: java.chaquopy.JavaArrayJInt, /) -> SubscriptionPlan.Builder: ...
        def setSubscriptionStatus(self, subscriptionStatus: int | java.jint | java.lang.Integer, /) -> SubscriptionPlan.Builder: ...
        def setSummary(self, summary: java.lang.CharSequence, /) -> SubscriptionPlan.Builder: ...
        def setTitle(self, title: java.lang.CharSequence, /) -> SubscriptionPlan.Builder: ...

class TelephonyCallback(java.lang.Object):
    def __init__(self) -> None: ...

    class UserMobileDataStateListener(java.lang.Object):
        def onUserMobileDataStateChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class SignalStrengthsListener(java.lang.Object):
        def onSignalStrengthsChanged(self, arg1: SignalStrength, /) -> None: ...

    class ServiceStateListener(java.lang.Object):
        def onServiceStateChanged(self, arg1: ServiceState, /) -> None: ...

    class RegistrationFailedListener(java.lang.Object):
        def onRegistrationFailed(self, arg1: CellIdentity, arg2: str | java.lang.String, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...

    class PreciseDataConnectionStateListener(java.lang.Object):
        def onPreciseDataConnectionStateChanged(self, arg1: PreciseDataConnectionState, /) -> None: ...

    class PhysicalChannelConfigListener(java.lang.Object):
        def onPhysicalChannelConfigChanged(self, arg1: java.util.List[PhysicalChannelConfig], /) -> None: ...

    class MessageWaitingIndicatorListener(java.lang.Object):
        def onMessageWaitingIndicatorChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class ImsCallDisconnectCauseListener(java.lang.Object):
        def onImsCallDisconnectCauseChanged(self, arg1: android.telephony.ims.ImsReasonInfo, /) -> None: ...

    class EmergencyNumberListListener(java.lang.Object):
        def onEmergencyNumberListChanged(self, arg1: java.util.Map[java.lang.Integer, java.util.List[android.telephony.emergency.EmergencyNumber]], /) -> None: ...

    class DisplayInfoListener(java.lang.Object):
        def onDisplayInfoChanged(self, arg1: TelephonyDisplayInfo, /) -> None: ...

    class DataConnectionStateListener(java.lang.Object):
        def onDataConnectionStateChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

    class DataActivityListener(java.lang.Object):
        def onDataActivity(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class DataActivationStateListener(java.lang.Object):
        def onDataActivationStateChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class CellLocationListener(java.lang.Object):
        def onCellLocationChanged(self, arg1: CellLocation, /) -> None: ...

    class CellInfoListener(java.lang.Object):
        def onCellInfoChanged(self, arg1: java.util.List[CellInfo], /) -> None: ...

    class CarrierNetworkListener(java.lang.Object):
        def onCarrierNetworkChange(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class CallStateListener(java.lang.Object):
        def onCallStateChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class CallForwardingIndicatorListener(java.lang.Object):
        def onCallForwardingIndicatorChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class CallDisconnectCauseListener(java.lang.Object):
        def onCallDisconnectCauseChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

    class BarringInfoListener(java.lang.Object):
        def onBarringInfoChanged(self, arg1: BarringInfo, /) -> None: ...

    class ActiveDataSubscriptionIdListener(java.lang.Object):
        def onActiveDataSubscriptionIdChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class TelephonyDisplayInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TelephonyDisplayInfo]] = ...
    OVERRIDE_NETWORK_TYPE_LTE_ADVANCED_PRO: typing.ClassVar[int] = ...
    OVERRIDE_NETWORK_TYPE_LTE_CA: typing.ClassVar[int] = ...
    OVERRIDE_NETWORK_TYPE_NONE: typing.ClassVar[int] = ...
    OVERRIDE_NETWORK_TYPE_NR_ADVANCED: typing.ClassVar[int] = ...
    OVERRIDE_NETWORK_TYPE_NR_NSA: typing.ClassVar[int] = ...
    OVERRIDE_NETWORK_TYPE_NR_NSA_MMWAVE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getNetworkType(self) -> int: ...
    def getOverrideNetworkType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isRoaming(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TelephonyManager(java.lang.Object):
    ACTION_CARRIER_MESSAGING_CLIENT_SERVICE: typing.ClassVar[str] = ...
    ACTION_CARRIER_SIGNAL_DEFAULT_NETWORK_AVAILABLE: typing.ClassVar[str] = ...
    ACTION_CARRIER_SIGNAL_PCO_VALUE: typing.ClassVar[str] = ...
    ACTION_CARRIER_SIGNAL_REDIRECTED: typing.ClassVar[str] = ...
    ACTION_CARRIER_SIGNAL_REQUEST_NETWORK_FAILED: typing.ClassVar[str] = ...
    ACTION_CARRIER_SIGNAL_RESET: typing.ClassVar[str] = ...
    ACTION_CONFIGURE_VOICEMAIL: typing.ClassVar[str] = ...
    ACTION_MULTI_SIM_CONFIG_CHANGED: typing.ClassVar[str] = ...
    ACTION_NETWORK_COUNTRY_CHANGED: typing.ClassVar[str] = ...
    ACTION_PHONE_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_RESET_MOBILE_NETWORK_SETTINGS: typing.ClassVar[str] = ...
    ACTION_RESPOND_VIA_MESSAGE: typing.ClassVar[str] = ...
    ACTION_SECRET_CODE: typing.ClassVar[str] = ...
    ACTION_SHOW_VOICEMAIL_NOTIFICATION: typing.ClassVar[str] = ...
    ACTION_SUBSCRIPTION_CARRIER_IDENTITY_CHANGED: typing.ClassVar[str] = ...
    ACTION_SUBSCRIPTION_SPECIFIC_CARRIER_IDENTITY_CHANGED: typing.ClassVar[str] = ...
    ALLOWED_NETWORK_TYPES_REASON_CARRIER: typing.ClassVar[int] = ...
    ALLOWED_NETWORK_TYPES_REASON_USER: typing.ClassVar[int] = ...
    APPTYPE_CSIM: typing.ClassVar[int] = ...
    APPTYPE_ISIM: typing.ClassVar[int] = ...
    APPTYPE_RUIM: typing.ClassVar[int] = ...
    APPTYPE_SIM: typing.ClassVar[int] = ...
    APPTYPE_UNKNOWN: typing.ClassVar[int] = ...
    APPTYPE_USIM: typing.ClassVar[int] = ...
    AUTHTYPE_EAP_AKA: typing.ClassVar[int] = ...
    AUTHTYPE_EAP_SIM: typing.ClassVar[int] = ...
    AUTHTYPE_GBA_BOOTSTRAP: typing.ClassVar[int] = ...
    AUTHTYPE_GBA_NAF_KEY_EXTERNAL: typing.ClassVar[int] = ...
    CALL_COMPOSER_STATUS_BUSINESS_ONLY: typing.ClassVar[int] = ...
    CALL_COMPOSER_STATUS_OFF: typing.ClassVar[int] = ...
    CALL_COMPOSER_STATUS_ON: typing.ClassVar[int] = ...
    CALL_STATE_IDLE: typing.ClassVar[int] = ...
    CALL_STATE_OFFHOOK: typing.ClassVar[int] = ...
    CALL_STATE_RINGING: typing.ClassVar[int] = ...
    CAPABILITY_SLICING_CONFIG_SUPPORTED: typing.ClassVar[str] = ...
    CARRIER_RESTRICTION_STATUS_NOT_RESTRICTED: typing.ClassVar[int] = ...
    CARRIER_RESTRICTION_STATUS_RESTRICTED: typing.ClassVar[int] = ...
    CARRIER_RESTRICTION_STATUS_RESTRICTED_TO_CALLER: typing.ClassVar[int] = ...
    CARRIER_RESTRICTION_STATUS_UNKNOWN: typing.ClassVar[int] = ...
    CDMA_ROAMING_MODE_AFFILIATED: typing.ClassVar[int] = ...
    CDMA_ROAMING_MODE_ANY: typing.ClassVar[int] = ...
    CDMA_ROAMING_MODE_HOME: typing.ClassVar[int] = ...
    CDMA_ROAMING_MODE_RADIO_DEFAULT: typing.ClassVar[int] = ...
    DATA_ACTIVITY_DORMANT: typing.ClassVar[int] = ...
    DATA_ACTIVITY_IN: typing.ClassVar[int] = ...
    DATA_ACTIVITY_INOUT: typing.ClassVar[int] = ...
    DATA_ACTIVITY_NONE: typing.ClassVar[int] = ...
    DATA_ACTIVITY_OUT: typing.ClassVar[int] = ...
    DATA_CONNECTED: typing.ClassVar[int] = ...
    DATA_CONNECTING: typing.ClassVar[int] = ...
    DATA_DISCONNECTED: typing.ClassVar[int] = ...
    DATA_DISCONNECTING: typing.ClassVar[int] = ...
    DATA_ENABLED_REASON_CARRIER: typing.ClassVar[int] = ...
    DATA_ENABLED_REASON_OVERRIDE: typing.ClassVar[int] = ...
    DATA_ENABLED_REASON_POLICY: typing.ClassVar[int] = ...
    DATA_ENABLED_REASON_THERMAL: typing.ClassVar[int] = ...
    DATA_ENABLED_REASON_UNKNOWN: typing.ClassVar[int] = ...
    DATA_ENABLED_REASON_USER: typing.ClassVar[int] = ...
    DATA_HANDOVER_IN_PROGRESS: typing.ClassVar[int] = ...
    DATA_SUSPENDED: typing.ClassVar[int] = ...
    DATA_UNKNOWN: typing.ClassVar[int] = ...
    DEFAULT_PORT_INDEX: typing.ClassVar[int] = ...
    ERI_FLASH: typing.ClassVar[int] = ...
    ERI_OFF: typing.ClassVar[int] = ...
    ERI_ON: typing.ClassVar[int] = ...
    EVENT_DISPLAY_EMERGENCY_MESSAGE: typing.ClassVar[str] = ...
    EXTRA_ACTIVE_SIM_SUPPORTED_COUNT: typing.ClassVar[str] = ...
    EXTRA_APN_PROTOCOL: typing.ClassVar[str] = ...
    EXTRA_APN_TYPE: typing.ClassVar[str] = ...
    EXTRA_CALL_VOICEMAIL_INTENT: typing.ClassVar[str] = ...
    EXTRA_CARRIER_ID: typing.ClassVar[str] = ...
    EXTRA_CARRIER_NAME: typing.ClassVar[str] = ...
    EXTRA_DATA_FAIL_CAUSE: typing.ClassVar[str] = ...
    EXTRA_DEFAULT_NETWORK_AVAILABLE: typing.ClassVar[str] = ...
    EXTRA_EMERGENCY_CALL_TO_SATELLITE_HANDOVER_TYPE: typing.ClassVar[str] = ...
    EXTRA_EMERGENCY_CALL_TO_SATELLITE_LAUNCH_INTENT: typing.ClassVar[str] = ...
    EXTRA_HIDE_PUBLIC_SETTINGS: typing.ClassVar[str] = ...
    EXTRA_INCOMING_NUMBER: typing.ClassVar[str] = ...
    EXTRA_IS_REFRESH: typing.ClassVar[str] = ...
    EXTRA_LAST_KNOWN_NETWORK_COUNTRY: typing.ClassVar[str] = ...
    EXTRA_LAUNCH_VOICEMAIL_SETTINGS_INTENT: typing.ClassVar[str] = ...
    EXTRA_NETWORK_COUNTRY: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_COUNT: typing.ClassVar[str] = ...
    EXTRA_PCO_ID: typing.ClassVar[str] = ...
    EXTRA_PCO_VALUE: typing.ClassVar[str] = ...
    EXTRA_PHONE_ACCOUNT_HANDLE: typing.ClassVar[str] = ...
    EXTRA_REDIRECTION_URL: typing.ClassVar[str] = ...
    EXTRA_SPECIFIC_CARRIER_ID: typing.ClassVar[str] = ...
    EXTRA_SPECIFIC_CARRIER_NAME: typing.ClassVar[str] = ...
    EXTRA_STATE: typing.ClassVar[str] = ...
    EXTRA_STATE_IDLE: typing.ClassVar[str] = ...
    EXTRA_STATE_OFFHOOK: typing.ClassVar[str] = ...
    EXTRA_STATE_RINGING: typing.ClassVar[str] = ...
    EXTRA_SUBSCRIPTION_ID: typing.ClassVar[str] = ...
    EXTRA_VOICEMAIL_NUMBER: typing.ClassVar[str] = ...
    INCLUDE_LOCATION_DATA_COARSE: typing.ClassVar[int] = ...
    INCLUDE_LOCATION_DATA_FINE: typing.ClassVar[int] = ...
    INCLUDE_LOCATION_DATA_NONE: typing.ClassVar[int] = ...
    METADATA_HIDE_VOICEMAIL_SETTINGS_MENU: typing.ClassVar[str] = ...
    MULTISIM_ALLOWED: typing.ClassVar[int] = ...
    MULTISIM_NOT_SUPPORTED_BY_CARRIER: typing.ClassVar[int] = ...
    MULTISIM_NOT_SUPPORTED_BY_HARDWARE: typing.ClassVar[int] = ...
    NETWORK_SELECTION_MODE_AUTO: typing.ClassVar[int] = ...
    NETWORK_SELECTION_MODE_MANUAL: typing.ClassVar[int] = ...
    NETWORK_SELECTION_MODE_UNKNOWN: typing.ClassVar[int] = ...
    NETWORK_TYPE_1xRTT: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_1xRTT: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_CDMA: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_EDGE: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_EHRPD: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_EVDO_0: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_EVDO_A: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_EVDO_B: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_GPRS: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_GSM: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_HSDPA: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_HSPA: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_HSPAP: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_HSUPA: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_IWLAN: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_LTE: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_LTE_CA: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_NR: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_TD_SCDMA: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_UMTS: typing.ClassVar[int] = ...
    NETWORK_TYPE_BITMASK_UNKNOWN: typing.ClassVar[int] = ...
    NETWORK_TYPE_CDMA: typing.ClassVar[int] = ...
    NETWORK_TYPE_EDGE: typing.ClassVar[int] = ...
    NETWORK_TYPE_EHRPD: typing.ClassVar[int] = ...
    NETWORK_TYPE_EVDO_0: typing.ClassVar[int] = ...
    NETWORK_TYPE_EVDO_A: typing.ClassVar[int] = ...
    NETWORK_TYPE_EVDO_B: typing.ClassVar[int] = ...
    NETWORK_TYPE_GPRS: typing.ClassVar[int] = ...
    NETWORK_TYPE_GSM: typing.ClassVar[int] = ...
    NETWORK_TYPE_HSDPA: typing.ClassVar[int] = ...
    NETWORK_TYPE_HSPA: typing.ClassVar[int] = ...
    NETWORK_TYPE_HSPAP: typing.ClassVar[int] = ...
    NETWORK_TYPE_HSUPA: typing.ClassVar[int] = ...
    NETWORK_TYPE_IDEN: typing.ClassVar[int] = ...
    NETWORK_TYPE_IWLAN: typing.ClassVar[int] = ...
    NETWORK_TYPE_LTE: typing.ClassVar[int] = ...
    NETWORK_TYPE_NR: typing.ClassVar[int] = ...
    NETWORK_TYPE_TD_SCDMA: typing.ClassVar[int] = ...
    NETWORK_TYPE_UMTS: typing.ClassVar[int] = ...
    NETWORK_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    PHONE_TYPE_CDMA: typing.ClassVar[int] = ...
    PHONE_TYPE_GSM: typing.ClassVar[int] = ...
    PHONE_TYPE_NONE: typing.ClassVar[int] = ...
    PHONE_TYPE_SIP: typing.ClassVar[int] = ...
    PREMIUM_CAPABILITY_PRIORITIZE_LATENCY: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_ALREADY_IN_PROGRESS: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_ALREADY_PURCHASED: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_CARRIER_DISABLED: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_CARRIER_ERROR: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_ENTITLEMENT_CHECK_FAILED: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_FEATURE_NOT_SUPPORTED: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_NETWORK_NOT_AVAILABLE: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_NOT_DEFAULT_DATA_SUBSCRIPTION: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_NOT_FOREGROUND: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_PENDING_NETWORK_SETUP: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_REQUEST_FAILED: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_SUCCESS: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_THROTTLED: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_TIMEOUT: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_USER_CANCELED: typing.ClassVar[int] = ...
    PURCHASE_PREMIUM_CAPABILITY_RESULT_USER_DISABLED: typing.ClassVar[int] = ...
    SET_OPPORTUNISTIC_SUB_INACTIVE_SUBSCRIPTION: typing.ClassVar[int] = ...
    SET_OPPORTUNISTIC_SUB_NO_OPPORTUNISTIC_SUB_AVAILABLE: typing.ClassVar[int] = ...
    SET_OPPORTUNISTIC_SUB_REMOTE_SERVICE_EXCEPTION: typing.ClassVar[int] = ...
    SET_OPPORTUNISTIC_SUB_SUCCESS: typing.ClassVar[int] = ...
    SET_OPPORTUNISTIC_SUB_VALIDATION_FAILED: typing.ClassVar[int] = ...
    SIM_STATE_ABSENT: typing.ClassVar[int] = ...
    SIM_STATE_CARD_IO_ERROR: typing.ClassVar[int] = ...
    SIM_STATE_CARD_RESTRICTED: typing.ClassVar[int] = ...
    SIM_STATE_NETWORK_LOCKED: typing.ClassVar[int] = ...
    SIM_STATE_NOT_READY: typing.ClassVar[int] = ...
    SIM_STATE_PERM_DISABLED: typing.ClassVar[int] = ...
    SIM_STATE_PIN_REQUIRED: typing.ClassVar[int] = ...
    SIM_STATE_PUK_REQUIRED: typing.ClassVar[int] = ...
    SIM_STATE_READY: typing.ClassVar[int] = ...
    SIM_STATE_UNKNOWN: typing.ClassVar[int] = ...
    UNINITIALIZED_CARD_ID: typing.ClassVar[int] = ...
    UNKNOWN_CARRIER_ID: typing.ClassVar[int] = ...
    UNSUPPORTED_CARD_ID: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_ABORTED: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_DISABLE_MODEM_FAIL: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_ENABLE_MODEM_FAIL: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_INVALID_ARGUMENTS: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_MULTIPLE_NETWORKS_NOT_SUPPORTED: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_NO_CARRIER_PRIVILEGE: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_NO_OPPORTUNISTIC_SUB_AVAILABLE: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_REMOTE_SERVICE_EXCEPTION: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_SERVICE_IS_DISABLED: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_SUCCESS: typing.ClassVar[int] = ...
    UPDATE_AVAILABLE_NETWORKS_UNKNOWN_FAILURE: typing.ClassVar[int] = ...
    USSD_ERROR_SERVICE_UNAVAIL: typing.ClassVar[int] = ...
    USSD_RETURN_FAILURE: typing.ClassVar[int] = ...
    VVM_TYPE_CVVM: typing.ClassVar[str] = ...
    VVM_TYPE_OMTP: typing.ClassVar[str] = ...
    def canChangeDtmfToneLength(self) -> bool: ...
    def clearSignalStrengthUpdateRequest(self, request: SignalStrengthUpdateRequest, /) -> None: ...
    def createForPhoneAccountHandle(self, phoneAccountHandle: android.telecom.PhoneAccountHandle, /) -> TelephonyManager | None: ...
    def createForSubscriptionId(self, subId: int | java.jint | java.lang.Integer, /) -> TelephonyManager: ...
    def doesSwitchMultiSimConfigTriggerReboot(self) -> bool: ...
    def getActiveModemCount(self) -> int: ...
    def getAllCellInfo(self) -> java.util.List[CellInfo]: ...
    def getAllowedNetworkTypesForReason(self, reason: int | java.jint | java.lang.Integer, /) -> int: ...
    def getCallComposerStatus(self) -> int: ...
    def getCallState(self) -> int: ...
    def getCallStateForSubscription(self) -> int: ...
    def getCardIdForDefaultEuicc(self) -> int: ...
    def getCarrierConfig(self) -> android.os.PersistableBundle: ...
    def getCarrierIdFromSimMccMnc(self) -> int: ...
    def getCarrierRestrictionStatus(self, executor: java.util.concurrent.Executor, resultListener: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def getCellLocation(self) -> CellLocation | None: ...
    def getDataActivity(self) -> int: ...
    def getDataNetworkType(self) -> int: ...
    def getDataState(self) -> int: ...
    @typing.overload
    def getDeviceId(self) -> str: ...
    @typing.overload
    def getDeviceId(self, slotIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getDeviceSoftwareVersion(self) -> str | None: ...
    @typing.overload
    def getEmergencyNumberList(self) -> java.util.Map[java.lang.Integer, java.util.List[android.telephony.emergency.EmergencyNumber]]: ...
    @typing.overload
    def getEmergencyNumberList(self, categories: int | java.jint | java.lang.Integer, /) -> java.util.Map[java.lang.Integer, java.util.List[android.telephony.emergency.EmergencyNumber]]: ...
    def getEquivalentHomePlmns(self) -> java.util.List[java.lang.String]: ...
    def getForbiddenPlmns(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getGroupIdLevel1(self) -> str: ...
    def getIccAuthentication(self, appType: int | java.jint | java.lang.Integer, authType: int | java.jint | java.lang.Integer, data: str | java.lang.String, /) -> str: ...
    @typing.overload
    def getImei(self) -> str: ...
    @typing.overload
    def getImei(self, slotIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getLine1Number(self) -> str: ...
    def getManualNetworkSelectionPlmn(self) -> str: ...
    @typing.overload
    def getManufacturerCode(self) -> str | None: ...
    @typing.overload
    def getManufacturerCode(self, slotIndex: int | java.jint | java.lang.Integer, /) -> str | None: ...
    @staticmethod
    def getMaximumCallComposerPictureSize() -> int: ...
    @typing.overload
    def getMeid(self) -> str: ...
    @typing.overload
    def getMeid(self, slotIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getMmsUAProfUrl(self) -> str: ...
    def getMmsUserAgent(self) -> str: ...
    def getNai(self) -> str: ...
    @typing.overload
    def getNetworkCountryIso(self) -> str: ...
    @typing.overload
    def getNetworkCountryIso(self, slotIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getNetworkOperator(self) -> str: ...
    def getNetworkOperatorName(self) -> str: ...
    def getNetworkSelectionMode(self) -> int: ...
    def getNetworkSlicingConfiguration(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[android.telephony.data.NetworkSlicingConfig, TelephonyManager.NetworkSlicingException], /) -> None: ...
    def getNetworkSpecifier(self) -> str: ...
    def getNetworkType(self) -> int: ...
    def getPhoneAccountHandle(self) -> android.telecom.PhoneAccountHandle | None: ...
    def getPhoneCount(self) -> int: ...
    def getPhoneType(self) -> int: ...
    def getPreferredOpportunisticDataSubscription(self) -> int: ...
    def getPrimaryImei(self) -> str: ...
    @typing.overload
    def getServiceState(self) -> ServiceState | None: ...
    @typing.overload
    def getServiceState(self, includeLocationData: int | java.jint | java.lang.Integer, /) -> ServiceState | None: ...
    def getSignalStrength(self) -> SignalStrength | None: ...
    def getSimCarrierId(self) -> int: ...
    def getSimCarrierIdName(self) -> java.lang.CharSequence | None: ...
    def getSimCountryIso(self) -> str: ...
    def getSimOperator(self) -> str: ...
    def getSimOperatorName(self) -> str: ...
    def getSimSerialNumber(self) -> str: ...
    def getSimSpecificCarrierId(self) -> int: ...
    def getSimSpecificCarrierIdName(self) -> java.lang.CharSequence | None: ...
    @typing.overload
    def getSimState(self) -> int: ...
    @typing.overload
    def getSimState(self, slotIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getSubscriberId(self) -> str: ...
    @typing.overload
    def getSubscriptionId(self) -> int: ...
    @typing.overload
    def getSubscriptionId(self, phoneAccountHandle: android.telecom.PhoneAccountHandle, /) -> int: ...
    def getSupportedModemCount(self) -> int: ...
    def getSupportedRadioAccessFamily(self) -> int: ...
    @typing.overload
    def getTypeAllocationCode(self) -> str | None: ...
    @typing.overload
    def getTypeAllocationCode(self, slotIndex: int | java.jint | java.lang.Integer, /) -> str | None: ...
    def getUiccCardsInfo(self) -> java.util.List[UiccCardInfo]: ...
    def getVisualVoicemailPackageName(self) -> str | None: ...
    def getVoiceMailAlphaTag(self) -> str: ...
    def getVoiceMailNumber(self) -> str: ...
    def getVoiceNetworkType(self) -> int: ...
    def getVoicemailRingtoneUri(self, accountHandle: android.telecom.PhoneAccountHandle, /) -> android.net.Uri | None: ...
    def hasCarrierPrivileges(self) -> bool: ...
    def hasIccCard(self) -> bool: ...
    def iccCloseLogicalChannel(self, channel: int | java.jint | java.lang.Integer, /) -> bool: ...
    def iccExchangeSimIO(self, fileID: int | java.jint | java.lang.Integer, command: int | java.jint | java.lang.Integer, p1: int | java.jint | java.lang.Integer, p2: int | java.jint | java.lang.Integer, p3: int | java.jint | java.lang.Integer, filePath: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def iccOpenLogicalChannel(self, AID: str | java.lang.String, /) -> IccOpenLogicalChannelResponse: ...
    @typing.overload
    def iccOpenLogicalChannel(self, AID: str | java.lang.String, p2: int | java.jint | java.lang.Integer, /) -> IccOpenLogicalChannelResponse: ...
    def iccTransmitApduBasicChannel(self, cla: int | java.jint | java.lang.Integer, instruction: int | java.jint | java.lang.Integer, p1: int | java.jint | java.lang.Integer, p2: int | java.jint | java.lang.Integer, p3: int | java.jint | java.lang.Integer, data: str | java.lang.String, /) -> str: ...
    def iccTransmitApduLogicalChannel(self, channel: int | java.jint | java.lang.Integer, cla: int | java.jint | java.lang.Integer, instruction: int | java.jint | java.lang.Integer, p1: int | java.jint | java.lang.Integer, p2: int | java.jint | java.lang.Integer, p3: int | java.jint | java.lang.Integer, data: str | java.lang.String, /) -> str: ...
    def isConcurrentVoiceAndDataSupported(self) -> bool: ...
    def isDataCapable(self) -> bool: ...
    def isDataConnectionAllowed(self) -> bool: ...
    def isDataEnabled(self) -> bool: ...
    def isDataEnabledForReason(self, reason: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isDataRoamingEnabled(self) -> bool: ...
    def isDeviceSmsCapable(self) -> bool: ...
    def isDeviceVoiceCapable(self) -> bool: ...
    def isEmergencyNumber(self, number: str | java.lang.String, /) -> bool: ...
    def isHearingAidCompatibilitySupported(self) -> bool: ...
    def isManualNetworkSelectionAllowed(self) -> bool: ...
    def isModemEnabledForSlot(self, slotIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isMultiSimSupported(self) -> int: ...
    def isNetworkRoaming(self) -> bool: ...
    def isPremiumCapabilityAvailableForPurchase(self, capability: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isRadioInterfaceCapabilitySupported(self, capability: str | java.lang.String, /) -> bool: ...
    def isRttSupported(self) -> bool: ...
    def isSmsCapable(self) -> bool: ...
    def isTtyModeSupported(self) -> bool: ...
    def isVoiceCapable(self) -> bool: ...
    def isVoicemailVibrationEnabled(self, accountHandle: android.telecom.PhoneAccountHandle, /) -> bool: ...
    def isWorldPhone(self) -> bool: ...
    def listen(self, listener: PhoneStateListener, events: int | java.jint | java.lang.Integer, /) -> None: ...
    def purchasePremiumCapability(self, capability: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, callback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def rebootModem(self) -> None: ...
    @typing.overload
    def registerTelephonyCallback(self, executor: java.util.concurrent.Executor, callback: TelephonyCallback, /) -> None: ...
    @typing.overload
    def registerTelephonyCallback(self, includeLocationData: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, callback: TelephonyCallback, /) -> None: ...
    def requestCellInfoUpdate(self, executor: java.util.concurrent.Executor, callback: TelephonyManager.CellInfoCallback, /) -> None: ...
    @typing.overload
    def requestNetworkScan(self, request: NetworkScanRequest, executor: java.util.concurrent.Executor, callback: TelephonyScanManager.NetworkScanCallback, /) -> NetworkScan | None: ...
    @typing.overload
    def requestNetworkScan(self, includeLocationData: int | java.jint | java.lang.Integer, request: NetworkScanRequest, executor: java.util.concurrent.Executor, callback: TelephonyScanManager.NetworkScanCallback, /) -> NetworkScan | None: ...
    def sendDialerSpecialCode(self, inputCode: str | java.lang.String, /) -> None: ...
    def sendEnvelopeWithStatus(self, content: str | java.lang.String, /) -> str: ...
    def sendUssdRequest(self, ussdRequest: str | java.lang.String, callback: TelephonyManager.UssdResponseCallback, handler: android.os.Handler, /) -> None: ...
    def sendVisualVoicemailSms(self, number: str | java.lang.String, port: int | java.jint | java.lang.Integer, text: str | java.lang.String, sentIntent: android.app.PendingIntent, /) -> None: ...
    def setAllowedNetworkTypesForReason(self, reason: int | java.jint | java.lang.Integer, allowedNetworkTypes: int | java.jlong | java.lang.Long, /) -> None: ...
    def setCallComposerStatus(self, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDataEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDataEnabledForReason(self, reason: int | java.jint | java.lang.Integer, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setForbiddenPlmns(self, fplmns: java.util.List[java.lang.String], /) -> int: ...
    def setLine1NumberForDisplay(self, alphaTag: str | java.lang.String, number: str | java.lang.String, /) -> bool: ...
    def setNetworkSelectionModeAutomatic(self) -> None: ...
    @typing.overload
    def setNetworkSelectionModeManual(self, operatorNumeric: str | java.lang.String, persistSelection: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setNetworkSelectionModeManual(self, operatorNumeric: str | java.lang.String, persistSelection: bool | java.jboolean | java.lang.Boolean, ran: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setOperatorBrandOverride(self, brand: str | java.lang.String, /) -> bool: ...
    def setPreferredNetworkTypeToGlobal(self) -> bool: ...
    def setPreferredOpportunisticDataSubscription(self, subId: int | java.jint | java.lang.Integer, needValidation: bool | java.jboolean | java.lang.Boolean, executor: java.util.concurrent.Executor, callback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def setSignalStrengthUpdateRequest(self, request: SignalStrengthUpdateRequest, /) -> None: ...
    def setVisualVoicemailSmsFilterSettings(self, settings: VisualVoicemailSmsFilterSettings, /) -> None: ...
    def setVoiceMailNumber(self, alphaTag: str | java.lang.String, number: str | java.lang.String, /) -> bool: ...
    def setVoicemailRingtoneUri(self, phoneAccountHandle: android.telecom.PhoneAccountHandle, uri: android.net.Uri, /) -> None: ...
    def setVoicemailVibrationEnabled(self, phoneAccountHandle: android.telecom.PhoneAccountHandle, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def switchMultiSimConfig(self, numOfSims: int | java.jint | java.lang.Integer, /) -> None: ...
    def unregisterTelephonyCallback(self, callback: TelephonyCallback, /) -> None: ...
    def updateAvailableNetworks(self, availableNetworks: java.util.List[AvailableNetworkInfo], executor: java.util.concurrent.Executor, callback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    @typing.overload
    def uploadCallComposerPicture(self, pictureToUpload: java.io.InputStream, contentType: str | java.lang.String, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[android.os.ParcelUuid, TelephonyManager.CallComposerException], /) -> None: ...
    @typing.overload
    def uploadCallComposerPicture(self, pictureToUpload: java.nio.file.Path, contentType: str | java.lang.String, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[android.os.ParcelUuid, TelephonyManager.CallComposerException], /) -> None: ...

    class UssdResponseCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onReceiveUssdResponse(self, telephonyManager: TelephonyManager, request: str | java.lang.String, response: java.lang.CharSequence, /) -> None: ...
        def onReceiveUssdResponseFailed(self, telephonyManager: TelephonyManager, request: str | java.lang.String, failureCode: int | java.jint | java.lang.Integer, /) -> None: ...

    class TimeoutException(TelephonyManager.NetworkSlicingException): ...

    class NetworkSlicingException(java.lang.Exception):
        def toString(self) -> str: ...

    class ModemErrorException(TelephonyManager.NetworkSlicingException): ...

    class CellInfoCallback(java.lang.Object):
        ERROR_MODEM_ERROR: typing.ClassVar[int] = ...
        ERROR_TIMEOUT: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def onCellInfo(self, arg1: java.util.List[CellInfo], /) -> None: ...
        def onError(self, errorCode: int | java.jint | java.lang.Integer, detail: java.lang.Throwable, /) -> None: ...

    class CallComposerException(java.lang.Exception):
        ERROR_AUTHENTICATION_FAILED: typing.ClassVar[int] = ...
        ERROR_FILE_TOO_LARGE: typing.ClassVar[int] = ...
        ERROR_INPUT_CLOSED: typing.ClassVar[int] = ...
        ERROR_IO_EXCEPTION: typing.ClassVar[int] = ...
        ERROR_NETWORK_UNAVAILABLE: typing.ClassVar[int] = ...
        ERROR_REMOTE_END_CLOSED: typing.ClassVar[int] = ...
        ERROR_UNKNOWN: typing.ClassVar[int] = ...
        def __init__(self, errorCode: int | java.jint | java.lang.Integer, ioException: java.io.IOException, /) -> None: ...
        def getErrorCode(self) -> int: ...
        def getIOException(self) -> java.io.IOException: ...

class TelephonyScanManager(java.lang.Object):
    def __init__(self) -> None: ...

    class NetworkScanCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onComplete(self) -> None: ...
        def onError(self, error: int | java.jint | java.lang.Integer, /) -> None: ...
        def onResults(self, results: java.util.List[CellInfo], /) -> None: ...

class UiccCardInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UiccCardInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCardId(self) -> int: ...
    def getEid(self) -> str | None: ...
    def getIccId(self) -> str | None: ...
    def getPhysicalSlotIndex(self) -> int: ...
    def getPorts(self) -> java.util.Collection[UiccPortInfo]: ...
    def getSlotIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def isEuicc(self) -> bool: ...
    def isMultipleEnabledProfilesSupported(self) -> bool: ...
    def isRemovable(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UiccPortInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UiccPortInfo]] = ...
    ICCID_REDACTED: typing.ClassVar[str] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIccId(self) -> str | None: ...
    def getLogicalSlotIndex(self) -> int: ...
    def getPortIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def isActive(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VisualVoicemailService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCellServiceConnected(self, arg1: VisualVoicemailService.VisualVoicemailTask, arg2: android.telecom.PhoneAccountHandle, /) -> None: ...
    def onSimRemoved(self, arg1: VisualVoicemailService.VisualVoicemailTask, arg2: android.telecom.PhoneAccountHandle, /) -> None: ...
    def onSmsReceived(self, arg1: VisualVoicemailService.VisualVoicemailTask, arg2: VisualVoicemailSms, /) -> None: ...
    def onStopped(self, arg1: VisualVoicemailService.VisualVoicemailTask, /) -> None: ...

    class VisualVoicemailTask(java.lang.Object):
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def finish(self) -> None: ...
        def hashCode(self) -> int: ...

class VisualVoicemailSms(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VisualVoicemailSms]] = ...
    def describeContents(self) -> int: ...
    def getFields(self) -> android.os.Bundle: ...
    def getMessageBody(self) -> str: ...
    def getPhoneAccountHandle(self) -> android.telecom.PhoneAccountHandle: ...
    def getPrefix(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VisualVoicemailSmsFilterSettings(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VisualVoicemailSmsFilterSettings]] = ...
    DESTINATION_PORT_ANY: typing.ClassVar[int] = ...
    DESTINATION_PORT_DATA_SMS: typing.ClassVar[int] = ...
    clientPrefix: str = ...
    destinationPort: int = ...
    originatingNumbers: java.util.List[java.lang.String] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> VisualVoicemailSmsFilterSettings: ...
        def setClientPrefix(self, clientPrefix: str | java.lang.String, /) -> VisualVoicemailSmsFilterSettings.Builder: ...
        def setDestinationPort(self, destinationPort: int | java.jint | java.lang.Integer, /) -> VisualVoicemailSmsFilterSettings.Builder: ...
        def setOriginatingNumbers(self, originatingNumbers: java.util.List[java.lang.String], /) -> VisualVoicemailSmsFilterSettings.Builder: ...
